# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'btqw_main.ui'
#
# Created: Fri Feb  1 19:24:01 2013
#      by: PyQt4 UI code generator 4.9.1
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    _fromUtf8 = lambda s: s

class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName(_fromUtf8("MainWindow"))
        MainWindow.resize(800, 600)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(_fromUtf8(":/Btqw Icon")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        MainWindow.setWindowIcon(icon)
        self.centralwidget = QtGui.QWidget(MainWindow)
        self.centralwidget.setObjectName(_fromUtf8("centralwidget"))
        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtGui.QMenuBar(MainWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 800, 25))
        self.menubar.setObjectName(_fromUtf8("menubar"))
        self.menu_File = QtGui.QMenu(self.menubar)
        self.menu_File.setObjectName(_fromUtf8("menu_File"))
        self.menu_Window = QtGui.QMenu(self.menubar)
        self.menu_Window.setObjectName(_fromUtf8("menu_Window"))
        self.menu_Action = QtGui.QMenu(self.menubar)
        self.menu_Action.setObjectName(_fromUtf8("menu_Action"))
        self.menu_Jobs = QtGui.QMenu(self.menubar)
        self.menu_Jobs.setObjectName(_fromUtf8("menu_Jobs"))
        self.menu_Conds = QtGui.QMenu(self.menubar)
        self.menu_Conds.setObjectName(_fromUtf8("menu_Conds"))
        self.menu_Search = QtGui.QMenu(self.menubar)
        self.menu_Search.setObjectName(_fromUtf8("menu_Search"))
        self.menu_Help = QtGui.QMenu(self.menubar)
        self.menu_Help.setObjectName(_fromUtf8("menu_Help"))
        self.menu_Variables = QtGui.QMenu(self.menubar)
        self.menu_Variables.setObjectName(_fromUtf8("menu_Variables"))
        self.menuCreate = QtGui.QMenu(self.menubar)
        self.menuCreate.setObjectName(_fromUtf8("menuCreate"))
        MainWindow.setMenuBar(self.menubar)
        self.statusbar = QtGui.QStatusBar(MainWindow)
        self.statusbar.setObjectName(_fromUtf8("statusbar"))
        MainWindow.setStatusBar(self.statusbar)
        self.toolBar = QtGui.QToolBar(MainWindow)
        self.toolBar.setObjectName(_fromUtf8("toolBar"))
        MainWindow.addToolBar(QtCore.Qt.TopToolBarArea, self.toolBar)
        self.action_Program_options = QtGui.QAction(MainWindow)
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(_fromUtf8(":/Program optons")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_Program_options.setIcon(icon1)
        self.action_Program_options.setShortcutContext(QtCore.Qt.ApplicationShortcut)
        self.action_Program_options.setObjectName(_fromUtf8("action_Program_options"))
        self.action_Display_options = QtGui.QAction(MainWindow)
        self.action_Display_options.setObjectName(_fromUtf8("action_Display_options"))
        self.action_Save_options = QtGui.QAction(MainWindow)
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap(_fromUtf8(":/save job file")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_Save_options.setIcon(icon2)
        self.action_Save_options.setShortcutContext(QtCore.Qt.ApplicationShortcut)
        self.action_Save_options.setObjectName(_fromUtf8("action_Save_options"))
        self.action_Network_stats = QtGui.QAction(MainWindow)
        self.action_Network_stats.setObjectName(_fromUtf8("action_Network_stats"))
        self.action_User_Permissions = QtGui.QAction(MainWindow)
        self.action_User_Permissions.setObjectName(_fromUtf8("action_User_Permissions"))
        self.action_Quit = QtGui.QAction(MainWindow)
        icon3 = QtGui.QIcon()
        icon3.addPixmap(QtGui.QPixmap(_fromUtf8(":/Quit program")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_Quit.setIcon(icon3)
        self.action_Quit.setShortcutContext(QtCore.Qt.ApplicationShortcut)
        self.action_Quit.setObjectName(_fromUtf8("action_Quit"))
        self.action_Window_options = QtGui.QAction(MainWindow)
        icon4 = QtGui.QIcon()
        icon4.addPixmap(QtGui.QPixmap(_fromUtf8(":/Window options")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_Window_options.setIcon(icon4)
        self.action_Window_options.setObjectName(_fromUtf8("action_Window_options"))
        self.action_New_job_window = QtGui.QAction(MainWindow)
        self.action_New_job_window.setObjectName(_fromUtf8("action_New_job_window"))
        self.action_New_variable_window = QtGui.QAction(MainWindow)
        self.action_New_variable_window.setObjectName(_fromUtf8("action_New_variable_window"))
        self.action_Cascade = QtGui.QAction(MainWindow)
        self.action_Cascade.setObjectName(_fromUtf8("action_Cascade"))
        self.action_Tile_vertically = QtGui.QAction(MainWindow)
        self.action_Tile_vertically.setObjectName(_fromUtf8("action_Tile_vertically"))
        self.action_Tile_horizontally = QtGui.QAction(MainWindow)
        self.action_Tile_horizontally.setObjectName(_fromUtf8("action_Tile_horizontally"))
        self.action_list_format = QtGui.QAction(MainWindow)
        self.action_list_format.setObjectName(_fromUtf8("action_list_format"))
        self.action_delete_job = QtGui.QAction(MainWindow)
        self.action_delete_job.setEnabled(False)
        icon5 = QtGui.QIcon()
        icon5.addPixmap(QtGui.QPixmap(_fromUtf8(":/Delete job")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_delete_job.setIcon(icon5)
        self.action_delete_job.setObjectName(_fromUtf8("action_delete_job"))
        self.action_JPermissions = QtGui.QAction(MainWindow)
        self.action_JPermissions.setEnabled(False)
        self.action_JPermissions.setObjectName(_fromUtf8("action_JPermissions"))
        self.action_titprill = QtGui.QAction(MainWindow)
        self.action_titprill.setEnabled(False)
        icon6 = QtGui.QIcon()
        icon6.addPixmap(QtGui.QPixmap(_fromUtf8(":/Title priority load level")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_titprill.setIcon(icon6)
        self.action_titprill.setObjectName(_fromUtf8("action_titprill"))
        self.action_set_runnable = QtGui.QAction(MainWindow)
        self.action_set_runnable.setEnabled(False)
        icon7 = QtGui.QIcon()
        icon7.addPixmap(QtGui.QPixmap(_fromUtf8(":/Set runnable")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_set_runnable.setIcon(icon7)
        self.action_set_runnable.setObjectName(_fromUtf8("action_set_runnable"))
        self.action_setcanc = QtGui.QAction(MainWindow)
        self.action_setcanc.setEnabled(False)
        icon8 = QtGui.QIcon()
        icon8.addPixmap(QtGui.QPixmap(_fromUtf8(":/Set cancelled")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_setcanc.setIcon(icon8)
        self.action_setcanc.setObjectName(_fromUtf8("action_setcanc"))
        self.action_interrupt_job = QtGui.QAction(MainWindow)
        self.action_interrupt_job.setEnabled(False)
        icon9 = QtGui.QIcon()
        icon9.addPixmap(QtGui.QPixmap(_fromUtf8(":/Interrupt signal")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_interrupt_job.setIcon(icon9)
        self.action_interrupt_job.setObjectName(_fromUtf8("action_interrupt_job"))
        self.action_quit_job = QtGui.QAction(MainWindow)
        self.action_quit_job.setEnabled(False)
        icon10 = QtGui.QIcon()
        icon10.addPixmap(QtGui.QPixmap(_fromUtf8(":/Quit signal")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_quit_job.setIcon(icon10)
        self.action_quit_job.setObjectName(_fromUtf8("action_quit_job"))
        self.action_othersig = QtGui.QAction(MainWindow)
        self.action_othersig.setEnabled(False)
        self.action_othersig.setObjectName(_fromUtf8("action_othersig"))
        self.action_View_job = QtGui.QAction(MainWindow)
        self.action_View_job.setEnabled(False)
        icon11 = QtGui.QIcon()
        icon11.addPixmap(QtGui.QPixmap(_fromUtf8(":/View job script")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_View_job.setIcon(icon11)
        self.action_View_job.setObjectName(_fromUtf8("action_View_job"))
        self.action_advance_time = QtGui.QAction(MainWindow)
        self.action_advance_time.setEnabled(False)
        icon12 = QtGui.QIcon()
        icon12.addPixmap(QtGui.QPixmap(_fromUtf8(":/Advance time")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_advance_time.setIcon(icon12)
        self.action_advance_time.setObjectName(_fromUtf8("action_advance_time"))
        self.action_time_limits = QtGui.QAction(MainWindow)
        self.action_time_limits.setEnabled(False)
        self.action_time_limits.setObjectName(_fromUtf8("action_time_limits"))
        self.action_procpar = QtGui.QAction(MainWindow)
        self.action_procpar.setEnabled(False)
        icon13 = QtGui.QIcon()
        icon13.addPixmap(QtGui.QPixmap(_fromUtf8(":/Process parameters")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_procpar.setIcon(icon13)
        self.action_procpar.setObjectName(_fromUtf8("action_procpar"))
        self.action_time = QtGui.QAction(MainWindow)
        self.action_time.setEnabled(False)
        icon14 = QtGui.QIcon()
        icon14.addPixmap(QtGui.QPixmap(_fromUtf8(":/Set time")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_time.setIcon(icon14)
        self.action_time.setObjectName(_fromUtf8("action_time"))
        self.action_mailwrt = QtGui.QAction(MainWindow)
        self.action_mailwrt.setEnabled(False)
        self.action_mailwrt.setObjectName(_fromUtf8("action_mailwrt"))
        self.action_Unqueue_job = QtGui.QAction(MainWindow)
        self.action_Unqueue_job.setObjectName(_fromUtf8("action_Unqueue_job"))
        self.action_Search_for = QtGui.QAction(MainWindow)
        self.action_Search_for.setObjectName(_fromUtf8("action_Search_for"))
        self.action_Search_forwards = QtGui.QAction(MainWindow)
        self.action_Search_forwards.setObjectName(_fromUtf8("action_Search_forwards"))
        self.action_Search_Backwards = QtGui.QAction(MainWindow)
        self.action_Search_Backwards.setObjectName(_fromUtf8("action_Search_Backwards"))
        self.action_About_BTQW = QtGui.QAction(MainWindow)
        self.action_About_BTQW.setObjectName(_fromUtf8("action_About_BTQW"))
        self.action_force_run = QtGui.QAction(MainWindow)
        self.action_force_run.setEnabled(False)
        icon15 = QtGui.QIcon()
        icon15.addPixmap(QtGui.QPixmap(_fromUtf8(":/Force run")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_force_run.setIcon(icon15)
        self.action_force_run.setObjectName(_fromUtf8("action_force_run"))
        self.action_Server_list = QtGui.QAction(MainWindow)
        self.action_Server_list.setObjectName(_fromUtf8("action_Server_list"))
        self.action_Port_settings = QtGui.QAction(MainWindow)
        self.action_Port_settings.setObjectName(_fromUtf8("action_Port_settings"))
        self.action_Save_As = QtGui.QAction(MainWindow)
        self.action_Save_As.setObjectName(_fromUtf8("action_Save_As"))
        self.action_Time_defaults = QtGui.QAction(MainWindow)
        self.action_Time_defaults.setObjectName(_fromUtf8("action_Time_defaults"))
        self.action_Condition_defaults = QtGui.QAction(MainWindow)
        self.action_Condition_defaults.setObjectName(_fromUtf8("action_Condition_defaults"))
        self.action_Assignment_defaults = QtGui.QAction(MainWindow)
        self.action_Assignment_defaults.setObjectName(_fromUtf8("action_Assignment_defaults"))
        self.action_go_job = QtGui.QAction(MainWindow)
        self.action_go_job.setEnabled(False)
        icon16 = QtGui.QIcon()
        icon16.addPixmap(QtGui.QPixmap(_fromUtf8(":/Go job")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_go_job.setIcon(icon16)
        self.action_go_job.setObjectName(_fromUtf8("action_go_job"))
        self.action_Arguments = QtGui.QAction(MainWindow)
        self.action_Arguments.setEnabled(False)
        self.action_Arguments.setObjectName(_fromUtf8("action_Arguments"))
        self.action_Environment = QtGui.QAction(MainWindow)
        self.action_Environment.setEnabled(False)
        self.action_Environment.setObjectName(_fromUtf8("action_Environment"))
        self.action_Redirections = QtGui.QAction(MainWindow)
        self.action_Redirections.setEnabled(False)
        self.action_Redirections.setObjectName(_fromUtf8("action_Redirections"))
        self.action_Invoke_BTRW = QtGui.QAction(MainWindow)
        icon17 = QtGui.QIcon()
        icon17.addPixmap(QtGui.QPixmap(_fromUtf8(":/Btrw icon")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_Invoke_BTRW.setIcon(icon17)
        self.action_Invoke_BTRW.setObjectName(_fromUtf8("action_Invoke_BTRW"))
        self.action_Unqueue_Job = QtGui.QAction(MainWindow)
        self.action_Unqueue_Job.setEnabled(False)
        self.action_Unqueue_Job.setObjectName(_fromUtf8("action_Unqueue_Job"))
        self.action_Copy_Job = QtGui.QAction(MainWindow)
        self.action_Copy_Job.setEnabled(False)
        self.action_Copy_Job.setObjectName(_fromUtf8("action_Copy_Job"))
        self.action_Job_Conditions = QtGui.QAction(MainWindow)
        self.action_Job_Conditions.setEnabled(False)
        icon18 = QtGui.QIcon()
        icon18.addPixmap(QtGui.QPixmap(_fromUtf8(":/Job conditions")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_Job_Conditions.setIcon(icon18)
        self.action_Job_Conditions.setObjectName(_fromUtf8("action_Job_Conditions"))
        self.action_Job_Assignments = QtGui.QAction(MainWindow)
        self.action_Job_Assignments.setEnabled(False)
        icon19 = QtGui.QIcon()
        icon19.addPixmap(QtGui.QPixmap(_fromUtf8(":/Job assignments")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_Job_Assignments.setIcon(icon19)
        self.action_Job_Assignments.setObjectName(_fromUtf8("action_Job_Assignments"))
        self.action_Assign = QtGui.QAction(MainWindow)
        self.action_Assign.setEnabled(False)
        icon20 = QtGui.QIcon()
        icon20.addPixmap(QtGui.QPixmap(_fromUtf8(":/Assign var")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_Assign.setIcon(icon20)
        self.action_Assign.setObjectName(_fromUtf8("action_Assign"))
        self.action_Increment = QtGui.QAction(MainWindow)
        self.action_Increment.setEnabled(False)
        icon21 = QtGui.QIcon()
        icon21.addPixmap(QtGui.QPixmap(_fromUtf8(":/Increment var")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_Increment.setIcon(icon21)
        self.action_Increment.setObjectName(_fromUtf8("action_Increment"))
        self.action_Decrement = QtGui.QAction(MainWindow)
        self.action_Decrement.setEnabled(False)
        icon22 = QtGui.QIcon()
        icon22.addPixmap(QtGui.QPixmap(_fromUtf8(":/Decrement var")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_Decrement.setIcon(icon22)
        self.action_Decrement.setObjectName(_fromUtf8("action_Decrement"))
        self.action_Multiply = QtGui.QAction(MainWindow)
        self.action_Multiply.setEnabled(False)
        self.action_Multiply.setObjectName(_fromUtf8("action_Multiply"))
        self.action_Divide = QtGui.QAction(MainWindow)
        self.action_Divide.setEnabled(False)
        self.action_Divide.setObjectName(_fromUtf8("action_Divide"))
        self.action_Remainder = QtGui.QAction(MainWindow)
        self.action_Remainder.setEnabled(False)
        self.action_Remainder.setObjectName(_fromUtf8("action_Remainder"))
        self.action_Set_comment = QtGui.QAction(MainWindow)
        self.action_Set_comment.setEnabled(False)
        self.action_Set_comment.setObjectName(_fromUtf8("action_Set_comment"))
        self.action_Set_constant = QtGui.QAction(MainWindow)
        self.action_Set_constant.setObjectName(_fromUtf8("action_Set_constant"))
        self.action_VPermissions = QtGui.QAction(MainWindow)
        self.action_VPermissions.setEnabled(False)
        self.action_VPermissions.setObjectName(_fromUtf8("action_VPermissions"))
        self.action_Create_Jobs = QtGui.QAction(MainWindow)
        self.action_Create_Jobs.setObjectName(_fromUtf8("action_Create_Jobs"))
        self.action_Create_Variable = QtGui.QAction(MainWindow)
        self.action_Create_Variable.setObjectName(_fromUtf8("action_Create_Variable"))
        self.action_Delete_Job = QtGui.QAction(MainWindow)
        self.action_Delete_Job.setObjectName(_fromUtf8("action_Delete_Job"))
        self.action_Delete_Variable = QtGui.QAction(MainWindow)
        self.action_Delete_Variable.setEnabled(False)
        self.action_Delete_Variable.setObjectName(_fromUtf8("action_Delete_Variable"))
        self.menu_File.addAction(self.action_Time_defaults)
        self.menu_File.addSeparator()
        self.menu_File.addAction(self.action_Program_options)
        self.menu_File.addSeparator()
        self.menu_File.addAction(self.action_Server_list)
        self.menu_File.addSeparator()
        self.menu_File.addAction(self.action_Port_settings)
        self.menu_File.addSeparator()
        self.menu_File.addAction(self.action_Save_As)
        self.menu_File.addSeparator()
        self.menu_File.addAction(self.action_Quit)
        self.menu_Window.addAction(self.action_New_job_window)
        self.menu_Window.addAction(self.action_New_variable_window)
        self.menu_Window.addAction(self.action_Window_options)
        self.menu_Window.addSeparator()
        self.menu_Window.addAction(self.action_Cascade)
        self.menu_Window.addAction(self.action_Tile_vertically)
        self.menu_Window.addAction(self.action_Tile_horizontally)
        self.menu_Window.addSeparator()
        self.menu_Window.addAction(self.action_list_format)
        self.menu_Action.addSeparator()
        self.menu_Action.addAction(self.action_set_runnable)
        self.menu_Action.addAction(self.action_setcanc)
        self.menu_Action.addAction(self.action_force_run)
        self.menu_Action.addAction(self.action_go_job)
        self.menu_Action.addAction(self.action_interrupt_job)
        self.menu_Action.addAction(self.action_quit_job)
        self.menu_Action.addAction(self.action_othersig)
        self.menu_Jobs.addAction(self.action_View_job)
        self.menu_Jobs.addSeparator()
        self.menu_Jobs.addAction(self.action_advance_time)
        self.menu_Jobs.addSeparator()
        self.menu_Jobs.addAction(self.action_time)
        self.menu_Jobs.addAction(self.action_titprill)
        self.menu_Jobs.addAction(self.action_procpar)
        self.menu_Jobs.addAction(self.action_time_limits)
        self.menu_Jobs.addAction(self.action_mailwrt)
        self.menu_Jobs.addSeparator()
        self.menu_Jobs.addAction(self.action_Arguments)
        self.menu_Jobs.addAction(self.action_Environment)
        self.menu_Jobs.addAction(self.action_Redirections)
        self.menu_Jobs.addSeparator()
        self.menu_Jobs.addAction(self.action_Unqueue_Job)
        self.menu_Jobs.addAction(self.action_Copy_Job)
        self.menu_Jobs.addSeparator()
        self.menu_Conds.addAction(self.action_Job_Conditions)
        self.menu_Conds.addAction(self.action_Job_Assignments)
        self.menu_Search.addAction(self.action_Search_for)
        self.menu_Search.addAction(self.action_Search_forwards)
        self.menu_Search.addAction(self.action_Search_Backwards)
        self.menu_Help.addAction(self.action_About_BTQW)
        self.menu_Variables.addAction(self.action_Assign)
        self.menu_Variables.addAction(self.action_Increment)
        self.menu_Variables.addAction(self.action_Decrement)
        self.menu_Variables.addAction(self.action_Multiply)
        self.menu_Variables.addAction(self.action_Divide)
        self.menu_Variables.addAction(self.action_Remainder)
        self.menu_Variables.addSeparator()
        self.menu_Variables.addAction(self.action_Set_comment)
        self.menu_Variables.addSeparator()
        self.menu_Variables.addAction(self.action_Set_constant)
        self.menuCreate.addAction(self.action_Create_Jobs)
        self.menuCreate.addAction(self.action_delete_job)
        self.menuCreate.addAction(self.action_JPermissions)
        self.menuCreate.addSeparator()
        self.menuCreate.addAction(self.action_Create_Variable)
        self.menuCreate.addAction(self.action_Delete_Variable)
        self.menuCreate.addAction(self.action_VPermissions)
        self.menubar.addAction(self.menu_File.menuAction())
        self.menubar.addAction(self.menu_Window.menuAction())
        self.menubar.addAction(self.menu_Action.menuAction())
        self.menubar.addAction(self.menuCreate.menuAction())
        self.menubar.addAction(self.menu_Jobs.menuAction())
        self.menubar.addAction(self.menu_Conds.menuAction())
        self.menubar.addAction(self.menu_Variables.menuAction())
        self.menubar.addAction(self.menu_Search.menuAction())
        self.menubar.addAction(self.menu_Help.menuAction())
        self.toolBar.addAction(self.action_Program_options)
        self.toolBar.addAction(self.action_Window_options)
        self.toolBar.addSeparator()
        self.toolBar.addAction(self.action_View_job)
        self.toolBar.addAction(self.action_titprill)
        self.toolBar.addAction(self.action_procpar)
        self.toolBar.addAction(self.action_delete_job)
        self.toolBar.addAction(self.action_set_runnable)
        self.toolBar.addAction(self.action_setcanc)
        self.toolBar.addSeparator()
        self.toolBar.addAction(self.action_force_run)
        self.toolBar.addAction(self.action_go_job)
        self.toolBar.addAction(self.action_advance_time)
        self.toolBar.addSeparator()
        self.toolBar.addAction(self.action_interrupt_job)
        self.toolBar.addAction(self.action_quit_job)
        self.toolBar.addSeparator()
        self.toolBar.addAction(self.action_time)
        self.toolBar.addAction(self.action_Job_Conditions)
        self.toolBar.addAction(self.action_Job_Assignments)
        self.toolBar.addSeparator()
        self.toolBar.addAction(self.action_Assign)
        self.toolBar.addAction(self.action_Increment)
        self.toolBar.addAction(self.action_Decrement)

        self.retranslateUi(MainWindow)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "BTQW", None, QtGui.QApplication.UnicodeUTF8))
        self.menu_File.setTitle(QtGui.QApplication.translate("MainWindow", "&File", None, QtGui.QApplication.UnicodeUTF8))
        self.menu_Window.setTitle(QtGui.QApplication.translate("MainWindow", "&Window", None, QtGui.QApplication.UnicodeUTF8))
        self.menu_Action.setTitle(QtGui.QApplication.translate("MainWindow", "&Action", None, QtGui.QApplication.UnicodeUTF8))
        self.menu_Jobs.setTitle(QtGui.QApplication.translate("MainWindow", "&Jobs", None, QtGui.QApplication.UnicodeUTF8))
        self.menu_Conds.setTitle(QtGui.QApplication.translate("MainWindow", "&Conditions", None, QtGui.QApplication.UnicodeUTF8))
        self.menu_Search.setTitle(QtGui.QApplication.translate("MainWindow", "&Search", None, QtGui.QApplication.UnicodeUTF8))
        self.menu_Help.setTitle(QtGui.QApplication.translate("MainWindow", "&Help", None, QtGui.QApplication.UnicodeUTF8))
        self.menu_Variables.setTitle(QtGui.QApplication.translate("MainWindow", "&Variables", None, QtGui.QApplication.UnicodeUTF8))
        self.menuCreate.setTitle(QtGui.QApplication.translate("MainWindow", "Create/Delete", None, QtGui.QApplication.UnicodeUTF8))
        self.toolBar.setWindowTitle(QtGui.QApplication.translate("MainWindow", "toolBar", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Program_options.setText(QtGui.QApplication.translate("MainWindow", "&Program options", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Program_options.setToolTip(QtGui.QApplication.translate("MainWindow", "Set overall program options, confirmation of job abort etc", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Program_options.setShortcut(QtGui.QApplication.translate("MainWindow", "Ctrl+P", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Display_options.setText(QtGui.QApplication.translate("MainWindow", "&Display options", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Display_options.setToolTip(QtGui.QApplication.translate("MainWindow", "Set the defaults for which items are displayed", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Display_options.setShortcut(QtGui.QApplication.translate("MainWindow", "Ctrl+D", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Save_options.setText(QtGui.QApplication.translate("MainWindow", "&Save options", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Save_options.setToolTip(QtGui.QApplication.translate("MainWindow", "Save options to config file", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Save_options.setShortcut(QtGui.QApplication.translate("MainWindow", "Ctrl+S", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Network_stats.setText(QtGui.QApplication.translate("MainWindow", "&Network stats", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Network_stats.setToolTip(QtGui.QApplication.translate("MainWindow", "Display connection statistics to other hosts on network", None, QtGui.QApplication.UnicodeUTF8))
        self.action_User_Permissions.setText(QtGui.QApplication.translate("MainWindow", "&User Permissions", None, QtGui.QApplication.UnicodeUTF8))
        self.action_User_Permissions.setToolTip(QtGui.QApplication.translate("MainWindow", "Display user permissions on the current server", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Quit.setText(QtGui.QApplication.translate("MainWindow", "&Quit", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Quit.setToolTip(QtGui.QApplication.translate("MainWindow", "Quit saving program options", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Quit.setShortcut(QtGui.QApplication.translate("MainWindow", "Ctrl+Q", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Window_options.setText(QtGui.QApplication.translate("MainWindow", "&Window Options", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Window_options.setShortcut(QtGui.QApplication.translate("MainWindow", "Ctrl+O", None, QtGui.QApplication.UnicodeUTF8))
        self.action_New_job_window.setText(QtGui.QApplication.translate("MainWindow", "New &job window", None, QtGui.QApplication.UnicodeUTF8))
        self.action_New_job_window.setToolTip(QtGui.QApplication.translate("MainWindow", "Create new job window (you can separately change viewing options)", None, QtGui.QApplication.UnicodeUTF8))
        self.action_New_job_window.setShortcut(QtGui.QApplication.translate("MainWindow", "Ctrl+Shift+J", None, QtGui.QApplication.UnicodeUTF8))
        self.action_New_variable_window.setText(QtGui.QApplication.translate("MainWindow", "New &variable window", None, QtGui.QApplication.UnicodeUTF8))
        self.action_New_variable_window.setToolTip(QtGui.QApplication.translate("MainWindow", "Create new variable display window (you can separately change viewing options)", None, QtGui.QApplication.UnicodeUTF8))
        self.action_New_variable_window.setShortcut(QtGui.QApplication.translate("MainWindow", "Ctrl+Shift+V", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Cascade.setText(QtGui.QApplication.translate("MainWindow", "&Cascade", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Cascade.setToolTip(QtGui.QApplication.translate("MainWindow", "Cascade job and variable windows", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Tile_vertically.setText(QtGui.QApplication.translate("MainWindow", "&Tile vertically", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Tile_vertically.setToolTip(QtGui.QApplication.translate("MainWindow", "Tile job and variable windows vertically", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Tile_horizontally.setText(QtGui.QApplication.translate("MainWindow", "&Tile horizontally", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Tile_horizontally.setToolTip(QtGui.QApplication.translate("MainWindow", "Tile job and variable windows horizontally", None, QtGui.QApplication.UnicodeUTF8))
        self.action_list_format.setText(QtGui.QApplication.translate("MainWindow", "&Set list format", None, QtGui.QApplication.UnicodeUTF8))
        self.action_list_format.setToolTip(QtGui.QApplication.translate("MainWindow", "Set which attributes of jobs or variables you want displayed in currently-selected window", None, QtGui.QApplication.UnicodeUTF8))
        self.action_delete_job.setText(QtGui.QApplication.translate("MainWindow", "&Delete Job", None, QtGui.QApplication.UnicodeUTF8))
        self.action_delete_job.setToolTip(QtGui.QApplication.translate("MainWindow", "Delete job (which should not be running - kill it first)", None, QtGui.QApplication.UnicodeUTF8))
        self.action_delete_job.setShortcut(QtGui.QApplication.translate("MainWindow", "Del", None, QtGui.QApplication.UnicodeUTF8))
        self.action_JPermissions.setText(QtGui.QApplication.translate("MainWindow", "Job &Permissions", None, QtGui.QApplication.UnicodeUTF8))
        self.action_JPermissions.setToolTip(QtGui.QApplication.translate("MainWindow", "Set the permissions on the selected job", None, QtGui.QApplication.UnicodeUTF8))
        self.action_titprill.setText(QtGui.QApplication.translate("MainWindow", "&Title prio, load level", None, QtGui.QApplication.UnicodeUTF8))
        self.action_titprill.setToolTip(QtGui.QApplication.translate("MainWindow", "Set title, priority, load level, command interpreter", None, QtGui.QApplication.UnicodeUTF8))
        self.action_titprill.setShortcut(QtGui.QApplication.translate("MainWindow", "P", None, QtGui.QApplication.UnicodeUTF8))
        self.action_set_runnable.setText(QtGui.QApplication.translate("MainWindow", "Set &runnable", None, QtGui.QApplication.UnicodeUTF8))
        self.action_set_runnable.setToolTip(QtGui.QApplication.translate("MainWindow", "Set the job to be runnable", None, QtGui.QApplication.UnicodeUTF8))
        self.action_set_runnable.setShortcut(QtGui.QApplication.translate("MainWindow", "R", None, QtGui.QApplication.UnicodeUTF8))
        self.action_setcanc.setText(QtGui.QApplication.translate("MainWindow", "Set &cancelled", None, QtGui.QApplication.UnicodeUTF8))
        self.action_setcanc.setToolTip(QtGui.QApplication.translate("MainWindow", "Set the job to cancelled state (does not activate cancelled assignment)", None, QtGui.QApplication.UnicodeUTF8))
        self.action_setcanc.setShortcut(QtGui.QApplication.translate("MainWindow", "Z", None, QtGui.QApplication.UnicodeUTF8))
        self.action_interrupt_job.setText(QtGui.QApplication.translate("MainWindow", "&Interrupt job", None, QtGui.QApplication.UnicodeUTF8))
        self.action_interrupt_job.setToolTip(QtGui.QApplication.translate("MainWindow", "Send \"interrupt\" signal to job", None, QtGui.QApplication.UnicodeUTF8))
        self.action_interrupt_job.setShortcut(QtGui.QApplication.translate("MainWindow", "Shift+Y", None, QtGui.QApplication.UnicodeUTF8))
        self.action_quit_job.setText(QtGui.QApplication.translate("MainWindow", "&Quit job", None, QtGui.QApplication.UnicodeUTF8))
        self.action_quit_job.setToolTip(QtGui.QApplication.translate("MainWindow", "Send \"quit\" signal to job", None, QtGui.QApplication.UnicodeUTF8))
        self.action_quit_job.setShortcut(QtGui.QApplication.translate("MainWindow", "Shift+N", None, QtGui.QApplication.UnicodeUTF8))
        self.action_othersig.setText(QtGui.QApplication.translate("MainWindow", "&Other signal", None, QtGui.QApplication.UnicodeUTF8))
        self.action_othersig.setToolTip(QtGui.QApplication.translate("MainWindow", "Send selected signal to job", None, QtGui.QApplication.UnicodeUTF8))
        self.action_othersig.setShortcut(QtGui.QApplication.translate("MainWindow", "!", None, QtGui.QApplication.UnicodeUTF8))
        self.action_View_job.setText(QtGui.QApplication.translate("MainWindow", "&View job", None, QtGui.QApplication.UnicodeUTF8))
        self.action_View_job.setToolTip(QtGui.QApplication.translate("MainWindow", "View the job script in a new window", None, QtGui.QApplication.UnicodeUTF8))
        self.action_View_job.setShortcut(QtGui.QApplication.translate("MainWindow", "Shift+I", None, QtGui.QApplication.UnicodeUTF8))
        self.action_advance_time.setText(QtGui.QApplication.translate("MainWindow", "&Advance Time", None, QtGui.QApplication.UnicodeUTF8))
        self.action_advance_time.setToolTip(QtGui.QApplication.translate("MainWindow", "Advance time of job to next repeat time", None, QtGui.QApplication.UnicodeUTF8))
        self.action_advance_time.setShortcut(QtGui.QApplication.translate("MainWindow", "F", None, QtGui.QApplication.UnicodeUTF8))
        self.action_time_limits.setText(QtGui.QApplication.translate("MainWindow", "Time &limits", None, QtGui.QApplication.UnicodeUTF8))
        self.action_time_limits.setToolTip(QtGui.QApplication.translate("MainWindow", "Set time limits and automatic signal to job", None, QtGui.QApplication.UnicodeUTF8))
        self.action_time_limits.setShortcut(QtGui.QApplication.translate("MainWindow", "Shift+L", None, QtGui.QApplication.UnicodeUTF8))
        self.action_procpar.setText(QtGui.QApplication.translate("MainWindow", "&Process Parameters", None, QtGui.QApplication.UnicodeUTF8))
        self.action_procpar.setToolTip(QtGui.QApplication.translate("MainWindow", "Set process parameters (umask, directory etc) on job", None, QtGui.QApplication.UnicodeUTF8))
        self.action_procpar.setShortcut(QtGui.QApplication.translate("MainWindow", "O", None, QtGui.QApplication.UnicodeUTF8))
        self.action_time.setText(QtGui.QApplication.translate("MainWindow", "&Time", None, QtGui.QApplication.UnicodeUTF8))
        self.action_time.setIconText(QtGui.QApplication.translate("MainWindow", "Time", None, QtGui.QApplication.UnicodeUTF8))
        self.action_time.setToolTip(QtGui.QApplication.translate("MainWindow", "Set next time and repeat parameters on job", None, QtGui.QApplication.UnicodeUTF8))
        self.action_time.setShortcut(QtGui.QApplication.translate("MainWindow", "T", None, QtGui.QApplication.UnicodeUTF8))
        self.action_mailwrt.setText(QtGui.QApplication.translate("MainWindow", "&Mail and write", None, QtGui.QApplication.UnicodeUTF8))
        self.action_mailwrt.setToolTip(QtGui.QApplication.translate("MainWindow", "Set user and message completion options on job", None, QtGui.QApplication.UnicodeUTF8))
        self.action_mailwrt.setShortcut(QtGui.QApplication.translate("MainWindow", "Shift+M", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Unqueue_job.setText(QtGui.QApplication.translate("MainWindow", "Un&queue job", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Unqueue_job.setToolTip(QtGui.QApplication.translate("MainWindow", "Take job off the queue and make a re-queueable file", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Unqueue_job.setShortcut(QtGui.QApplication.translate("MainWindow", "Shift+U", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Search_for.setText(QtGui.QApplication.translate("MainWindow", "&Search for...", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Search_for.setToolTip(QtGui.QApplication.translate("MainWindow", "Search for a string in current window", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Search_for.setShortcut(QtGui.QApplication.translate("MainWindow", "Shift+F", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Search_forwards.setText(QtGui.QApplication.translate("MainWindow", "Search &forwards", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Search_forwards.setToolTip(QtGui.QApplication.translate("MainWindow", "Repeat last search going forwards", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Search_forwards.setShortcut(QtGui.QApplication.translate("MainWindow", "F3, Ctrl+G", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Search_Backwards.setText(QtGui.QApplication.translate("MainWindow", "Search &backwards", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Search_Backwards.setToolTip(QtGui.QApplication.translate("MainWindow", "Repeat last search going backwards", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Search_Backwards.setShortcut(QtGui.QApplication.translate("MainWindow", "F4", None, QtGui.QApplication.UnicodeUTF8))
        self.action_About_BTQW.setText(QtGui.QApplication.translate("MainWindow", "&About BTQW", None, QtGui.QApplication.UnicodeUTF8))
        self.action_About_BTQW.setIconText(QtGui.QApplication.translate("MainWindow", "About BTQW", None, QtGui.QApplication.UnicodeUTF8))
        self.action_force_run.setText(QtGui.QApplication.translate("MainWindow", "&Force run", None, QtGui.QApplication.UnicodeUTF8))
        self.action_force_run.setToolTip(QtGui.QApplication.translate("MainWindow", "Set job runnable if not and try to force it to run, bypassing the time setting\n"
"(but not the conditions)", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Server_list.setText(QtGui.QApplication.translate("MainWindow", "&Server list", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Server_list.setToolTip(QtGui.QApplication.translate("MainWindow", "Display list of servers and connection status", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Port_settings.setText(QtGui.QApplication.translate("MainWindow", "P&ort settings", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Port_settings.setToolTip(QtGui.QApplication.translate("MainWindow", "Adjust port settings for access (use with care)", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Save_As.setText(QtGui.QApplication.translate("MainWindow", "Save &As...", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Save_As.setToolTip(QtGui.QApplication.translate("MainWindow", "Specify an alternative saved configuration file", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Save_As.setShortcut(QtGui.QApplication.translate("MainWindow", "Ctrl+Shift+S", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Time_defaults.setText(QtGui.QApplication.translate("MainWindow", "&Time defaults", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Condition_defaults.setText(QtGui.QApplication.translate("MainWindow", "&Condition defaults", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Condition_defaults.setToolTip(QtGui.QApplication.translate("MainWindow", "Set default condition parameters for creating new conditions", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Assignment_defaults.setText(QtGui.QApplication.translate("MainWindow", "&Assignment defaults", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Assignment_defaults.setToolTip(QtGui.QApplication.translate("MainWindow", "Set default assignment parameters for creating new assignments", None, QtGui.QApplication.UnicodeUTF8))
        self.action_go_job.setText(QtGui.QApplication.translate("MainWindow", "&Go job", None, QtGui.QApplication.UnicodeUTF8))
        self.action_go_job.setToolTip(QtGui.QApplication.translate("MainWindow", "Force job to run but advance the time to the next repeat if applicable", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Arguments.setText(QtGui.QApplication.translate("MainWindow", "&Arguments", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Arguments.setToolTip(QtGui.QApplication.translate("MainWindow", "Set command line arguments to pass to the job script", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Arguments.setShortcut(QtGui.QApplication.translate("MainWindow", "A", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Environment.setText(QtGui.QApplication.translate("MainWindow", "&Environment", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Environment.setToolTip(QtGui.QApplication.translate("MainWindow", "Set environment variables to pass to the job script", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Environment.setShortcut(QtGui.QApplication.translate("MainWindow", "E", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Redirections.setText(QtGui.QApplication.translate("MainWindow", "&Redirections", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Redirections.setToolTip(QtGui.QApplication.translate("MainWindow", "Set I/O redirections to pass to the job script", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Redirections.setShortcut(QtGui.QApplication.translate("MainWindow", "I", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Invoke_BTRW.setText(QtGui.QApplication.translate("MainWindow", "&Invoke BTRW", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Invoke_BTRW.setShortcut(QtGui.QApplication.translate("MainWindow", "Shift+W", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Unqueue_Job.setText(QtGui.QApplication.translate("MainWindow", "&Unqueue Job", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Unqueue_Job.setToolTip(QtGui.QApplication.translate("MainWindow", "Unqueue Job, making a copy in an XML file on the local disk", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Unqueue_Job.setShortcut(QtGui.QApplication.translate("MainWindow", "Shift+U", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Copy_Job.setText(QtGui.QApplication.translate("MainWindow", "&Copy job", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Copy_Job.setToolTip(QtGui.QApplication.translate("MainWindow", "Copy job to an XML file on the local disk but do not delete the job.", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Copy_Job.setShortcut(QtGui.QApplication.translate("MainWindow", "C", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Job_Conditions.setText(QtGui.QApplication.translate("MainWindow", "Job &Conditions", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Job_Conditions.setToolTip(QtGui.QApplication.translate("MainWindow", "Set the Job Conditions", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Job_Conditions.setShortcut(QtGui.QApplication.translate("MainWindow", "Shift+C", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Job_Assignments.setText(QtGui.QApplication.translate("MainWindow", "Job &Assignments", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Job_Assignments.setToolTip(QtGui.QApplication.translate("MainWindow", "Set Job Assignments", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Job_Assignments.setShortcut(QtGui.QApplication.translate("MainWindow", "Shift+A", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Assign.setText(QtGui.QApplication.translate("MainWindow", "&Assign", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Assign.setToolTip(QtGui.QApplication.translate("MainWindow", "Assign a given value to the variable", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Assign.setShortcut(QtGui.QApplication.translate("MainWindow", "=", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Increment.setText(QtGui.QApplication.translate("MainWindow", "&Increment", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Increment.setToolTip(QtGui.QApplication.translate("MainWindow", "Increment variable by the amount given in the set constant", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Increment.setShortcut(QtGui.QApplication.translate("MainWindow", "+", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Decrement.setText(QtGui.QApplication.translate("MainWindow", "&Decrement", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Decrement.setToolTip(QtGui.QApplication.translate("MainWindow", "Decrement variable by amount given in the set constant", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Decrement.setShortcut(QtGui.QApplication.translate("MainWindow", "-", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Multiply.setText(QtGui.QApplication.translate("MainWindow", "&Multiply", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Multiply.setToolTip(QtGui.QApplication.translate("MainWindow", "Multiply variable by amount given in set constant", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Multiply.setShortcut(QtGui.QApplication.translate("MainWindow", "*", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Divide.setText(QtGui.QApplication.translate("MainWindow", "&Divide", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Divide.setToolTip(QtGui.QApplication.translate("MainWindow", "Divide variable by amount given in set constant", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Divide.setShortcut(QtGui.QApplication.translate("MainWindow", "/", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Remainder.setText(QtGui.QApplication.translate("MainWindow", "&Remainder", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Remainder.setToolTip(QtGui.QApplication.translate("MainWindow", "Replace variable value by remainder when divided by set constant", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Remainder.setShortcut(QtGui.QApplication.translate("MainWindow", "%", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Set_comment.setText(QtGui.QApplication.translate("MainWindow", "&Set comment", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Set_comment.setToolTip(QtGui.QApplication.translate("MainWindow", "Set comment on variable", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Set_comment.setShortcut(QtGui.QApplication.translate("MainWindow", "\"", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Set_constant.setText(QtGui.QApplication.translate("MainWindow", "Set &constant", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Set_constant.setToolTip(QtGui.QApplication.translate("MainWindow", "Set constant to use in arithmetic operations", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Set_constant.setShortcut(QtGui.QApplication.translate("MainWindow", "@", None, QtGui.QApplication.UnicodeUTF8))
        self.action_VPermissions.setText(QtGui.QApplication.translate("MainWindow", "Variable &Permissions", None, QtGui.QApplication.UnicodeUTF8))
        self.action_VPermissions.setToolTip(QtGui.QApplication.translate("MainWindow", "Set permissions on the selected variable", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Create_Jobs.setText(QtGui.QApplication.translate("MainWindow", "Create &Jobs", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Create_Jobs.setToolTip(QtGui.QApplication.translate("MainWindow", "Enter window for creating jobs", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Create_Jobs.setStatusTip(QtGui.QApplication.translate("MainWindow", "This option invokes the BTRW program", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Create_Variable.setText(QtGui.QApplication.translate("MainWindow", "Create &Variable", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Create_Variable.setToolTip(QtGui.QApplication.translate("MainWindow", "Create a Variable", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Delete_Job.setText(QtGui.QApplication.translate("MainWindow", "Delete Job", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Delete_Job.setToolTip(QtGui.QApplication.translate("MainWindow", "Delete currently-selected Job", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Delete_Variable.setText(QtGui.QApplication.translate("MainWindow", "Delete Variable", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Delete_Variable.setToolTip(QtGui.QApplication.translate("MainWindow", "Delete Currently-selected Variable", None, QtGui.QApplication.UnicodeUTF8))

import resources_rc
