# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'timeparam.ui'
#
# Created: Mon Feb  4 20:08:19 2013
#      by: PyQt4 UI code generator 4.9.1
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    _fromUtf8 = lambda s: s

class Ui_timeparamdlg(object):
    def setupUi(self, timeparamdlg):
        timeparamdlg.setObjectName(_fromUtf8("timeparamdlg"))
        timeparamdlg.resize(682, 516)
        self.buttonBox = QtGui.QDialogButtonBox(timeparamdlg)
        self.buttonBox.setGeometry(QtCore.QRect(400, 470, 261, 32))
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtGui.QDialogButtonBox.Cancel|QtGui.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName(_fromUtf8("buttonBox"))
        self.timeisset = QtGui.QCheckBox(timeparamdlg)
        self.timeisset.setGeometry(QtCore.QRect(20, 20, 141, 22))
        self.timeisset.setObjectName(_fromUtf8("timeisset"))
        self.nexttime_date = QtGui.QCalendarWidget(timeparamdlg)
        self.nexttime_date.setGeometry(QtCore.QRect(20, 60, 448, 172))
        self.nexttime_date.setObjectName(_fromUtf8("nexttime_date"))
        self.nexttime_time = QtGui.QTimeEdit(timeparamdlg)
        self.nexttime_time.setGeometry(QtCore.QRect(490, 130, 118, 27))
        self.nexttime_time.setCalendarPopup(False)
        self.nexttime_time.setObjectName(_fromUtf8("nexttime_time"))
        self.label = QtGui.QLabel(timeparamdlg)
        self.label.setGeometry(QtCore.QRect(490, 80, 121, 17))
        self.label.setObjectName(_fromUtf8("label"))
        self.repstyle = QtGui.QComboBox(timeparamdlg)
        self.repstyle.setGeometry(QtCore.QRect(200, 270, 261, 27))
        self.repstyle.setObjectName(_fromUtf8("repstyle"))
        self.repstyle.addItem(_fromUtf8(""))
        self.repstyle.addItem(_fromUtf8(""))
        self.repstyle.addItem(_fromUtf8(""))
        self.repstyle.addItem(_fromUtf8(""))
        self.repstyle.addItem(_fromUtf8(""))
        self.repstyle.addItem(_fromUtf8(""))
        self.repstyle.addItem(_fromUtf8(""))
        self.repstyle.addItem(_fromUtf8(""))
        self.repstyle.addItem(_fromUtf8(""))
        self.repunits = QtGui.QSpinBox(timeparamdlg)
        self.repunits.setGeometry(QtCore.QRect(70, 270, 60, 27))
        self.repunits.setMinimum(1)
        self.repunits.setMaximum(60)
        self.repunits.setProperty("value", 1)
        self.repunits.setObjectName(_fromUtf8("repunits"))
        self.monthday = QtGui.QSpinBox(timeparamdlg)
        self.monthday.setGeometry(QtCore.QRect(500, 270, 60, 27))
        self.monthday.setMinimum(0)
        self.monthday.setMaximum(31)
        self.monthday.setSingleStep(1)
        self.monthday.setProperty("value", 1)
        self.monthday.setObjectName(_fromUtf8("monthday"))
        self.groupBox = QtGui.QGroupBox(timeparamdlg)
        self.groupBox.setGeometry(QtCore.QRect(70, 310, 411, 91))
        self.groupBox.setObjectName(_fromUtf8("groupBox"))
        self.avSun = QtGui.QCheckBox(self.groupBox)
        self.avSun.setGeometry(QtCore.QRect(0, 30, 97, 22))
        self.avSun.setObjectName(_fromUtf8("avSun"))
        self.avMon = QtGui.QCheckBox(self.groupBox)
        self.avMon.setGeometry(QtCore.QRect(90, 30, 97, 22))
        self.avMon.setObjectName(_fromUtf8("avMon"))
        self.avTue = QtGui.QCheckBox(self.groupBox)
        self.avTue.setGeometry(QtCore.QRect(180, 30, 97, 22))
        self.avTue.setObjectName(_fromUtf8("avTue"))
        self.avWed = QtGui.QCheckBox(self.groupBox)
        self.avWed.setGeometry(QtCore.QRect(270, 30, 111, 22))
        self.avWed.setObjectName(_fromUtf8("avWed"))
        self.avThu = QtGui.QCheckBox(self.groupBox)
        self.avThu.setGeometry(QtCore.QRect(0, 60, 97, 22))
        self.avThu.setObjectName(_fromUtf8("avThu"))
        self.avFri = QtGui.QCheckBox(self.groupBox)
        self.avFri.setGeometry(QtCore.QRect(90, 60, 97, 22))
        self.avFri.setObjectName(_fromUtf8("avFri"))
        self.avSat = QtGui.QCheckBox(self.groupBox)
        self.avSat.setGeometry(QtCore.QRect(180, 60, 97, 22))
        self.avSat.setObjectName(_fromUtf8("avSat"))
        self.avHol = QtGui.QCheckBox(self.groupBox)
        self.avHol.setGeometry(QtCore.QRect(270, 60, 97, 22))
        self.avHol.setObjectName(_fromUtf8("avHol"))
        self.label_2 = QtGui.QLabel(timeparamdlg)
        self.label_2.setGeometry(QtCore.QRect(70, 420, 161, 17))
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_2.setFont(font)
        self.label_2.setObjectName(_fromUtf8("label_2"))
        self.nextrep = QtGui.QLabel(timeparamdlg)
        self.nextrep.setGeometry(QtCore.QRect(250, 420, 201, 21))
        self.nextrep.setObjectName(_fromUtf8("nextrep"))
        self.ifnposs = QtGui.QComboBox(timeparamdlg)
        self.ifnposs.setGeometry(QtCore.QRect(220, 450, 151, 27))
        self.ifnposs.setObjectName(_fromUtf8("ifnposs"))
        self.ifnposs.addItem(_fromUtf8(""))
        self.ifnposs.addItem(_fromUtf8(""))
        self.ifnposs.addItem(_fromUtf8(""))
        self.ifnposs.addItem(_fromUtf8(""))
        self.label_3 = QtGui.QLabel(timeparamdlg)
        self.label_3.setGeometry(QtCore.QRect(70, 460, 111, 17))
        self.label_3.setObjectName(_fromUtf8("label_3"))
        self.label_4 = QtGui.QLabel(timeparamdlg)
        self.label_4.setGeometry(QtCore.QRect(500, 240, 141, 17))
        self.label_4.setObjectName(_fromUtf8("label_4"))
        self.setnow = QtGui.QPushButton(timeparamdlg)
        self.setnow.setGeometry(QtCore.QRect(490, 180, 98, 27))
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.setnow.setFont(font)
        self.setnow.setObjectName(_fromUtf8("setnow"))

        self.retranslateUi(timeparamdlg)
        self.repstyle.setCurrentIndex(1)
        self.ifnposs.setCurrentIndex(1)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("accepted()")), timeparamdlg.accept)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("rejected()")), timeparamdlg.reject)
        QtCore.QMetaObject.connectSlotsByName(timeparamdlg)
        timeparamdlg.setTabOrder(self.timeisset, self.nexttime_date)
        timeparamdlg.setTabOrder(self.nexttime_date, self.nexttime_time)
        timeparamdlg.setTabOrder(self.nexttime_time, self.setnow)
        timeparamdlg.setTabOrder(self.setnow, self.repunits)
        timeparamdlg.setTabOrder(self.repunits, self.repstyle)
        timeparamdlg.setTabOrder(self.repstyle, self.monthday)
        timeparamdlg.setTabOrder(self.monthday, self.avSun)
        timeparamdlg.setTabOrder(self.avSun, self.avMon)
        timeparamdlg.setTabOrder(self.avMon, self.avTue)
        timeparamdlg.setTabOrder(self.avTue, self.avWed)
        timeparamdlg.setTabOrder(self.avWed, self.avThu)
        timeparamdlg.setTabOrder(self.avThu, self.avFri)
        timeparamdlg.setTabOrder(self.avFri, self.avSat)
        timeparamdlg.setTabOrder(self.avSat, self.avHol)
        timeparamdlg.setTabOrder(self.avHol, self.ifnposs)
        timeparamdlg.setTabOrder(self.ifnposs, self.buttonBox)

    def retranslateUi(self, timeparamdlg):
        timeparamdlg.setWindowTitle(QtGui.QApplication.translate("timeparamdlg", "Job Time parameters", None, QtGui.QApplication.UnicodeUTF8))
        self.timeisset.setToolTip(QtGui.QApplication.translate("timeparamdlg", "Indicate job has time set as opposed to being a \"do when possible\" job.", None, QtGui.QApplication.UnicodeUTF8))
        self.timeisset.setText(QtGui.QApplication.translate("timeparamdlg", "Job has time set", None, QtGui.QApplication.UnicodeUTF8))
        self.nexttime_date.setToolTip(QtGui.QApplication.translate("timeparamdlg", "Select the date of the next run here", None, QtGui.QApplication.UnicodeUTF8))
        self.nexttime_time.setToolTip(QtGui.QApplication.translate("timeparamdlg", "Select the time part of the next time here", None, QtGui.QApplication.UnicodeUTF8))
        self.nexttime_time.setDisplayFormat(QtGui.QApplication.translate("timeparamdlg", "HH:mm", None, QtGui.QApplication.UnicodeUTF8))
        self.label.setText(QtGui.QApplication.translate("timeparamdlg", "Next time to run", None, QtGui.QApplication.UnicodeUTF8))
        self.repstyle.setToolTip(QtGui.QApplication.translate("timeparamdlg", "Set here what style of repeat you require.\n"
"Either set to delete at the end, to retain as \"done\" with manual reset or as\n"
"auto-repeat by the intervals given and number of units as given in the box.", None, QtGui.QApplication.UnicodeUTF8))
        self.repstyle.setItemText(0, QtGui.QApplication.translate("timeparamdlg", "Delete at end", None, QtGui.QApplication.UnicodeUTF8))
        self.repstyle.setItemText(1, QtGui.QApplication.translate("timeparamdlg", "Retain as done", None, QtGui.QApplication.UnicodeUTF8))
        self.repstyle.setItemText(2, QtGui.QApplication.translate("timeparamdlg", "Minutes", None, QtGui.QApplication.UnicodeUTF8))
        self.repstyle.setItemText(3, QtGui.QApplication.translate("timeparamdlg", "Hours", None, QtGui.QApplication.UnicodeUTF8))
        self.repstyle.setItemText(4, QtGui.QApplication.translate("timeparamdlg", "Days", None, QtGui.QApplication.UnicodeUTF8))
        self.repstyle.setItemText(5, QtGui.QApplication.translate("timeparamdlg", "Weeks", None, QtGui.QApplication.UnicodeUTF8))
        self.repstyle.setItemText(6, QtGui.QApplication.translate("timeparamdlg", "Months (relative to the beginning)", None, QtGui.QApplication.UnicodeUTF8))
        self.repstyle.setItemText(7, QtGui.QApplication.translate("timeparamdlg", "Months (relative to the end)", None, QtGui.QApplication.UnicodeUTF8))
        self.repstyle.setItemText(8, QtGui.QApplication.translate("timeparamdlg", "Years", None, QtGui.QApplication.UnicodeUTF8))
        self.repunits.setToolTip(QtGui.QApplication.translate("timeparamdlg", "Number of units of the repeat given", None, QtGui.QApplication.UnicodeUTF8))
        self.monthday.setToolTip(QtGui.QApplication.translate("timeparamdlg", "Set the target day of the month for monthly repeats\n"
"\n"
"For month relative to the beginning repeats, this gives the target day of the\n"
"month. If this is not acceptable, then the following day is tried until acceptable.\n"
"\n"
"For month relative to the end repeats this gives the number of days back from\n"
"the end of the month, possibly zero days, so if the month has 31 days, 0 would\n"
"aim for 31st, 1 would aim for 30th and so on. If the day of the week thereby\n"
"selected is unacceptable the preceding day is tried until acceptable.\n"
"\n"
"Note that the display of month days in month relative to the end has been\n"
"changed relative to previous software hopefully to make it more\n"
"understandable.", None, QtGui.QApplication.UnicodeUTF8))
        self.groupBox.setToolTip(QtGui.QApplication.translate("timeparamdlg", "Select days to avoid when calculating repeat", None, QtGui.QApplication.UnicodeUTF8))
        self.groupBox.setTitle(QtGui.QApplication.translate("timeparamdlg", "Avoiding days", None, QtGui.QApplication.UnicodeUTF8))
        self.avSun.setToolTip(QtGui.QApplication.translate("timeparamdlg", "Set Sunday as a day to avoid when calculating repeats", None, QtGui.QApplication.UnicodeUTF8))
        self.avSun.setText(QtGui.QApplication.translate("timeparamdlg", "Sunday", None, QtGui.QApplication.UnicodeUTF8))
        self.avMon.setToolTip(QtGui.QApplication.translate("timeparamdlg", "Set Monday as a day to avoid when calculating repeats", None, QtGui.QApplication.UnicodeUTF8))
        self.avMon.setText(QtGui.QApplication.translate("timeparamdlg", "Monday", None, QtGui.QApplication.UnicodeUTF8))
        self.avTue.setToolTip(QtGui.QApplication.translate("timeparamdlg", "Set Tuesday as a day to avoid when calculating repeats", None, QtGui.QApplication.UnicodeUTF8))
        self.avTue.setText(QtGui.QApplication.translate("timeparamdlg", "Tuesday", None, QtGui.QApplication.UnicodeUTF8))
        self.avWed.setToolTip(QtGui.QApplication.translate("timeparamdlg", "Set Wednesday as a day to avoid when calculating repeats", None, QtGui.QApplication.UnicodeUTF8))
        self.avWed.setText(QtGui.QApplication.translate("timeparamdlg", "Wednesday", None, QtGui.QApplication.UnicodeUTF8))
        self.avThu.setToolTip(QtGui.QApplication.translate("timeparamdlg", "Set Thursday as a day to avoid when calculating repeats", None, QtGui.QApplication.UnicodeUTF8))
        self.avThu.setText(QtGui.QApplication.translate("timeparamdlg", "Thursday", None, QtGui.QApplication.UnicodeUTF8))
        self.avFri.setToolTip(QtGui.QApplication.translate("timeparamdlg", "Set Friday as a day to avoid when calculating repeats", None, QtGui.QApplication.UnicodeUTF8))
        self.avFri.setText(QtGui.QApplication.translate("timeparamdlg", "Friday", None, QtGui.QApplication.UnicodeUTF8))
        self.avSat.setToolTip(QtGui.QApplication.translate("timeparamdlg", "Set Saturday as a day to avoid when calculating repeats", None, QtGui.QApplication.UnicodeUTF8))
        self.avSat.setText(QtGui.QApplication.translate("timeparamdlg", "Saturday", None, QtGui.QApplication.UnicodeUTF8))
        self.avHol.setToolTip(QtGui.QApplication.translate("timeparamdlg", "Avoid one of the table of holidays when calculating repeats.\n"
"", None, QtGui.QApplication.UnicodeUTF8))
        self.avHol.setText(QtGui.QApplication.translate("timeparamdlg", "Holiday", None, QtGui.QApplication.UnicodeUTF8))
        self.label_2.setText(QtGui.QApplication.translate("timeparamdlg", "Next repeat would be", None, QtGui.QApplication.UnicodeUTF8))
        self.nextrep.setToolTip(QtGui.QApplication.translate("timeparamdlg", "This is the estimated next repeat time", None, QtGui.QApplication.UnicodeUTF8))
        self.nextrep.setText(QtGui.QApplication.translate("timeparamdlg", "(n/a)", None, QtGui.QApplication.UnicodeUTF8))
        self.ifnposs.setItemText(0, QtGui.QApplication.translate("timeparamdlg", "Skip to next", None, QtGui.QApplication.UnicodeUTF8))
        self.ifnposs.setItemText(1, QtGui.QApplication.translate("timeparamdlg", "Delay current", None, QtGui.QApplication.UnicodeUTF8))
        self.ifnposs.setItemText(2, QtGui.QApplication.translate("timeparamdlg", "Delay and adjust", None, QtGui.QApplication.UnicodeUTF8))
        self.ifnposs.setItemText(3, QtGui.QApplication.translate("timeparamdlg", "Catch up", None, QtGui.QApplication.UnicodeUTF8))
        self.label_3.setText(QtGui.QApplication.translate("timeparamdlg", "If not possible", None, QtGui.QApplication.UnicodeUTF8))
        self.label_4.setText(QtGui.QApplication.translate("timeparamdlg", "D of M or from end", None, QtGui.QApplication.UnicodeUTF8))
        self.setnow.setToolTip(QtGui.QApplication.translate("timeparamdlg", "Reset date and time to \"now\"", None, QtGui.QApplication.UnicodeUTF8))
        self.setnow.setText(QtGui.QApplication.translate("timeparamdlg", "Now", None, QtGui.QApplication.UnicodeUTF8))

