# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'createjmain.ui'
#
# Created: Wed Jan  9 10:59:53 2013
#      by: PyQt4 UI code generator 4.9.1
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    _fromUtf8 = lambda s: s

class Ui_jcreatewin(object):
    def setupUi(self, jcreatewin):
        jcreatewin.setObjectName(_fromUtf8("jcreatewin"))
        jcreatewin.resize(648, 405)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Preferred, QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(100)
        sizePolicy.setVerticalStretch(100)
        sizePolicy.setHeightForWidth(jcreatewin.sizePolicy().hasHeightForWidth())
        jcreatewin.setSizePolicy(sizePolicy)
        jcreatewin.setUnifiedTitleAndToolBarOnMac(False)
        self.centralwidget = QtGui.QWidget(jcreatewin)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Preferred, QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.centralwidget.sizePolicy().hasHeightForWidth())
        self.centralwidget.setSizePolicy(sizePolicy)
        self.centralwidget.setObjectName(_fromUtf8("centralwidget"))
        self.joblist = QtGui.QTableWidget(self.centralwidget)
        self.joblist.setGeometry(QtCore.QRect(0, 0, 661, 351))
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Preferred, QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.joblist.sizePolicy().hasHeightForWidth())
        self.joblist.setSizePolicy(sizePolicy)
        self.joblist.setLayoutDirection(QtCore.Qt.LeftToRight)
        self.joblist.setObjectName(_fromUtf8("joblist"))
        self.joblist.setColumnCount(4)
        self.joblist.setRowCount(0)
        item = QtGui.QTableWidgetItem()
        self.joblist.setHorizontalHeaderItem(0, item)
        item = QtGui.QTableWidgetItem()
        self.joblist.setHorizontalHeaderItem(1, item)
        item = QtGui.QTableWidgetItem()
        self.joblist.setHorizontalHeaderItem(2, item)
        item = QtGui.QTableWidgetItem()
        self.joblist.setHorizontalHeaderItem(3, item)
        jcreatewin.setCentralWidget(self.centralwidget)
        self.menubar = QtGui.QMenuBar(jcreatewin)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 648, 25))
        self.menubar.setObjectName(_fromUtf8("menubar"))
        self.menuFile = QtGui.QMenu(self.menubar)
        self.menuFile.setObjectName(_fromUtf8("menuFile"))
        self.menu_Defaults = QtGui.QMenu(self.menubar)
        self.menu_Defaults.setObjectName(_fromUtf8("menu_Defaults"))
        self.menuJob = QtGui.QMenu(self.menubar)
        self.menuJob.setObjectName(_fromUtf8("menuJob"))
        self.menu_Script = QtGui.QMenu(self.menubar)
        self.menu_Script.setObjectName(_fromUtf8("menu_Script"))
        jcreatewin.setMenuBar(self.menubar)
        self.statusbar = QtGui.QStatusBar(jcreatewin)
        self.statusbar.setObjectName(_fromUtf8("statusbar"))
        jcreatewin.setStatusBar(self.statusbar)
        self.action_New_Job = QtGui.QAction(jcreatewin)
        self.action_New_Job.setObjectName(_fromUtf8("action_New_Job"))
        self.action_Open_Job_file = QtGui.QAction(jcreatewin)
        self.action_Open_Job_file.setObjectName(_fromUtf8("action_Open_Job_file"))
        self.action_Save = QtGui.QAction(jcreatewin)
        self.action_Save.setObjectName(_fromUtf8("action_Save"))
        self.actionSave_As = QtGui.QAction(jcreatewin)
        self.actionSave_As.setObjectName(_fromUtf8("actionSave_As"))
        self.action_Close = QtGui.QAction(jcreatewin)
        self.action_Close.setObjectName(_fromUtf8("action_Close"))
        self.action_Quit_back = QtGui.QAction(jcreatewin)
        self.action_Quit_back.setObjectName(_fromUtf8("action_Quit_back"))
        self.action_Time = QtGui.QAction(jcreatewin)
        self.action_Time.setObjectName(_fromUtf8("action_Time"))
        self.action_Conditions = QtGui.QAction(jcreatewin)
        self.action_Conditions.setObjectName(_fromUtf8("action_Conditions"))
        self.action_Assignments = QtGui.QAction(jcreatewin)
        self.action_Assignments.setObjectName(_fromUtf8("action_Assignments"))
        self.actionAr_guments = QtGui.QAction(jcreatewin)
        self.actionAr_guments.setObjectName(_fromUtf8("actionAr_guments"))
        self.action_I_O_Redirections = QtGui.QAction(jcreatewin)
        self.action_I_O_Redirections.setObjectName(_fromUtf8("action_I_O_Redirections"))
        self.action_Process_Parameters = QtGui.QAction(jcreatewin)
        self.action_Process_Parameters.setObjectName(_fromUtf8("action_Process_Parameters"))
        self.actionTitle_Prio_Load_Level = QtGui.QAction(jcreatewin)
        self.actionTitle_Prio_Load_Level.setObjectName(_fromUtf8("actionTitle_Prio_Load_Level"))
        self.action_Environment = QtGui.QAction(jcreatewin)
        self.action_Environment.setObjectName(_fromUtf8("action_Environment"))
        self.action_Process_Parameters_2 = QtGui.QAction(jcreatewin)
        self.action_Process_Parameters_2.setObjectName(_fromUtf8("action_Process_Parameters_2"))
        self.actionTitle_Prio_Load_Level_2 = QtGui.QAction(jcreatewin)
        self.actionTitle_Prio_Load_Level_2.setObjectName(_fromUtf8("actionTitle_Prio_Load_Level_2"))
        self.action_Time_2 = QtGui.QAction(jcreatewin)
        self.action_Time_2.setObjectName(_fromUtf8("action_Time_2"))
        self.action_Conditions_2 = QtGui.QAction(jcreatewin)
        self.action_Conditions_2.setObjectName(_fromUtf8("action_Conditions_2"))
        self.actionAr_guments_2 = QtGui.QAction(jcreatewin)
        self.actionAr_guments_2.setObjectName(_fromUtf8("actionAr_guments_2"))
        self.action_I_O_Redirections_2 = QtGui.QAction(jcreatewin)
        self.action_I_O_Redirections_2.setObjectName(_fromUtf8("action_I_O_Redirections_2"))
        self.action_Environment_2 = QtGui.QAction(jcreatewin)
        self.action_Environment_2.setObjectName(_fromUtf8("action_Environment_2"))
        self.action_Assignments_2 = QtGui.QAction(jcreatewin)
        self.action_Assignments_2.setObjectName(_fromUtf8("action_Assignments_2"))
        self.action_Edit_Script = QtGui.QAction(jcreatewin)
        self.action_Edit_Script.setObjectName(_fromUtf8("action_Edit_Script"))
        self.action_Copy_script = QtGui.QAction(jcreatewin)
        self.action_Copy_script.setObjectName(_fromUtf8("action_Copy_script"))
        self.action_Attach_from_file = QtGui.QAction(jcreatewin)
        self.action_Attach_from_file.setObjectName(_fromUtf8("action_Attach_from_file"))
        self.action_Program_options = QtGui.QAction(jcreatewin)
        self.action_Program_options.setObjectName(_fromUtf8("action_Program_options"))
        self.menuFile.addAction(self.action_New_Job)
        self.menuFile.addAction(self.action_Open_Job_file)
        self.menuFile.addSeparator()
        self.menuFile.addAction(self.action_Save)
        self.menuFile.addAction(self.actionSave_As)
        self.menuFile.addSeparator()
        self.menuFile.addAction(self.action_Close)
        self.menuFile.addAction(self.action_Program_options)
        self.menuFile.addSeparator()
        self.menuFile.addSeparator()
        self.menuFile.addAction(self.action_Quit_back)
        self.menu_Defaults.addAction(self.actionTitle_Prio_Load_Level)
        self.menu_Defaults.addAction(self.action_Process_Parameters)
        self.menu_Defaults.addSeparator()
        self.menu_Defaults.addAction(self.action_Time)
        self.menu_Defaults.addAction(self.action_Conditions)
        self.menu_Defaults.addAction(self.action_Assignments)
        self.menu_Defaults.addSeparator()
        self.menu_Defaults.addAction(self.actionAr_guments)
        self.menu_Defaults.addAction(self.action_I_O_Redirections)
        self.menu_Defaults.addAction(self.action_Environment)
        self.menuJob.addAction(self.actionTitle_Prio_Load_Level_2)
        self.menuJob.addAction(self.action_Process_Parameters_2)
        self.menuJob.addSeparator()
        self.menuJob.addAction(self.action_Time_2)
        self.menuJob.addAction(self.action_Conditions_2)
        self.menuJob.addAction(self.action_Assignments_2)
        self.menuJob.addSeparator()
        self.menuJob.addAction(self.actionAr_guments_2)
        self.menuJob.addAction(self.action_I_O_Redirections_2)
        self.menuJob.addAction(self.action_Environment_2)
        self.menu_Script.addAction(self.action_Edit_Script)
        self.menu_Script.addAction(self.action_Copy_script)
        self.menu_Script.addAction(self.action_Attach_from_file)
        self.menubar.addAction(self.menuFile.menuAction())
        self.menubar.addAction(self.menu_Defaults.menuAction())
        self.menubar.addAction(self.menuJob.menuAction())
        self.menubar.addAction(self.menu_Script.menuAction())

        self.retranslateUi(jcreatewin)
        QtCore.QMetaObject.connectSlotsByName(jcreatewin)

    def retranslateUi(self, jcreatewin):
        jcreatewin.setWindowTitle(QtGui.QApplication.translate("jcreatewin", "Administer job files", None, QtGui.QApplication.UnicodeUTF8))
        jcreatewin.setStatusTip(QtGui.QApplication.translate("jcreatewin", "These are a list of job files ready to save or submit", None, QtGui.QApplication.UnicodeUTF8))
        item = self.joblist.horizontalHeaderItem(0)
        item.setText(QtGui.QApplication.translate("jcreatewin", "Job file", None, QtGui.QApplication.UnicodeUTF8))
        item = self.joblist.horizontalHeaderItem(1)
        item.setText(QtGui.QApplication.translate("jcreatewin", "Job title", None, QtGui.QApplication.UnicodeUTF8))
        item = self.joblist.horizontalHeaderItem(2)
        item.setText(QtGui.QApplication.translate("jcreatewin", "Run/Canc", None, QtGui.QApplication.UnicodeUTF8))
        item = self.joblist.horizontalHeaderItem(3)
        item.setText(QtGui.QApplication.translate("jcreatewin", "Subm", None, QtGui.QApplication.UnicodeUTF8))
        self.menuFile.setTitle(QtGui.QApplication.translate("jcreatewin", "File", None, QtGui.QApplication.UnicodeUTF8))
        self.menu_Defaults.setTitle(QtGui.QApplication.translate("jcreatewin", "&Defaults", None, QtGui.QApplication.UnicodeUTF8))
        self.menuJob.setTitle(QtGui.QApplication.translate("jcreatewin", "Job", None, QtGui.QApplication.UnicodeUTF8))
        self.menu_Script.setTitle(QtGui.QApplication.translate("jcreatewin", "&Script", None, QtGui.QApplication.UnicodeUTF8))
        self.action_New_Job.setText(QtGui.QApplication.translate("jcreatewin", "&New Job", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Open_Job_file.setText(QtGui.QApplication.translate("jcreatewin", "&Open Job file", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Save.setText(QtGui.QApplication.translate("jcreatewin", "&Save", None, QtGui.QApplication.UnicodeUTF8))
        self.actionSave_As.setText(QtGui.QApplication.translate("jcreatewin", "Save &As", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Close.setText(QtGui.QApplication.translate("jcreatewin", "&Close job", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Quit_back.setText(QtGui.QApplication.translate("jcreatewin", "&Quit back", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Time.setText(QtGui.QApplication.translate("jcreatewin", "&Time", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Conditions.setText(QtGui.QApplication.translate("jcreatewin", "&Conditions", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Assignments.setText(QtGui.QApplication.translate("jcreatewin", "&Assignments", None, QtGui.QApplication.UnicodeUTF8))
        self.actionAr_guments.setText(QtGui.QApplication.translate("jcreatewin", "Ar&guments", None, QtGui.QApplication.UnicodeUTF8))
        self.action_I_O_Redirections.setText(QtGui.QApplication.translate("jcreatewin", "&I/O Redirections", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Process_Parameters.setText(QtGui.QApplication.translate("jcreatewin", "&Process Parameters", None, QtGui.QApplication.UnicodeUTF8))
        self.actionTitle_Prio_Load_Level.setText(QtGui.QApplication.translate("jcreatewin", "Title, Prio, Load Level", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Environment.setText(QtGui.QApplication.translate("jcreatewin", "&Environment", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Process_Parameters_2.setText(QtGui.QApplication.translate("jcreatewin", "&Process Parameters", None, QtGui.QApplication.UnicodeUTF8))
        self.actionTitle_Prio_Load_Level_2.setText(QtGui.QApplication.translate("jcreatewin", "Title, Prio, Load Level", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Time_2.setText(QtGui.QApplication.translate("jcreatewin", "&Time", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Conditions_2.setText(QtGui.QApplication.translate("jcreatewin", "&Conditions", None, QtGui.QApplication.UnicodeUTF8))
        self.actionAr_guments_2.setText(QtGui.QApplication.translate("jcreatewin", "Ar&guments", None, QtGui.QApplication.UnicodeUTF8))
        self.action_I_O_Redirections_2.setText(QtGui.QApplication.translate("jcreatewin", "&I/O Redirections", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Environment_2.setText(QtGui.QApplication.translate("jcreatewin", "&Environment", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Assignments_2.setText(QtGui.QApplication.translate("jcreatewin", "&Assignments", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Edit_Script.setText(QtGui.QApplication.translate("jcreatewin", "&Edit Script", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Copy_script.setText(QtGui.QApplication.translate("jcreatewin", "&Copy script", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Attach_from_file.setText(QtGui.QApplication.translate("jcreatewin", "&Attach from file", None, QtGui.QApplication.UnicodeUTF8))
        self.action_Program_options.setText(QtGui.QApplication.translate("jcreatewin", "&Program options", None, QtGui.QApplication.UnicodeUTF8))

