# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'btrw_main.ui'
#
# Created: Mon Feb 11 18:23:10 2013
#      by: PyQt4 UI code generator 4.9.1
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    _fromUtf8 = lambda s: s

class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName(_fromUtf8("MainWindow"))
        MainWindow.resize(800, 600)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(_fromUtf8(":/Btrw icon")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        MainWindow.setWindowIcon(icon)
        MainWindow.setToolTip(_fromUtf8(""))
        self.centralwidget = QtGui.QWidget(MainWindow)
        self.centralwidget.setObjectName(_fromUtf8("centralwidget"))
        self.joblist = QtGui.QTableWidget(self.centralwidget)
        self.joblist.setGeometry(QtCore.QRect(0, 10, 791, 491))
        self.joblist.setContextMenuPolicy(QtCore.Qt.CustomContextMenu)
        self.joblist.setSelectionMode(QtGui.QAbstractItemView.SingleSelection)
        self.joblist.setSelectionBehavior(QtGui.QAbstractItemView.SelectRows)
        self.joblist.setObjectName(_fromUtf8("joblist"))
        self.joblist.setColumnCount(8)
        self.joblist.setRowCount(0)
        item = QtGui.QTableWidgetItem()
        self.joblist.setHorizontalHeaderItem(0, item)
        item = QtGui.QTableWidgetItem()
        self.joblist.setHorizontalHeaderItem(1, item)
        item = QtGui.QTableWidgetItem()
        self.joblist.setHorizontalHeaderItem(2, item)
        item = QtGui.QTableWidgetItem()
        self.joblist.setHorizontalHeaderItem(3, item)
        item = QtGui.QTableWidgetItem()
        self.joblist.setHorizontalHeaderItem(4, item)
        item = QtGui.QTableWidgetItem()
        self.joblist.setHorizontalHeaderItem(5, item)
        item = QtGui.QTableWidgetItem()
        self.joblist.setHorizontalHeaderItem(6, item)
        item = QtGui.QTableWidgetItem()
        self.joblist.setHorizontalHeaderItem(7, item)
        self.joblist.horizontalHeader().setVisible(True)
        self.joblist.verticalHeader().setVisible(False)
        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtGui.QMenuBar(MainWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 800, 25))
        self.menubar.setDefaultUp(False)
        self.menubar.setObjectName(_fromUtf8("menubar"))
        self.menu_File = QtGui.QMenu(self.menubar)
        self.menu_File.setObjectName(_fromUtf8("menu_File"))
        self.menu_Defaults = QtGui.QMenu(self.menubar)
        self.menu_Defaults.setObjectName(_fromUtf8("menu_Defaults"))
        self.menu_job = QtGui.QMenu(self.menubar)
        self.menu_job.setObjectName(_fromUtf8("menu_job"))
        self.menu_Submission = QtGui.QMenu(self.menubar)
        self.menu_Submission.setObjectName(_fromUtf8("menu_Submission"))
        self.menu_Help = QtGui.QMenu(self.menubar)
        self.menu_Help.setObjectName(_fromUtf8("menu_Help"))
        self.menu_Conditions = QtGui.QMenu(self.menubar)
        self.menu_Conditions.setObjectName(_fromUtf8("menu_Conditions"))
        MainWindow.setMenuBar(self.menubar)
        self.statusbar = QtGui.QStatusBar(MainWindow)
        self.statusbar.setObjectName(_fromUtf8("statusbar"))
        MainWindow.setStatusBar(self.statusbar)
        self.toolBar = QtGui.QToolBar(MainWindow)
        self.toolBar.setObjectName(_fromUtf8("toolBar"))
        MainWindow.addToolBar(QtCore.Qt.TopToolBarArea, self.toolBar)
        self.action_new_job = QtGui.QAction(MainWindow)
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(_fromUtf8(":/new job file")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_new_job.setIcon(icon1)
        self.action_new_job.setObjectName(_fromUtf8("action_new_job"))
        self.action_open_job = QtGui.QAction(MainWindow)
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap(_fromUtf8(":/open job file")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_open_job.setIcon(icon2)
        self.action_open_job.setObjectName(_fromUtf8("action_open_job"))
        self.action_save = QtGui.QAction(MainWindow)
        icon3 = QtGui.QIcon()
        icon3.addPixmap(QtGui.QPixmap(_fromUtf8(":/save job file")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_save.setIcon(icon3)
        self.action_save.setObjectName(_fromUtf8("action_save"))
        self.action_save_as = QtGui.QAction(MainWindow)
        self.action_save_as.setObjectName(_fromUtf8("action_save_as"))
        self.action_close = QtGui.QAction(MainWindow)
        self.action_close.setObjectName(_fromUtf8("action_close"))
        self.action_progopts = QtGui.QAction(MainWindow)
        self.action_progopts.setObjectName(_fromUtf8("action_progopts"))
        self.action_quit = QtGui.QAction(MainWindow)
        icon4 = QtGui.QIcon()
        icon4.addPixmap(QtGui.QPixmap(_fromUtf8(":/Quit program")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_quit.setIcon(icon4)
        self.action_quit.setObjectName(_fromUtf8("action_quit"))
        self.action_def_setcanc = QtGui.QAction(MainWindow)
        self.action_def_setcanc.setCheckable(True)
        self.action_def_setcanc.setObjectName(_fromUtf8("action_def_setcanc"))
        self.action_def_titprill = QtGui.QAction(MainWindow)
        self.action_def_titprill.setObjectName(_fromUtf8("action_def_titprill"))
        self.action_def_procpar = QtGui.QAction(MainWindow)
        self.action_def_procpar.setObjectName(_fromUtf8("action_def_procpar"))
        self.action_def_timelim = QtGui.QAction(MainWindow)
        self.action_def_timelim.setObjectName(_fromUtf8("action_def_timelim"))
        self.action_def_perms = QtGui.QAction(MainWindow)
        self.action_def_perms.setObjectName(_fromUtf8("action_def_perms"))
        self.action_def_mailwrite = QtGui.QAction(MainWindow)
        self.action_def_mailwrite.setObjectName(_fromUtf8("action_def_mailwrite"))
        self.action_def_args = QtGui.QAction(MainWindow)
        self.action_def_args.setObjectName(_fromUtf8("action_def_args"))
        self.action_def_redirs = QtGui.QAction(MainWindow)
        self.action_def_redirs.setObjectName(_fromUtf8("action_def_redirs"))
        self.action_job_setrun = QtGui.QAction(MainWindow)
        self.action_job_setrun.setObjectName(_fromUtf8("action_job_setrun"))
        self.action_job_setcanc = QtGui.QAction(MainWindow)
        self.action_job_setcanc.setObjectName(_fromUtf8("action_job_setcanc"))
        self.action_job_titprill = QtGui.QAction(MainWindow)
        icon5 = QtGui.QIcon()
        icon5.addPixmap(QtGui.QPixmap(_fromUtf8(":/Title priority load level")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_job_titprill.setIcon(icon5)
        self.action_job_titprill.setObjectName(_fromUtf8("action_job_titprill"))
        self.action_job_procpar = QtGui.QAction(MainWindow)
        icon6 = QtGui.QIcon()
        icon6.addPixmap(QtGui.QPixmap(_fromUtf8(":/Process parameters")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_job_procpar.setIcon(icon6)
        self.action_job_procpar.setObjectName(_fromUtf8("action_job_procpar"))
        self.action_job_timelim = QtGui.QAction(MainWindow)
        self.action_job_timelim.setObjectName(_fromUtf8("action_job_timelim"))
        self.action_job_perms = QtGui.QAction(MainWindow)
        self.action_job_perms.setObjectName(_fromUtf8("action_job_perms"))
        self.action_job_mailwrite = QtGui.QAction(MainWindow)
        self.action_job_mailwrite.setObjectName(_fromUtf8("action_job_mailwrite"))
        self.action_job_args = QtGui.QAction(MainWindow)
        self.action_job_args.setObjectName(_fromUtf8("action_job_args"))
        self.action_job_redirs = QtGui.QAction(MainWindow)
        self.action_job_redirs.setObjectName(_fromUtf8("action_job_redirs"))
        self.action_view_script = QtGui.QAction(MainWindow)
        icon7 = QtGui.QIcon()
        icon7.addPixmap(QtGui.QPixmap(_fromUtf8(":/View job script")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_view_script.setIcon(icon7)
        self.action_view_script.setObjectName(_fromUtf8("action_view_script"))
        self.action_edit_script = QtGui.QAction(MainWindow)
        icon8 = QtGui.QIcon()
        icon8.addPixmap(QtGui.QPixmap(_fromUtf8(":/Edit job script")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_edit_script.setIcon(icon8)
        self.action_edit_script.setObjectName(_fromUtf8("action_edit_script"))
        self.action_submit_locally = QtGui.QAction(MainWindow)
        icon9 = QtGui.QIcon()
        icon9.addPixmap(QtGui.QPixmap(_fromUtf8(":/Submit job")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_submit_locally.setIcon(icon9)
        self.action_submit_locally.setObjectName(_fromUtf8("action_submit_locally"))
        self.action_submit_remote = QtGui.QAction(MainWindow)
        self.action_submit_remote.setObjectName(_fromUtf8("action_submit_remote"))
        self.action_About_BTRW = QtGui.QAction(MainWindow)
        self.action_About_BTRW.setObjectName(_fromUtf8("action_About_BTRW"))
        self.action_job_conds = QtGui.QAction(MainWindow)
        icon10 = QtGui.QIcon()
        icon10.addPixmap(QtGui.QPixmap(_fromUtf8(":/Job conditions")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_job_conds.setIcon(icon10)
        self.action_job_conds.setObjectName(_fromUtf8("action_job_conds"))
        self.action_job_asses = QtGui.QAction(MainWindow)
        icon11 = QtGui.QIcon()
        icon11.addPixmap(QtGui.QPixmap(_fromUtf8(":/Job assignments")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_job_asses.setIcon(icon11)
        self.action_job_asses.setObjectName(_fromUtf8("action_job_asses"))
        self.action_def_conds = QtGui.QAction(MainWindow)
        self.action_def_conds.setObjectName(_fromUtf8("action_def_conds"))
        self.action_def_asses = QtGui.QAction(MainWindow)
        self.action_def_asses.setObjectName(_fromUtf8("action_def_asses"))
        self.action_closedel = QtGui.QAction(MainWindow)
        self.action_closedel.setObjectName(_fromUtf8("action_closedel"))
        self.action_saveall = QtGui.QAction(MainWindow)
        self.action_saveall.setObjectName(_fromUtf8("action_saveall"))
        self.action_def_env = QtGui.QAction(MainWindow)
        self.action_def_env.setObjectName(_fromUtf8("action_def_env"))
        self.action_job_env = QtGui.QAction(MainWindow)
        self.action_job_env.setObjectName(_fromUtf8("action_job_env"))
        self.action_job_set_time = QtGui.QAction(MainWindow)
        icon12 = QtGui.QIcon()
        icon12.addPixmap(QtGui.QPixmap(_fromUtf8(":/Set time")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.action_job_set_time.setIcon(icon12)
        self.action_job_set_time.setObjectName(_fromUtf8("action_job_set_time"))
        self.action_def_set_time = QtGui.QAction(MainWindow)
        self.action_def_set_time.setObjectName(_fromUtf8("action_def_set_time"))
        self.menu_File.addAction(self.action_new_job)
        self.menu_File.addAction(self.action_open_job)
        self.menu_File.addAction(self.action_save)
        self.menu_File.addAction(self.action_save_as)
        self.menu_File.addAction(self.action_saveall)
        self.menu_File.addAction(self.action_close)
        self.menu_File.addAction(self.action_closedel)
        self.menu_File.addSeparator()
        self.menu_File.addAction(self.action_progopts)
        self.menu_File.addSeparator()
        self.menu_File.addAction(self.action_quit)
        self.menu_Defaults.addAction(self.action_def_setcanc)
        self.menu_Defaults.addSeparator()
        self.menu_Defaults.addAction(self.action_def_set_time)
        self.menu_Defaults.addAction(self.action_def_titprill)
        self.menu_Defaults.addAction(self.action_def_procpar)
        self.menu_Defaults.addAction(self.action_def_timelim)
        self.menu_Defaults.addAction(self.action_def_perms)
        self.menu_Defaults.addAction(self.action_def_mailwrite)
        self.menu_Defaults.addSeparator()
        self.menu_Defaults.addAction(self.action_def_args)
        self.menu_Defaults.addAction(self.action_def_redirs)
        self.menu_Defaults.addAction(self.action_def_env)
        self.menu_job.addAction(self.action_job_setrun)
        self.menu_job.addAction(self.action_job_setcanc)
        self.menu_job.addSeparator()
        self.menu_job.addAction(self.action_job_set_time)
        self.menu_job.addAction(self.action_job_titprill)
        self.menu_job.addAction(self.action_job_procpar)
        self.menu_job.addAction(self.action_job_timelim)
        self.menu_job.addAction(self.action_job_perms)
        self.menu_job.addAction(self.action_job_mailwrite)
        self.menu_job.addSeparator()
        self.menu_job.addAction(self.action_job_args)
        self.menu_job.addAction(self.action_job_redirs)
        self.menu_job.addAction(self.action_job_env)
        self.menu_Submission.addAction(self.action_view_script)
        self.menu_Submission.addAction(self.action_edit_script)
        self.menu_Submission.addSeparator()
        self.menu_Submission.addAction(self.action_submit_locally)
        self.menu_Submission.addAction(self.action_submit_remote)
        self.menu_Help.addAction(self.action_About_BTRW)
        self.menu_Conditions.addAction(self.action_job_conds)
        self.menu_Conditions.addAction(self.action_job_asses)
        self.menu_Conditions.addSeparator()
        self.menu_Conditions.addAction(self.action_def_conds)
        self.menu_Conditions.addAction(self.action_def_asses)
        self.menubar.addAction(self.menu_File.menuAction())
        self.menubar.addAction(self.menu_Defaults.menuAction())
        self.menubar.addAction(self.menu_job.menuAction())
        self.menubar.addAction(self.menu_Conditions.menuAction())
        self.menubar.addAction(self.menu_Submission.menuAction())
        self.menubar.addAction(self.menu_Help.menuAction())
        self.toolBar.addAction(self.action_new_job)
        self.toolBar.addAction(self.action_open_job)
        self.toolBar.addAction(self.action_save)
        self.toolBar.addSeparator()
        self.toolBar.addAction(self.action_view_script)
        self.toolBar.addAction(self.action_edit_script)
        self.toolBar.addSeparator()
        self.toolBar.addAction(self.action_submit_locally)
        self.toolBar.addSeparator()
        self.toolBar.addAction(self.action_job_set_time)
        self.toolBar.addAction(self.action_job_titprill)
        self.toolBar.addAction(self.action_job_procpar)
        self.toolBar.addSeparator()
        self.toolBar.addAction(self.action_job_conds)
        self.toolBar.addAction(self.action_job_asses)

        self.retranslateUi(MainWindow)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "Administer saved job files", None, QtGui.QApplication.UnicodeUTF8))
        item = self.joblist.horizontalHeaderItem(0)
        item.setText(QtGui.QApplication.translate("MainWindow", "Directory", None, QtGui.QApplication.UnicodeUTF8))
        item = self.joblist.horizontalHeaderItem(1)
        item.setText(QtGui.QApplication.translate("MainWindow", "File", None, QtGui.QApplication.UnicodeUTF8))
        item = self.joblist.horizontalHeaderItem(2)
        item.setText(QtGui.QApplication.translate("MainWindow", "Title", None, QtGui.QApplication.UnicodeUTF8))
        item = self.joblist.horizontalHeaderItem(3)
        item.setText(QtGui.QApplication.translate("MainWindow", "CI", None, QtGui.QApplication.UnicodeUTF8))
        item = self.joblist.horizontalHeaderItem(4)
        item.setText(QtGui.QApplication.translate("MainWindow", "Scr", None, QtGui.QApplication.UnicodeUTF8))
        item = self.joblist.horizontalHeaderItem(5)
        item.setText(QtGui.QApplication.translate("MainWindow", "R/C", None, QtGui.QApplication.UnicodeUTF8))
        item = self.joblist.horizontalHeaderItem(6)
        item.setText(QtGui.QApplication.translate("MainWindow", "Subm", None, QtGui.QApplication.UnicodeUTF8))
        item = self.joblist.horizontalHeaderItem(7)
        item.setText(QtGui.QApplication.translate("MainWindow", "Ch", None, QtGui.QApplication.UnicodeUTF8))
        self.menu_File.setTitle(QtGui.QApplication.translate("MainWindow", "&File", None, QtGui.QApplication.UnicodeUTF8))
        self.menu_Defaults.setTitle(QtGui.QApplication.translate("MainWindow", "&Defaults", None, QtGui.QApplication.UnicodeUTF8))
        self.menu_job.setTitle(QtGui.QApplication.translate("MainWindow", "&job", None, QtGui.QApplication.UnicodeUTF8))
        self.menu_Submission.setTitle(QtGui.QApplication.translate("MainWindow", "&Submission", None, QtGui.QApplication.UnicodeUTF8))
        self.menu_Help.setTitle(QtGui.QApplication.translate("MainWindow", "&Help", None, QtGui.QApplication.UnicodeUTF8))
        self.menu_Conditions.setTitle(QtGui.QApplication.translate("MainWindow", "&Conditions", None, QtGui.QApplication.UnicodeUTF8))
        self.toolBar.setWindowTitle(QtGui.QApplication.translate("MainWindow", "toolBar", None, QtGui.QApplication.UnicodeUTF8))
        self.action_new_job.setText(QtGui.QApplication.translate("MainWindow", "&New job", None, QtGui.QApplication.UnicodeUTF8))
        self.action_new_job.setToolTip(QtGui.QApplication.translate("MainWindow", "Create a new job", None, QtGui.QApplication.UnicodeUTF8))
        self.action_new_job.setShortcut(QtGui.QApplication.translate("MainWindow", "Ctrl+N", None, QtGui.QApplication.UnicodeUTF8))
        self.action_open_job.setText(QtGui.QApplication.translate("MainWindow", "&Open job", None, QtGui.QApplication.UnicodeUTF8))
        self.action_open_job.setToolTip(QtGui.QApplication.translate("MainWindow", "open an existing job file", None, QtGui.QApplication.UnicodeUTF8))
        self.action_open_job.setShortcut(QtGui.QApplication.translate("MainWindow", "Ctrl+O", None, QtGui.QApplication.UnicodeUTF8))
        self.action_save.setText(QtGui.QApplication.translate("MainWindow", "&Save", None, QtGui.QApplication.UnicodeUTF8))
        self.action_save.setToolTip(QtGui.QApplication.translate("MainWindow", "save job to file", None, QtGui.QApplication.UnicodeUTF8))
        self.action_save.setShortcut(QtGui.QApplication.translate("MainWindow", "Ctrl+S", None, QtGui.QApplication.UnicodeUTF8))
        self.action_save_as.setText(QtGui.QApplication.translate("MainWindow", "Save &as", None, QtGui.QApplication.UnicodeUTF8))
        self.action_save_as.setToolTip(QtGui.QApplication.translate("MainWindow", "save job to prompted-for file name", None, QtGui.QApplication.UnicodeUTF8))
        self.action_save_as.setShortcut(QtGui.QApplication.translate("MainWindow", "Ctrl+Shift+S", None, QtGui.QApplication.UnicodeUTF8))
        self.action_close.setText(QtGui.QApplication.translate("MainWindow", "&Close", None, QtGui.QApplication.UnicodeUTF8))
        self.action_close.setToolTip(QtGui.QApplication.translate("MainWindow", "close job file", None, QtGui.QApplication.UnicodeUTF8))
        self.action_close.setShortcut(QtGui.QApplication.translate("MainWindow", "Ctrl+W", None, QtGui.QApplication.UnicodeUTF8))
        self.action_progopts.setText(QtGui.QApplication.translate("MainWindow", "&Program options", None, QtGui.QApplication.UnicodeUTF8))
        self.action_quit.setText(QtGui.QApplication.translate("MainWindow", "&Quit", None, QtGui.QApplication.UnicodeUTF8))
        self.action_quit.setToolTip(QtGui.QApplication.translate("MainWindow", "Quit program", None, QtGui.QApplication.UnicodeUTF8))
        self.action_quit.setShortcut(QtGui.QApplication.translate("MainWindow", "Ctrl+Q", None, QtGui.QApplication.UnicodeUTF8))
        self.action_def_setcanc.setText(QtGui.QApplication.translate("MainWindow", "Set &Cancelled", None, QtGui.QApplication.UnicodeUTF8))
        self.action_def_setcanc.setToolTip(QtGui.QApplication.translate("MainWindow", "Select this if you want new jobs to be set by default to the cancelled state\n"
"", None, QtGui.QApplication.UnicodeUTF8))
        self.action_def_titprill.setText(QtGui.QApplication.translate("MainWindow", "&Title priority load level", None, QtGui.QApplication.UnicodeUTF8))
        self.action_def_titprill.setToolTip(QtGui.QApplication.translate("MainWindow", "Set the default title, priority, load level and command interpreter", None, QtGui.QApplication.UnicodeUTF8))
        self.action_def_procpar.setText(QtGui.QApplication.translate("MainWindow", "&Process parameters", None, QtGui.QApplication.UnicodeUTF8))
        self.action_def_procpar.setToolTip(QtGui.QApplication.translate("MainWindow", "Set the default values for process parameters such as working directory,\n"
"umask, exit code ranges", None, QtGui.QApplication.UnicodeUTF8))
        self.action_def_timelim.setText(QtGui.QApplication.translate("MainWindow", "&Time limits", None, QtGui.QApplication.UnicodeUTF8))
        self.action_def_timelim.setToolTip(QtGui.QApplication.translate("MainWindow", "Set various default time limits", None, QtGui.QApplication.UnicodeUTF8))
        self.action_def_perms.setText(QtGui.QApplication.translate("MainWindow", "Per&missions", None, QtGui.QApplication.UnicodeUTF8))
        self.action_def_perms.setToolTip(QtGui.QApplication.translate("MainWindow", "Set the default job permissions", None, QtGui.QApplication.UnicodeUTF8))
        self.action_def_mailwrite.setText(QtGui.QApplication.translate("MainWindow", "&Mail / write", None, QtGui.QApplication.UnicodeUTF8))
        self.action_def_mailwrite.setToolTip(QtGui.QApplication.translate("MainWindow", "Set the default mail and write message options", None, QtGui.QApplication.UnicodeUTF8))
        self.action_def_args.setText(QtGui.QApplication.translate("MainWindow", "Ar&guments", None, QtGui.QApplication.UnicodeUTF8))
        self.action_def_args.setToolTip(QtGui.QApplication.translate("MainWindow", "Set the default job arguments", None, QtGui.QApplication.UnicodeUTF8))
        self.action_def_redirs.setText(QtGui.QApplication.translate("MainWindow", "&Redirections", None, QtGui.QApplication.UnicodeUTF8))
        self.action_def_redirs.setToolTip(QtGui.QApplication.translate("MainWindow", "Set the default job redirections", None, QtGui.QApplication.UnicodeUTF8))
        self.action_job_setrun.setText(QtGui.QApplication.translate("MainWindow", "Set &runnable", None, QtGui.QApplication.UnicodeUTF8))
        self.action_job_setrun.setShortcut(QtGui.QApplication.translate("MainWindow", "R", None, QtGui.QApplication.UnicodeUTF8))
        self.action_job_setcanc.setText(QtGui.QApplication.translate("MainWindow", "Set &cancelled", None, QtGui.QApplication.UnicodeUTF8))
        self.action_job_setcanc.setShortcut(QtGui.QApplication.translate("MainWindow", "Z", None, QtGui.QApplication.UnicodeUTF8))
        self.action_job_titprill.setText(QtGui.QApplication.translate("MainWindow", "&Title, priority, load level", None, QtGui.QApplication.UnicodeUTF8))
        self.action_job_titprill.setToolTip(QtGui.QApplication.translate("MainWindow", "Title, priority, load level, command interpreter", None, QtGui.QApplication.UnicodeUTF8))
        self.action_job_titprill.setShortcut(QtGui.QApplication.translate("MainWindow", "Ctrl+T", None, QtGui.QApplication.UnicodeUTF8))
        self.action_job_procpar.setText(QtGui.QApplication.translate("MainWindow", "&Process parameters", None, QtGui.QApplication.UnicodeUTF8))
        self.action_job_procpar.setToolTip(QtGui.QApplication.translate("MainWindow", "Process parameters (directory, umask, ulimit) for the job", None, QtGui.QApplication.UnicodeUTF8))
        self.action_job_procpar.setShortcut(QtGui.QApplication.translate("MainWindow", "Ctrl+P", None, QtGui.QApplication.UnicodeUTF8))
        self.action_job_timelim.setText(QtGui.QApplication.translate("MainWindow", "Time &limits", None, QtGui.QApplication.UnicodeUTF8))
        self.action_job_timelim.setToolTip(QtGui.QApplication.translate("MainWindow", "Time limits for the job", None, QtGui.QApplication.UnicodeUTF8))
        self.action_job_perms.setText(QtGui.QApplication.translate("MainWindow", "Per&missions", None, QtGui.QApplication.UnicodeUTF8))
        self.action_job_perms.setToolTip(QtGui.QApplication.translate("MainWindow", "Permissions on the job", None, QtGui.QApplication.UnicodeUTF8))
        self.action_job_mailwrite.setText(QtGui.QApplication.translate("MainWindow", "&Mail / Write", None, QtGui.QApplication.UnicodeUTF8))
        self.action_job_mailwrite.setToolTip(QtGui.QApplication.translate("MainWindow", "Mail / Write flag settings", None, QtGui.QApplication.UnicodeUTF8))
        self.action_job_args.setText(QtGui.QApplication.translate("MainWindow", "&Arguments", None, QtGui.QApplication.UnicodeUTF8))
        self.action_job_args.setToolTip(QtGui.QApplication.translate("MainWindow", "Edit the job arguments", None, QtGui.QApplication.UnicodeUTF8))
        self.action_job_redirs.setText(QtGui.QApplication.translate("MainWindow", "&Redirections", None, QtGui.QApplication.UnicodeUTF8))
        self.action_job_redirs.setToolTip(QtGui.QApplication.translate("MainWindow", "Edit the job redirections", None, QtGui.QApplication.UnicodeUTF8))
        self.action_view_script.setText(QtGui.QApplication.translate("MainWindow", "&View script", None, QtGui.QApplication.UnicodeUTF8))
        self.action_view_script.setToolTip(QtGui.QApplication.translate("MainWindow", "View the script of the job (read-only)", None, QtGui.QApplication.UnicodeUTF8))
        self.action_edit_script.setText(QtGui.QApplication.translate("MainWindow", "&Edit script", None, QtGui.QApplication.UnicodeUTF8))
        self.action_edit_script.setToolTip(QtGui.QApplication.translate("MainWindow", "Edit script of job in selected editor", None, QtGui.QApplication.UnicodeUTF8))
        self.action_submit_locally.setText(QtGui.QApplication.translate("MainWindow", "&Submit locally", None, QtGui.QApplication.UnicodeUTF8))
        self.action_submit_locally.setToolTip(QtGui.QApplication.translate("MainWindow", "Submit job to local/standard server", None, QtGui.QApplication.UnicodeUTF8))
        self.action_submit_remote.setText(QtGui.QApplication.translate("MainWindow", "&Submit remote", None, QtGui.QApplication.UnicodeUTF8))
        self.action_submit_remote.setToolTip(QtGui.QApplication.translate("MainWindow", "Submit job to alternative server", None, QtGui.QApplication.UnicodeUTF8))
        self.action_About_BTRW.setText(QtGui.QApplication.translate("MainWindow", "&About BTRW", None, QtGui.QApplication.UnicodeUTF8))
        self.action_job_conds.setText(QtGui.QApplication.translate("MainWindow", "&Conditions", None, QtGui.QApplication.UnicodeUTF8))
        self.action_job_conds.setToolTip(QtGui.QApplication.translate("MainWindow", "Set conditions on the job", None, QtGui.QApplication.UnicodeUTF8))
        self.action_job_asses.setText(QtGui.QApplication.translate("MainWindow", "&Assignments", None, QtGui.QApplication.UnicodeUTF8))
        self.action_job_asses.setToolTip(QtGui.QApplication.translate("MainWindow", "Set assignments on the job", None, QtGui.QApplication.UnicodeUTF8))
        self.action_def_conds.setText(QtGui.QApplication.translate("MainWindow", "&Default conditions", None, QtGui.QApplication.UnicodeUTF8))
        self.action_def_conds.setToolTip(QtGui.QApplication.translate("MainWindow", "Set default conditions for new jobs", None, QtGui.QApplication.UnicodeUTF8))
        self.action_def_asses.setText(QtGui.QApplication.translate("MainWindow", "D&efault assignments", None, QtGui.QApplication.UnicodeUTF8))
        self.action_def_asses.setToolTip(QtGui.QApplication.translate("MainWindow", "Set default assignments for new jobs", None, QtGui.QApplication.UnicodeUTF8))
        self.action_closedel.setText(QtGui.QApplication.translate("MainWindow", "Close and &Delete", None, QtGui.QApplication.UnicodeUTF8))
        self.action_closedel.setToolTip(QtGui.QApplication.translate("MainWindow", "This closes the job file and additionally deletes it.", None, QtGui.QApplication.UnicodeUTF8))
        self.action_saveall.setText(QtGui.QApplication.translate("MainWindow", "Save A&ll", None, QtGui.QApplication.UnicodeUTF8))
        self.action_saveall.setToolTip(QtGui.QApplication.translate("MainWindow", "Save all unsaved jobs", None, QtGui.QApplication.UnicodeUTF8))
        self.action_def_env.setText(QtGui.QApplication.translate("MainWindow", "&Environment", None, QtGui.QApplication.UnicodeUTF8))
        self.action_def_env.setToolTip(QtGui.QApplication.translate("MainWindow", "Set the default list of environment variables for the job", None, QtGui.QApplication.UnicodeUTF8))
        self.action_job_env.setText(QtGui.QApplication.translate("MainWindow", "&Environment", None, QtGui.QApplication.UnicodeUTF8))
        self.action_job_env.setToolTip(QtGui.QApplication.translate("MainWindow", "Edit the list of environment variables for the job", None, QtGui.QApplication.UnicodeUTF8))
        self.action_job_env.setShortcut(QtGui.QApplication.translate("MainWindow", "Ctrl+E", None, QtGui.QApplication.UnicodeUTF8))
        self.action_job_set_time.setText(QtGui.QApplication.translate("MainWindow", "&Set time", None, QtGui.QApplication.UnicodeUTF8))
        self.action_job_set_time.setToolTip(QtGui.QApplication.translate("MainWindow", "Set time and repeat parameters for the job", None, QtGui.QApplication.UnicodeUTF8))
        self.action_job_set_time.setShortcut(QtGui.QApplication.translate("MainWindow", "T", None, QtGui.QApplication.UnicodeUTF8))
        self.action_def_set_time.setText(QtGui.QApplication.translate("MainWindow", "&Set time", None, QtGui.QApplication.UnicodeUTF8))
        self.action_def_set_time.setToolTip(QtGui.QApplication.translate("MainWindow", "Set the default time and repeat parameters", None, QtGui.QApplication.UnicodeUTF8))

import resources_rc
