# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'upermdisp.ui'
#
# Created: Tue Aug 14 11:40:54 2012
#      by: PyQt4 UI code generator 4.9.1
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    _fromUtf8 = lambda s: s

class Ui_userperms(object):
    def setupUi(self, userperms):
        userperms.setObjectName(_fromUtf8("userperms"))
        userperms.resize(672, 834)
        self.buttonBox = QtGui.QDialogButtonBox(userperms)
        self.buttonBox.setGeometry(QtCore.QRect(490, 780, 111, 32))
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtGui.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName(_fromUtf8("buttonBox"))
        self.label = QtGui.QLabel(userperms)
        self.label.setGeometry(QtCore.QRect(30, 30, 191, 17))
        self.label.setObjectName(_fromUtf8("label"))
        self.servname = QtGui.QLineEdit(userperms)
        self.servname.setGeometry(QtCore.QRect(220, 20, 321, 27))
        self.servname.setFrame(False)
        self.servname.setReadOnly(True)
        self.servname.setObjectName(_fromUtf8("servname"))
        self.label_2 = QtGui.QLabel(userperms)
        self.label_2.setGeometry(QtCore.QRect(30, 60, 101, 17))
        self.label_2.setObjectName(_fromUtf8("label_2"))
        self.username = QtGui.QLineEdit(userperms)
        self.username.setGeometry(QtCore.QRect(220, 50, 231, 27))
        self.username.setFrame(False)
        self.username.setReadOnly(True)
        self.username.setObjectName(_fromUtf8("username"))
        self.radminperm = QtGui.QCheckBox(userperms)
        self.radminperm.setGeometry(QtCore.QRect(30, 240, 151, 22))
        self.radminperm.setObjectName(_fromUtf8("radminperm"))
        self.wadminperm = QtGui.QCheckBox(userperms)
        self.wadminperm.setGeometry(QtCore.QRect(30, 270, 171, 22))
        self.wadminperm.setObjectName(_fromUtf8("wadminperm"))
        self.createperm = QtGui.QCheckBox(userperms)
        self.createperm.setGeometry(QtCore.QRect(30, 300, 141, 22))
        self.createperm.setObjectName(_fromUtf8("createperm"))
        self.chpermperm = QtGui.QCheckBox(userperms)
        self.chpermperm.setGeometry(QtCore.QRect(30, 330, 311, 22))
        self.chpermperm.setObjectName(_fromUtf8("chpermperm"))
        self.spcreateperm = QtGui.QCheckBox(userperms)
        self.spcreateperm.setGeometry(QtCore.QRect(30, 360, 161, 22))
        self.spcreateperm.setObjectName(_fromUtf8("spcreateperm"))
        self.or_ug_perm = QtGui.QCheckBox(userperms)
        self.or_ug_perm.setGeometry(QtCore.QRect(290, 240, 181, 22))
        self.or_ug_perm.setObjectName(_fromUtf8("or_ug_perm"))
        self.or_uo_perm = QtGui.QCheckBox(userperms)
        self.or_uo_perm.setGeometry(QtCore.QRect(290, 270, 191, 22))
        self.or_uo_perm.setObjectName(_fromUtf8("or_uo_perm"))
        self.or_go_perm = QtGui.QCheckBox(userperms)
        self.or_go_perm.setGeometry(QtCore.QRect(290, 300, 191, 22))
        self.or_go_perm.setObjectName(_fromUtf8("or_go_perm"))
        self.sstopperm = QtGui.QCheckBox(userperms)
        self.sstopperm.setGeometry(QtCore.QRect(290, 330, 181, 22))
        self.sstopperm.setObjectName(_fromUtf8("sstopperm"))
        self.label_3 = QtGui.QLabel(userperms)
        self.label_3.setGeometry(QtCore.QRect(30, 130, 62, 17))
        self.label_3.setObjectName(_fromUtf8("label_3"))
        self.label_4 = QtGui.QLabel(userperms)
        self.label_4.setGeometry(QtCore.QRect(30, 160, 62, 17))
        self.label_4.setObjectName(_fromUtf8("label_4"))
        self.label_5 = QtGui.QLabel(userperms)
        self.label_5.setGeometry(QtCore.QRect(30, 190, 62, 17))
        self.label_5.setObjectName(_fromUtf8("label_5"))
        self.minpri = QtGui.QLineEdit(userperms)
        self.minpri.setGeometry(QtCore.QRect(90, 120, 81, 27))
        self.minpri.setFrame(False)
        self.minpri.setReadOnly(True)
        self.minpri.setObjectName(_fromUtf8("minpri"))
        self.defpri = QtGui.QLineEdit(userperms)
        self.defpri.setGeometry(QtCore.QRect(90, 150, 81, 27))
        self.defpri.setFrame(False)
        self.defpri.setReadOnly(True)
        self.defpri.setObjectName(_fromUtf8("defpri"))
        self.maxpri = QtGui.QLineEdit(userperms)
        self.maxpri.setGeometry(QtCore.QRect(90, 180, 81, 27))
        self.maxpri.setFrame(False)
        self.maxpri.setReadOnly(True)
        self.maxpri.setObjectName(_fromUtf8("maxpri"))
        self.label_6 = QtGui.QLabel(userperms)
        self.label_6.setGeometry(QtCore.QRect(30, 90, 101, 17))
        self.label_6.setObjectName(_fromUtf8("label_6"))
        self.groupname = QtGui.QLineEdit(userperms)
        self.groupname.setGeometry(QtCore.QRect(220, 80, 231, 27))
        self.groupname.setFrame(False)
        self.groupname.setReadOnly(True)
        self.groupname.setObjectName(_fromUtf8("groupname"))
        self.label_7 = QtGui.QLabel(userperms)
        self.label_7.setGeometry(QtCore.QRect(220, 190, 62, 17))
        self.label_7.setObjectName(_fromUtf8("label_7"))
        self.totll = QtGui.QLineEdit(userperms)
        self.totll.setGeometry(QtCore.QRect(300, 150, 81, 27))
        self.totll.setToolTip(_fromUtf8("This is the total load level for jobs running at once"))
        self.totll.setFrame(False)
        self.totll.setReadOnly(True)
        self.totll.setObjectName(_fromUtf8("totll"))
        self.label_8 = QtGui.QLabel(userperms)
        self.label_8.setGeometry(QtCore.QRect(220, 160, 62, 17))
        self.label_8.setObjectName(_fromUtf8("label_8"))
        self.maxll = QtGui.QLineEdit(userperms)
        self.maxll.setGeometry(QtCore.QRect(300, 120, 81, 27))
        self.maxll.setFrame(False)
        self.maxll.setReadOnly(True)
        self.maxll.setObjectName(_fromUtf8("maxll"))
        self.label_9 = QtGui.QLabel(userperms)
        self.label_9.setGeometry(QtCore.QRect(220, 130, 62, 17))
        self.label_9.setObjectName(_fromUtf8("label_9"))
        self.speccll = QtGui.QLineEdit(userperms)
        self.speccll.setGeometry(QtCore.QRect(300, 180, 81, 27))
        self.speccll.setFrame(False)
        self.speccll.setReadOnly(True)
        self.speccll.setObjectName(_fromUtf8("speccll"))
        self.label_10 = QtGui.QLabel(userperms)
        self.label_10.setGeometry(QtCore.QRect(210, 370, 161, 20))
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.label_10.setFont(font)
        self.label_10.setObjectName(_fromUtf8("label_10"))
        self.permtab = QtGui.QTabWidget(userperms)
        self.permtab.setGeometry(QtCore.QRect(60, 410, 471, 356))
        self.permtab.setObjectName(_fromUtf8("permtab"))
        self.juser = QtGui.QWidget()
        self.juser.setObjectName(_fromUtf8("juser"))
        self.horizontalLayout_5 = QtGui.QHBoxLayout(self.juser)
        self.horizontalLayout_5.setObjectName(_fromUtf8("horizontalLayout_5"))
        self.gridLayout = QtGui.QGridLayout()
        self.gridLayout.setObjectName(_fromUtf8("gridLayout"))
        self.ju_read = QtGui.QCheckBox(self.juser)
        self.ju_read.setObjectName(_fromUtf8("ju_read"))
        self.gridLayout.addWidget(self.ju_read, 0, 0, 1, 1)
        self.ju_write = QtGui.QCheckBox(self.juser)
        self.ju_write.setObjectName(_fromUtf8("ju_write"))
        self.gridLayout.addWidget(self.ju_write, 1, 0, 1, 1)
        self.ju_show = QtGui.QCheckBox(self.juser)
        self.ju_show.setObjectName(_fromUtf8("ju_show"))
        self.gridLayout.addWidget(self.ju_show, 2, 0, 1, 1)
        self.ju_rperm = QtGui.QCheckBox(self.juser)
        self.ju_rperm.setObjectName(_fromUtf8("ju_rperm"))
        self.gridLayout.addWidget(self.ju_rperm, 3, 0, 1, 1)
        self.ju_wperm = QtGui.QCheckBox(self.juser)
        self.ju_wperm.setObjectName(_fromUtf8("ju_wperm"))
        self.gridLayout.addWidget(self.ju_wperm, 4, 0, 1, 1)
        self.ju_utake = QtGui.QCheckBox(self.juser)
        self.ju_utake.setObjectName(_fromUtf8("ju_utake"))
        self.gridLayout.addWidget(self.ju_utake, 5, 0, 1, 1)
        self.ju_gtake = QtGui.QCheckBox(self.juser)
        self.ju_gtake.setObjectName(_fromUtf8("ju_gtake"))
        self.gridLayout.addWidget(self.ju_gtake, 6, 0, 1, 1)
        self.ju_ugive = QtGui.QCheckBox(self.juser)
        self.ju_ugive.setObjectName(_fromUtf8("ju_ugive"))
        self.gridLayout.addWidget(self.ju_ugive, 7, 0, 1, 1)
        self.ju_del = QtGui.QCheckBox(self.juser)
        self.ju_del.setObjectName(_fromUtf8("ju_del"))
        self.gridLayout.addWidget(self.ju_del, 9, 0, 1, 1)
        self.ju_kill = QtGui.QCheckBox(self.juser)
        self.ju_kill.setObjectName(_fromUtf8("ju_kill"))
        self.gridLayout.addWidget(self.ju_kill, 10, 0, 1, 1)
        self.ju_ggive = QtGui.QCheckBox(self.juser)
        self.ju_ggive.setObjectName(_fromUtf8("ju_ggive"))
        self.gridLayout.addWidget(self.ju_ggive, 8, 0, 1, 1)
        self.horizontalLayout_5.addLayout(self.gridLayout)
        self.permtab.addTab(self.juser, _fromUtf8(""))
        self.jgroup = QtGui.QWidget()
        self.jgroup.setObjectName(_fromUtf8("jgroup"))
        self.horizontalLayout_4 = QtGui.QHBoxLayout(self.jgroup)
        self.horizontalLayout_4.setObjectName(_fromUtf8("horizontalLayout_4"))
        self.gridLayout_2 = QtGui.QGridLayout()
        self.gridLayout_2.setObjectName(_fromUtf8("gridLayout_2"))
        self.jg_read = QtGui.QCheckBox(self.jgroup)
        self.jg_read.setObjectName(_fromUtf8("jg_read"))
        self.gridLayout_2.addWidget(self.jg_read, 0, 0, 1, 1)
        self.jg_write = QtGui.QCheckBox(self.jgroup)
        self.jg_write.setObjectName(_fromUtf8("jg_write"))
        self.gridLayout_2.addWidget(self.jg_write, 1, 0, 1, 1)
        self.jg_show = QtGui.QCheckBox(self.jgroup)
        self.jg_show.setObjectName(_fromUtf8("jg_show"))
        self.gridLayout_2.addWidget(self.jg_show, 2, 0, 1, 1)
        self.jg_rperm = QtGui.QCheckBox(self.jgroup)
        self.jg_rperm.setObjectName(_fromUtf8("jg_rperm"))
        self.gridLayout_2.addWidget(self.jg_rperm, 3, 0, 1, 1)
        self.jg_wperm = QtGui.QCheckBox(self.jgroup)
        self.jg_wperm.setObjectName(_fromUtf8("jg_wperm"))
        self.gridLayout_2.addWidget(self.jg_wperm, 4, 0, 1, 1)
        self.jg_utake = QtGui.QCheckBox(self.jgroup)
        self.jg_utake.setObjectName(_fromUtf8("jg_utake"))
        self.gridLayout_2.addWidget(self.jg_utake, 5, 0, 1, 1)
        self.jg_gtake = QtGui.QCheckBox(self.jgroup)
        self.jg_gtake.setObjectName(_fromUtf8("jg_gtake"))
        self.gridLayout_2.addWidget(self.jg_gtake, 6, 0, 1, 1)
        self.jg_ugive = QtGui.QCheckBox(self.jgroup)
        self.jg_ugive.setObjectName(_fromUtf8("jg_ugive"))
        self.gridLayout_2.addWidget(self.jg_ugive, 7, 0, 1, 1)
        self.jg_del = QtGui.QCheckBox(self.jgroup)
        self.jg_del.setObjectName(_fromUtf8("jg_del"))
        self.gridLayout_2.addWidget(self.jg_del, 9, 0, 1, 1)
        self.jg_kill = QtGui.QCheckBox(self.jgroup)
        self.jg_kill.setObjectName(_fromUtf8("jg_kill"))
        self.gridLayout_2.addWidget(self.jg_kill, 10, 0, 1, 1)
        self.jg_ggive = QtGui.QCheckBox(self.jgroup)
        self.jg_ggive.setObjectName(_fromUtf8("jg_ggive"))
        self.gridLayout_2.addWidget(self.jg_ggive, 8, 0, 1, 1)
        self.horizontalLayout_4.addLayout(self.gridLayout_2)
        self.permtab.addTab(self.jgroup, _fromUtf8(""))
        self.jother = QtGui.QWidget()
        self.jother.setObjectName(_fromUtf8("jother"))
        self.horizontalLayout_3 = QtGui.QHBoxLayout(self.jother)
        self.horizontalLayout_3.setObjectName(_fromUtf8("horizontalLayout_3"))
        self.gridLayout_3 = QtGui.QGridLayout()
        self.gridLayout_3.setObjectName(_fromUtf8("gridLayout_3"))
        self.jo_read = QtGui.QCheckBox(self.jother)
        self.jo_read.setObjectName(_fromUtf8("jo_read"))
        self.gridLayout_3.addWidget(self.jo_read, 0, 0, 1, 1)
        self.jo_write = QtGui.QCheckBox(self.jother)
        self.jo_write.setObjectName(_fromUtf8("jo_write"))
        self.gridLayout_3.addWidget(self.jo_write, 1, 0, 1, 1)
        self.jo_show = QtGui.QCheckBox(self.jother)
        self.jo_show.setObjectName(_fromUtf8("jo_show"))
        self.gridLayout_3.addWidget(self.jo_show, 2, 0, 1, 1)
        self.jo_rperm = QtGui.QCheckBox(self.jother)
        self.jo_rperm.setObjectName(_fromUtf8("jo_rperm"))
        self.gridLayout_3.addWidget(self.jo_rperm, 3, 0, 1, 1)
        self.jo_wperm = QtGui.QCheckBox(self.jother)
        self.jo_wperm.setObjectName(_fromUtf8("jo_wperm"))
        self.gridLayout_3.addWidget(self.jo_wperm, 4, 0, 1, 1)
        self.jo_utake = QtGui.QCheckBox(self.jother)
        self.jo_utake.setObjectName(_fromUtf8("jo_utake"))
        self.gridLayout_3.addWidget(self.jo_utake, 5, 0, 1, 1)
        self.jo_gtake = QtGui.QCheckBox(self.jother)
        self.jo_gtake.setObjectName(_fromUtf8("jo_gtake"))
        self.gridLayout_3.addWidget(self.jo_gtake, 6, 0, 1, 1)
        self.jo_ugive = QtGui.QCheckBox(self.jother)
        self.jo_ugive.setObjectName(_fromUtf8("jo_ugive"))
        self.gridLayout_3.addWidget(self.jo_ugive, 7, 0, 1, 1)
        self.jo_del = QtGui.QCheckBox(self.jother)
        self.jo_del.setObjectName(_fromUtf8("jo_del"))
        self.gridLayout_3.addWidget(self.jo_del, 9, 0, 1, 1)
        self.jo_kill = QtGui.QCheckBox(self.jother)
        self.jo_kill.setObjectName(_fromUtf8("jo_kill"))
        self.gridLayout_3.addWidget(self.jo_kill, 10, 0, 1, 1)
        self.jo_ggive = QtGui.QCheckBox(self.jother)
        self.jo_ggive.setObjectName(_fromUtf8("jo_ggive"))
        self.gridLayout_3.addWidget(self.jo_ggive, 8, 0, 1, 1)
        self.horizontalLayout_3.addLayout(self.gridLayout_3)
        self.permtab.addTab(self.jother, _fromUtf8(""))
        self.vuser = QtGui.QWidget()
        self.vuser.setObjectName(_fromUtf8("vuser"))
        self.horizontalLayout_2 = QtGui.QHBoxLayout(self.vuser)
        self.horizontalLayout_2.setObjectName(_fromUtf8("horizontalLayout_2"))
        self.gridLayout_4 = QtGui.QGridLayout()
        self.gridLayout_4.setObjectName(_fromUtf8("gridLayout_4"))
        self.vu_read = QtGui.QCheckBox(self.vuser)
        self.vu_read.setObjectName(_fromUtf8("vu_read"))
        self.gridLayout_4.addWidget(self.vu_read, 0, 0, 1, 1)
        self.vu_write = QtGui.QCheckBox(self.vuser)
        self.vu_write.setObjectName(_fromUtf8("vu_write"))
        self.gridLayout_4.addWidget(self.vu_write, 1, 0, 1, 1)
        self.vu_show = QtGui.QCheckBox(self.vuser)
        self.vu_show.setObjectName(_fromUtf8("vu_show"))
        self.gridLayout_4.addWidget(self.vu_show, 2, 0, 1, 1)
        self.vu_rperm = QtGui.QCheckBox(self.vuser)
        self.vu_rperm.setObjectName(_fromUtf8("vu_rperm"))
        self.gridLayout_4.addWidget(self.vu_rperm, 3, 0, 1, 1)
        self.vu_wperm = QtGui.QCheckBox(self.vuser)
        self.vu_wperm.setObjectName(_fromUtf8("vu_wperm"))
        self.gridLayout_4.addWidget(self.vu_wperm, 4, 0, 1, 1)
        self.vu_utake = QtGui.QCheckBox(self.vuser)
        self.vu_utake.setObjectName(_fromUtf8("vu_utake"))
        self.gridLayout_4.addWidget(self.vu_utake, 5, 0, 1, 1)
        self.vu_gtake = QtGui.QCheckBox(self.vuser)
        self.vu_gtake.setObjectName(_fromUtf8("vu_gtake"))
        self.gridLayout_4.addWidget(self.vu_gtake, 6, 0, 1, 1)
        self.vu_ugive = QtGui.QCheckBox(self.vuser)
        self.vu_ugive.setObjectName(_fromUtf8("vu_ugive"))
        self.gridLayout_4.addWidget(self.vu_ugive, 7, 0, 1, 1)
        self.vu_del = QtGui.QCheckBox(self.vuser)
        self.vu_del.setObjectName(_fromUtf8("vu_del"))
        self.gridLayout_4.addWidget(self.vu_del, 9, 0, 1, 1)
        self.vu_ggive = QtGui.QCheckBox(self.vuser)
        self.vu_ggive.setObjectName(_fromUtf8("vu_ggive"))
        self.gridLayout_4.addWidget(self.vu_ggive, 8, 0, 1, 1)
        self.horizontalLayout_2.addLayout(self.gridLayout_4)
        self.permtab.addTab(self.vuser, _fromUtf8(""))
        self.vgroup = QtGui.QWidget()
        self.vgroup.setObjectName(_fromUtf8("vgroup"))
        self.horizontalLayout = QtGui.QHBoxLayout(self.vgroup)
        self.horizontalLayout.setObjectName(_fromUtf8("horizontalLayout"))
        self.gridLayout_5 = QtGui.QGridLayout()
        self.gridLayout_5.setObjectName(_fromUtf8("gridLayout_5"))
        self.vg_read = QtGui.QCheckBox(self.vgroup)
        self.vg_read.setObjectName(_fromUtf8("vg_read"))
        self.gridLayout_5.addWidget(self.vg_read, 0, 0, 1, 1)
        self.vg_write = QtGui.QCheckBox(self.vgroup)
        self.vg_write.setObjectName(_fromUtf8("vg_write"))
        self.gridLayout_5.addWidget(self.vg_write, 1, 0, 1, 1)
        self.vg_show = QtGui.QCheckBox(self.vgroup)
        self.vg_show.setObjectName(_fromUtf8("vg_show"))
        self.gridLayout_5.addWidget(self.vg_show, 2, 0, 1, 1)
        self.vg_rperm = QtGui.QCheckBox(self.vgroup)
        self.vg_rperm.setObjectName(_fromUtf8("vg_rperm"))
        self.gridLayout_5.addWidget(self.vg_rperm, 3, 0, 1, 1)
        self.vg_wperm = QtGui.QCheckBox(self.vgroup)
        self.vg_wperm.setObjectName(_fromUtf8("vg_wperm"))
        self.gridLayout_5.addWidget(self.vg_wperm, 4, 0, 1, 1)
        self.vg_utake = QtGui.QCheckBox(self.vgroup)
        self.vg_utake.setObjectName(_fromUtf8("vg_utake"))
        self.gridLayout_5.addWidget(self.vg_utake, 5, 0, 1, 1)
        self.vg_gtake = QtGui.QCheckBox(self.vgroup)
        self.vg_gtake.setObjectName(_fromUtf8("vg_gtake"))
        self.gridLayout_5.addWidget(self.vg_gtake, 6, 0, 1, 1)
        self.vg_ugive = QtGui.QCheckBox(self.vgroup)
        self.vg_ugive.setObjectName(_fromUtf8("vg_ugive"))
        self.gridLayout_5.addWidget(self.vg_ugive, 7, 0, 1, 1)
        self.vg_ggive = QtGui.QCheckBox(self.vgroup)
        self.vg_ggive.setObjectName(_fromUtf8("vg_ggive"))
        self.gridLayout_5.addWidget(self.vg_ggive, 8, 0, 1, 1)
        self.vg_del = QtGui.QCheckBox(self.vgroup)
        self.vg_del.setObjectName(_fromUtf8("vg_del"))
        self.gridLayout_5.addWidget(self.vg_del, 9, 0, 1, 1)
        self.horizontalLayout.addLayout(self.gridLayout_5)
        self.permtab.addTab(self.vgroup, _fromUtf8(""))
        self.vother = QtGui.QWidget()
        self.vother.setObjectName(_fromUtf8("vother"))
        self.hboxlayout = QtGui.QHBoxLayout(self.vother)
        self.hboxlayout.setObjectName(_fromUtf8("hboxlayout"))
        self.gridLayout_6 = QtGui.QGridLayout()
        self.gridLayout_6.setObjectName(_fromUtf8("gridLayout_6"))
        self.vo_read = QtGui.QCheckBox(self.vother)
        self.vo_read.setObjectName(_fromUtf8("vo_read"))
        self.gridLayout_6.addWidget(self.vo_read, 0, 0, 1, 1)
        self.vo_write = QtGui.QCheckBox(self.vother)
        self.vo_write.setObjectName(_fromUtf8("vo_write"))
        self.gridLayout_6.addWidget(self.vo_write, 1, 0, 1, 1)
        self.vo_show = QtGui.QCheckBox(self.vother)
        self.vo_show.setObjectName(_fromUtf8("vo_show"))
        self.gridLayout_6.addWidget(self.vo_show, 2, 0, 1, 1)
        self.vo_rperm = QtGui.QCheckBox(self.vother)
        self.vo_rperm.setObjectName(_fromUtf8("vo_rperm"))
        self.gridLayout_6.addWidget(self.vo_rperm, 3, 0, 1, 1)
        self.vo_wperm = QtGui.QCheckBox(self.vother)
        self.vo_wperm.setObjectName(_fromUtf8("vo_wperm"))
        self.gridLayout_6.addWidget(self.vo_wperm, 4, 0, 1, 1)
        self.vo_utake = QtGui.QCheckBox(self.vother)
        self.vo_utake.setObjectName(_fromUtf8("vo_utake"))
        self.gridLayout_6.addWidget(self.vo_utake, 5, 0, 1, 1)
        self.vo_gtake = QtGui.QCheckBox(self.vother)
        self.vo_gtake.setObjectName(_fromUtf8("vo_gtake"))
        self.gridLayout_6.addWidget(self.vo_gtake, 6, 0, 1, 1)
        self.vo_ugive = QtGui.QCheckBox(self.vother)
        self.vo_ugive.setObjectName(_fromUtf8("vo_ugive"))
        self.gridLayout_6.addWidget(self.vo_ugive, 7, 0, 1, 1)
        self.vo_ggive = QtGui.QCheckBox(self.vother)
        self.vo_ggive.setObjectName(_fromUtf8("vo_ggive"))
        self.gridLayout_6.addWidget(self.vo_ggive, 8, 0, 1, 1)
        self.vo_del = QtGui.QCheckBox(self.vother)
        self.vo_del.setObjectName(_fromUtf8("vo_del"))
        self.gridLayout_6.addWidget(self.vo_del, 9, 0, 1, 1)
        self.hboxlayout.addLayout(self.gridLayout_6)
        self.permtab.addTab(self.vother, _fromUtf8(""))

        self.retranslateUi(userperms)
        self.permtab.setCurrentIndex(2)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("accepted()")), userperms.accept)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("rejected()")), userperms.reject)
        QtCore.QMetaObject.connectSlotsByName(userperms)
        userperms.setTabOrder(self.servname, self.username)
        userperms.setTabOrder(self.username, self.groupname)
        userperms.setTabOrder(self.groupname, self.minpri)
        userperms.setTabOrder(self.minpri, self.defpri)
        userperms.setTabOrder(self.defpri, self.maxpri)
        userperms.setTabOrder(self.maxpri, self.maxll)
        userperms.setTabOrder(self.maxll, self.totll)
        userperms.setTabOrder(self.totll, self.speccll)
        userperms.setTabOrder(self.speccll, self.radminperm)
        userperms.setTabOrder(self.radminperm, self.wadminperm)
        userperms.setTabOrder(self.wadminperm, self.createperm)
        userperms.setTabOrder(self.createperm, self.chpermperm)
        userperms.setTabOrder(self.chpermperm, self.spcreateperm)
        userperms.setTabOrder(self.spcreateperm, self.or_ug_perm)
        userperms.setTabOrder(self.or_ug_perm, self.or_uo_perm)
        userperms.setTabOrder(self.or_uo_perm, self.or_go_perm)
        userperms.setTabOrder(self.or_go_perm, self.sstopperm)
        userperms.setTabOrder(self.sstopperm, self.permtab)
        userperms.setTabOrder(self.permtab, self.ju_read)
        userperms.setTabOrder(self.ju_read, self.ju_write)
        userperms.setTabOrder(self.ju_write, self.ju_show)
        userperms.setTabOrder(self.ju_show, self.ju_rperm)
        userperms.setTabOrder(self.ju_rperm, self.ju_wperm)
        userperms.setTabOrder(self.ju_wperm, self.ju_utake)
        userperms.setTabOrder(self.ju_utake, self.ju_gtake)
        userperms.setTabOrder(self.ju_gtake, self.ju_ugive)
        userperms.setTabOrder(self.ju_ugive, self.ju_ggive)
        userperms.setTabOrder(self.ju_ggive, self.ju_del)
        userperms.setTabOrder(self.ju_del, self.ju_kill)
        userperms.setTabOrder(self.ju_kill, self.jg_read)
        userperms.setTabOrder(self.jg_read, self.jg_write)
        userperms.setTabOrder(self.jg_write, self.jg_show)
        userperms.setTabOrder(self.jg_show, self.jg_rperm)
        userperms.setTabOrder(self.jg_rperm, self.jg_wperm)
        userperms.setTabOrder(self.jg_wperm, self.jg_utake)
        userperms.setTabOrder(self.jg_utake, self.jg_gtake)
        userperms.setTabOrder(self.jg_gtake, self.jg_ugive)
        userperms.setTabOrder(self.jg_ugive, self.jg_ggive)
        userperms.setTabOrder(self.jg_ggive, self.jg_del)
        userperms.setTabOrder(self.jg_del, self.jg_kill)
        userperms.setTabOrder(self.jg_kill, self.jo_read)
        userperms.setTabOrder(self.jo_read, self.jo_write)
        userperms.setTabOrder(self.jo_write, self.jo_show)
        userperms.setTabOrder(self.jo_show, self.jo_rperm)
        userperms.setTabOrder(self.jo_rperm, self.jo_wperm)
        userperms.setTabOrder(self.jo_wperm, self.jo_utake)
        userperms.setTabOrder(self.jo_utake, self.jo_gtake)
        userperms.setTabOrder(self.jo_gtake, self.jo_ugive)
        userperms.setTabOrder(self.jo_ugive, self.jo_ggive)
        userperms.setTabOrder(self.jo_ggive, self.jo_del)
        userperms.setTabOrder(self.jo_del, self.jo_kill)
        userperms.setTabOrder(self.jo_kill, self.vu_read)
        userperms.setTabOrder(self.vu_read, self.vu_write)
        userperms.setTabOrder(self.vu_write, self.vu_show)
        userperms.setTabOrder(self.vu_show, self.vu_rperm)
        userperms.setTabOrder(self.vu_rperm, self.vu_wperm)
        userperms.setTabOrder(self.vu_wperm, self.vu_utake)
        userperms.setTabOrder(self.vu_utake, self.vu_gtake)
        userperms.setTabOrder(self.vu_gtake, self.vu_ugive)
        userperms.setTabOrder(self.vu_ugive, self.vu_ggive)
        userperms.setTabOrder(self.vu_ggive, self.vu_del)
        userperms.setTabOrder(self.vu_del, self.vg_read)
        userperms.setTabOrder(self.vg_read, self.vg_write)
        userperms.setTabOrder(self.vg_write, self.vg_show)
        userperms.setTabOrder(self.vg_show, self.vg_rperm)
        userperms.setTabOrder(self.vg_rperm, self.vg_wperm)
        userperms.setTabOrder(self.vg_wperm, self.vg_utake)
        userperms.setTabOrder(self.vg_utake, self.vg_gtake)
        userperms.setTabOrder(self.vg_gtake, self.vg_ugive)
        userperms.setTabOrder(self.vg_ugive, self.vg_ggive)
        userperms.setTabOrder(self.vg_ggive, self.vg_del)
        userperms.setTabOrder(self.vg_del, self.vo_read)
        userperms.setTabOrder(self.vo_read, self.vo_write)
        userperms.setTabOrder(self.vo_write, self.vo_show)
        userperms.setTabOrder(self.vo_show, self.vo_rperm)
        userperms.setTabOrder(self.vo_rperm, self.vo_wperm)
        userperms.setTabOrder(self.vo_wperm, self.vo_utake)
        userperms.setTabOrder(self.vo_utake, self.vo_gtake)
        userperms.setTabOrder(self.vo_gtake, self.vo_ugive)
        userperms.setTabOrder(self.vo_ugive, self.vo_ggive)
        userperms.setTabOrder(self.vo_ggive, self.vo_del)
        userperms.setTabOrder(self.vo_del, self.buttonBox)

    def retranslateUi(self, userperms):
        userperms.setWindowTitle(QtGui.QApplication.translate("userperms", "User permissions", None, QtGui.QApplication.UnicodeUTF8))
        self.label.setText(QtGui.QApplication.translate("userperms", "User permissions on server", None, QtGui.QApplication.UnicodeUTF8))
        self.servname.setToolTip(QtGui.QApplication.translate("userperms", "This is the server to which the permissions apply", None, QtGui.QApplication.UnicodeUTF8))
        self.label_2.setText(QtGui.QApplication.translate("userperms", "User Name", None, QtGui.QApplication.UnicodeUTF8))
        self.username.setToolTip(QtGui.QApplication.translate("userperms", "This is the user name on the server", None, QtGui.QApplication.UnicodeUTF8))
        self.radminperm.setToolTip(QtGui.QApplication.translate("userperms", "User can read admin file", None, QtGui.QApplication.UnicodeUTF8))
        self.radminperm.setText(QtGui.QApplication.translate("userperms", "Read admin file", None, QtGui.QApplication.UnicodeUTF8))
        self.wadminperm.setToolTip(QtGui.QApplication.translate("userperms", "User can edit admin file of permissions", None, QtGui.QApplication.UnicodeUTF8))
        self.wadminperm.setText(QtGui.QApplication.translate("userperms", "Write admin file", None, QtGui.QApplication.UnicodeUTF8))
        self.createperm.setToolTip(QtGui.QApplication.translate("userperms", "User can create objects (jobs and variables)", None, QtGui.QApplication.UnicodeUTF8))
        self.createperm.setText(QtGui.QApplication.translate("userperms", "Create things", None, QtGui.QApplication.UnicodeUTF8))
        self.chpermperm.setToolTip(QtGui.QApplication.translate("userperms", "User can adjust default priority and permissions", None, QtGui.QApplication.UnicodeUTF8))
        self.chpermperm.setText(QtGui.QApplication.translate("userperms", "Change default prio/perms", None, QtGui.QApplication.UnicodeUTF8))
        self.spcreateperm.setToolTip(QtGui.QApplication.translate("userperms", "User can create command interpreters", None, QtGui.QApplication.UnicodeUTF8))
        self.spcreateperm.setText(QtGui.QApplication.translate("userperms", "Special Create", None, QtGui.QApplication.UnicodeUTF8))
        self.or_ug_perm.setToolTip(QtGui.QApplication.translate("userperms", "Combine user and group permissions", None, QtGui.QApplication.UnicodeUTF8))
        self.or_ug_perm.setText(QtGui.QApplication.translate("userperms", "OR User/Group perms", None, QtGui.QApplication.UnicodeUTF8))
        self.or_uo_perm.setToolTip(QtGui.QApplication.translate("userperms", "Combine user and other permissions", None, QtGui.QApplication.UnicodeUTF8))
        self.or_uo_perm.setText(QtGui.QApplication.translate("userperms", "OR User/Other perms", None, QtGui.QApplication.UnicodeUTF8))
        self.or_go_perm.setToolTip(QtGui.QApplication.translate("userperms", "Combine group and other permissions", None, QtGui.QApplication.UnicodeUTF8))
        self.or_go_perm.setText(QtGui.QApplication.translate("userperms", "OR Group/Other perms", None, QtGui.QApplication.UnicodeUTF8))
        self.sstopperm.setToolTip(QtGui.QApplication.translate("userperms", "User can stop the scheduler", None, QtGui.QApplication.UnicodeUTF8))
        self.sstopperm.setText(QtGui.QApplication.translate("userperms", "Stop Scheduler", None, QtGui.QApplication.UnicodeUTF8))
        self.label_3.setText(QtGui.QApplication.translate("userperms", "Min Pri", None, QtGui.QApplication.UnicodeUTF8))
        self.label_4.setText(QtGui.QApplication.translate("userperms", "Def Pri", None, QtGui.QApplication.UnicodeUTF8))
        self.label_5.setText(QtGui.QApplication.translate("userperms", "Max Pri", None, QtGui.QApplication.UnicodeUTF8))
        self.minpri.setToolTip(QtGui.QApplication.translate("userperms", "This is the minimum allowed priority", None, QtGui.QApplication.UnicodeUTF8))
        self.defpri.setToolTip(QtGui.QApplication.translate("userperms", "This is the default priority", None, QtGui.QApplication.UnicodeUTF8))
        self.maxpri.setToolTip(QtGui.QApplication.translate("userperms", "This is the maximum priority", None, QtGui.QApplication.UnicodeUTF8))
        self.label_6.setText(QtGui.QApplication.translate("userperms", "Group Name", None, QtGui.QApplication.UnicodeUTF8))
        self.groupname.setToolTip(QtGui.QApplication.translate("userperms", "This is the group name on the server", None, QtGui.QApplication.UnicodeUTF8))
        self.label_7.setText(QtGui.QApplication.translate("userperms", "Spec C LL", None, QtGui.QApplication.UnicodeUTF8))
        self.label_8.setText(QtGui.QApplication.translate("userperms", "Tot LL", None, QtGui.QApplication.UnicodeUTF8))
        self.maxll.setToolTip(QtGui.QApplication.translate("userperms", "This is the maximum load level for any one job", None, QtGui.QApplication.UnicodeUTF8))
        self.label_9.setText(QtGui.QApplication.translate("userperms", "Max LL", None, QtGui.QApplication.UnicodeUTF8))
        self.speccll.setToolTip(QtGui.QApplication.translate("userperms", "This is the special create load level (if creating command interpreters)", None, QtGui.QApplication.UnicodeUTF8))
        self.label_10.setText(QtGui.QApplication.translate("userperms", "Default permissions", None, QtGui.QApplication.UnicodeUTF8))
        self.ju_read.setToolTip(QtGui.QApplication.translate("userperms", "User can read details of jobs", None, QtGui.QApplication.UnicodeUTF8))
        self.ju_read.setText(QtGui.QApplication.translate("userperms", "Read Job", None, QtGui.QApplication.UnicodeUTF8))
        self.ju_write.setToolTip(QtGui.QApplication.translate("userperms", "User can update details of jobs", None, QtGui.QApplication.UnicodeUTF8))
        self.ju_write.setText(QtGui.QApplication.translate("userperms", "Write job", None, QtGui.QApplication.UnicodeUTF8))
        self.ju_show.setToolTip(QtGui.QApplication.translate("userperms", "User can see job exists", None, QtGui.QApplication.UnicodeUTF8))
        self.ju_show.setText(QtGui.QApplication.translate("userperms", "Reveal job", None, QtGui.QApplication.UnicodeUTF8))
        self.ju_rperm.setToolTip(QtGui.QApplication.translate("userperms", "User can read job permissions", None, QtGui.QApplication.UnicodeUTF8))
        self.ju_rperm.setText(QtGui.QApplication.translate("userperms", "Read perms job", None, QtGui.QApplication.UnicodeUTF8))
        self.ju_wperm.setToolTip(QtGui.QApplication.translate("userperms", "User can update job permissions", None, QtGui.QApplication.UnicodeUTF8))
        self.ju_wperm.setText(QtGui.QApplication.translate("userperms", "Write perms job", None, QtGui.QApplication.UnicodeUTF8))
        self.ju_utake.setToolTip(QtGui.QApplication.translate("userperms", "User can acquire job", None, QtGui.QApplication.UnicodeUTF8))
        self.ju_utake.setText(QtGui.QApplication.translate("userperms", "Acquire ownership job", None, QtGui.QApplication.UnicodeUTF8))
        self.ju_gtake.setToolTip(QtGui.QApplication.translate("userperms", "User can acquire job for group owner", None, QtGui.QApplication.UnicodeUTF8))
        self.ju_gtake.setText(QtGui.QApplication.translate("userperms", "Acquire group ownership job", None, QtGui.QApplication.UnicodeUTF8))
        self.ju_ugive.setToolTip(QtGui.QApplication.translate("userperms", "User can give away job", None, QtGui.QApplication.UnicodeUTF8))
        self.ju_ugive.setText(QtGui.QApplication.translate("userperms", "Give away owner job", None, QtGui.QApplication.UnicodeUTF8))
        self.ju_del.setToolTip(QtGui.QApplication.translate("userperms", "User can delete job", None, QtGui.QApplication.UnicodeUTF8))
        self.ju_del.setText(QtGui.QApplication.translate("userperms", "Delete job", None, QtGui.QApplication.UnicodeUTF8))
        self.ju_kill.setToolTip(QtGui.QApplication.translate("userperms", "User can kill job", None, QtGui.QApplication.UnicodeUTF8))
        self.ju_kill.setText(QtGui.QApplication.translate("userperms", "Kill job", None, QtGui.QApplication.UnicodeUTF8))
        self.ju_ggive.setToolTip(QtGui.QApplication.translate("userperms", "User can give away group ownership", None, QtGui.QApplication.UnicodeUTF8))
        self.ju_ggive.setText(QtGui.QApplication.translate("userperms", "Give away group owner job", None, QtGui.QApplication.UnicodeUTF8))
        self.permtab.setTabText(self.permtab.indexOf(self.juser), QtGui.QApplication.translate("userperms", "Job-user", None, QtGui.QApplication.UnicodeUTF8))
        self.jg_read.setToolTip(QtGui.QApplication.translate("userperms", "Group can read details of jobs", None, QtGui.QApplication.UnicodeUTF8))
        self.jg_read.setText(QtGui.QApplication.translate("userperms", "Read Job", None, QtGui.QApplication.UnicodeUTF8))
        self.jg_write.setToolTip(QtGui.QApplication.translate("userperms", "Group can update details of jobs", None, QtGui.QApplication.UnicodeUTF8))
        self.jg_write.setText(QtGui.QApplication.translate("userperms", "Write job", None, QtGui.QApplication.UnicodeUTF8))
        self.jg_show.setToolTip(QtGui.QApplication.translate("userperms", "Group can see job exists", None, QtGui.QApplication.UnicodeUTF8))
        self.jg_show.setText(QtGui.QApplication.translate("userperms", "Reveal job", None, QtGui.QApplication.UnicodeUTF8))
        self.jg_rperm.setToolTip(QtGui.QApplication.translate("userperms", "Group can read job permissions", None, QtGui.QApplication.UnicodeUTF8))
        self.jg_rperm.setText(QtGui.QApplication.translate("userperms", "Read perms job", None, QtGui.QApplication.UnicodeUTF8))
        self.jg_wperm.setToolTip(QtGui.QApplication.translate("userperms", "Group can update job permissions", None, QtGui.QApplication.UnicodeUTF8))
        self.jg_wperm.setText(QtGui.QApplication.translate("userperms", "Write perms job", None, QtGui.QApplication.UnicodeUTF8))
        self.jg_utake.setToolTip(QtGui.QApplication.translate("userperms", "Group can acquire job for user", None, QtGui.QApplication.UnicodeUTF8))
        self.jg_utake.setText(QtGui.QApplication.translate("userperms", "Acquire ownership job", None, QtGui.QApplication.UnicodeUTF8))
        self.jg_gtake.setToolTip(QtGui.QApplication.translate("userperms", "Group can acquire job for group owner", None, QtGui.QApplication.UnicodeUTF8))
        self.jg_gtake.setText(QtGui.QApplication.translate("userperms", "Acquire group ownership job", None, QtGui.QApplication.UnicodeUTF8))
        self.jg_ugive.setToolTip(QtGui.QApplication.translate("userperms", "Group can give away job owner", None, QtGui.QApplication.UnicodeUTF8))
        self.jg_ugive.setText(QtGui.QApplication.translate("userperms", "Give away owner job", None, QtGui.QApplication.UnicodeUTF8))
        self.jg_del.setToolTip(QtGui.QApplication.translate("userperms", "Group can delete job", None, QtGui.QApplication.UnicodeUTF8))
        self.jg_del.setText(QtGui.QApplication.translate("userperms", "Delete job", None, QtGui.QApplication.UnicodeUTF8))
        self.jg_kill.setToolTip(QtGui.QApplication.translate("userperms", "Group can kill job", None, QtGui.QApplication.UnicodeUTF8))
        self.jg_kill.setText(QtGui.QApplication.translate("userperms", "Kill job", None, QtGui.QApplication.UnicodeUTF8))
        self.jg_ggive.setToolTip(QtGui.QApplication.translate("userperms", "Group can give away group ownership", None, QtGui.QApplication.UnicodeUTF8))
        self.jg_ggive.setText(QtGui.QApplication.translate("userperms", "Give away group owner job", None, QtGui.QApplication.UnicodeUTF8))
        self.permtab.setTabText(self.permtab.indexOf(self.jgroup), QtGui.QApplication.translate("userperms", "Job-group", None, QtGui.QApplication.UnicodeUTF8))
        self.jo_read.setToolTip(QtGui.QApplication.translate("userperms", "Others can read details of jobs", None, QtGui.QApplication.UnicodeUTF8))
        self.jo_read.setText(QtGui.QApplication.translate("userperms", "Read Job", None, QtGui.QApplication.UnicodeUTF8))
        self.jo_write.setToolTip(QtGui.QApplication.translate("userperms", "Others can update details of jobs", None, QtGui.QApplication.UnicodeUTF8))
        self.jo_write.setText(QtGui.QApplication.translate("userperms", "Write job", None, QtGui.QApplication.UnicodeUTF8))
        self.jo_show.setToolTip(QtGui.QApplication.translate("userperms", "Others can see job exists", None, QtGui.QApplication.UnicodeUTF8))
        self.jo_show.setText(QtGui.QApplication.translate("userperms", "Reveal job", None, QtGui.QApplication.UnicodeUTF8))
        self.jo_rperm.setToolTip(QtGui.QApplication.translate("userperms", "Others can read job permissions", None, QtGui.QApplication.UnicodeUTF8))
        self.jo_rperm.setText(QtGui.QApplication.translate("userperms", "Read perms job", None, QtGui.QApplication.UnicodeUTF8))
        self.jo_wperm.setToolTip(QtGui.QApplication.translate("userperms", "Others can update job permissions", None, QtGui.QApplication.UnicodeUTF8))
        self.jo_wperm.setText(QtGui.QApplication.translate("userperms", "Write perms job", None, QtGui.QApplication.UnicodeUTF8))
        self.jo_utake.setToolTip(QtGui.QApplication.translate("userperms", "Others can acquire job for owner", None, QtGui.QApplication.UnicodeUTF8))
        self.jo_utake.setText(QtGui.QApplication.translate("userperms", "Acquire ownership job", None, QtGui.QApplication.UnicodeUTF8))
        self.jo_gtake.setToolTip(QtGui.QApplication.translate("userperms", "Others can acquire job for group owner", None, QtGui.QApplication.UnicodeUTF8))
        self.jo_gtake.setText(QtGui.QApplication.translate("userperms", "Acquire group ownership job", None, QtGui.QApplication.UnicodeUTF8))
        self.jo_ugive.setToolTip(QtGui.QApplication.translate("userperms", "Others can give away job", None, QtGui.QApplication.UnicodeUTF8))
        self.jo_ugive.setText(QtGui.QApplication.translate("userperms", "Give away owner job", None, QtGui.QApplication.UnicodeUTF8))
        self.jo_del.setToolTip(QtGui.QApplication.translate("userperms", "Others can delete job", None, QtGui.QApplication.UnicodeUTF8))
        self.jo_del.setText(QtGui.QApplication.translate("userperms", "Delete job", None, QtGui.QApplication.UnicodeUTF8))
        self.jo_kill.setToolTip(QtGui.QApplication.translate("userperms", "Others can kill job", None, QtGui.QApplication.UnicodeUTF8))
        self.jo_kill.setText(QtGui.QApplication.translate("userperms", "Kill job", None, QtGui.QApplication.UnicodeUTF8))
        self.jo_ggive.setToolTip(QtGui.QApplication.translate("userperms", "Others can give away group ownership", None, QtGui.QApplication.UnicodeUTF8))
        self.jo_ggive.setText(QtGui.QApplication.translate("userperms", "Give away group owner job", None, QtGui.QApplication.UnicodeUTF8))
        self.permtab.setTabText(self.permtab.indexOf(self.jother), QtGui.QApplication.translate("userperms", "Job-other", None, QtGui.QApplication.UnicodeUTF8))
        self.vu_read.setToolTip(QtGui.QApplication.translate("userperms", "User can read details of variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vu_read.setText(QtGui.QApplication.translate("userperms", "Read variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vu_write.setToolTip(QtGui.QApplication.translate("userperms", "User can update details of variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vu_write.setText(QtGui.QApplication.translate("userperms", "Write variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vu_show.setToolTip(QtGui.QApplication.translate("userperms", "User can see variable exists", None, QtGui.QApplication.UnicodeUTF8))
        self.vu_show.setText(QtGui.QApplication.translate("userperms", "Reveal variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vu_rperm.setToolTip(QtGui.QApplication.translate("userperms", "User can read variable permissions", None, QtGui.QApplication.UnicodeUTF8))
        self.vu_rperm.setText(QtGui.QApplication.translate("userperms", "Read perms variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vu_wperm.setToolTip(QtGui.QApplication.translate("userperms", "User can update variable permissions", None, QtGui.QApplication.UnicodeUTF8))
        self.vu_wperm.setText(QtGui.QApplication.translate("userperms", "Write perms variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vu_utake.setToolTip(QtGui.QApplication.translate("userperms", "User can acquire variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vu_utake.setText(QtGui.QApplication.translate("userperms", "Acquire ownership variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vu_gtake.setToolTip(QtGui.QApplication.translate("userperms", "User can acquire variable for group owner", None, QtGui.QApplication.UnicodeUTF8))
        self.vu_gtake.setText(QtGui.QApplication.translate("userperms", "Acquire group ownership variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vu_ugive.setToolTip(QtGui.QApplication.translate("userperms", "User can give away variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vu_ugive.setText(QtGui.QApplication.translate("userperms", "Give away owner variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vu_del.setToolTip(QtGui.QApplication.translate("userperms", "User can delete variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vu_del.setText(QtGui.QApplication.translate("userperms", "Delete variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vu_ggive.setToolTip(QtGui.QApplication.translate("userperms", "User can give away group ownership", None, QtGui.QApplication.UnicodeUTF8))
        self.vu_ggive.setText(QtGui.QApplication.translate("userperms", "Give away group owner variable", None, QtGui.QApplication.UnicodeUTF8))
        self.permtab.setTabText(self.permtab.indexOf(self.vuser), QtGui.QApplication.translate("userperms", "Var-user", None, QtGui.QApplication.UnicodeUTF8))
        self.vg_read.setToolTip(QtGui.QApplication.translate("userperms", "Group can read details of variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vg_read.setText(QtGui.QApplication.translate("userperms", "Read variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vg_write.setToolTip(QtGui.QApplication.translate("userperms", "Group can update details of variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vg_write.setText(QtGui.QApplication.translate("userperms", "Write variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vg_show.setToolTip(QtGui.QApplication.translate("userperms", "Group can see variable exists", None, QtGui.QApplication.UnicodeUTF8))
        self.vg_show.setText(QtGui.QApplication.translate("userperms", "Reveal variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vg_rperm.setToolTip(QtGui.QApplication.translate("userperms", "Group can read variable permissions", None, QtGui.QApplication.UnicodeUTF8))
        self.vg_rperm.setText(QtGui.QApplication.translate("userperms", "Read perms variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vg_wperm.setToolTip(QtGui.QApplication.translate("userperms", "Group can update variable permissions", None, QtGui.QApplication.UnicodeUTF8))
        self.vg_wperm.setText(QtGui.QApplication.translate("userperms", "Write perms variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vg_utake.setToolTip(QtGui.QApplication.translate("userperms", "Group can acquire variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vg_utake.setText(QtGui.QApplication.translate("userperms", "Acquire ownership variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vg_gtake.setToolTip(QtGui.QApplication.translate("userperms", "Group can acquire variable for group owner", None, QtGui.QApplication.UnicodeUTF8))
        self.vg_gtake.setText(QtGui.QApplication.translate("userperms", "Acquire group ownership variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vg_ugive.setToolTip(QtGui.QApplication.translate("userperms", "Group can give away variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vg_ugive.setText(QtGui.QApplication.translate("userperms", "Give away owner variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vg_ggive.setToolTip(QtGui.QApplication.translate("userperms", "Group can give away group ownership", None, QtGui.QApplication.UnicodeUTF8))
        self.vg_ggive.setText(QtGui.QApplication.translate("userperms", "Give away group owner variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vg_del.setToolTip(QtGui.QApplication.translate("userperms", "Group can delete variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vg_del.setText(QtGui.QApplication.translate("userperms", "Delete variable", None, QtGui.QApplication.UnicodeUTF8))
        self.permtab.setTabText(self.permtab.indexOf(self.vgroup), QtGui.QApplication.translate("userperms", "Var-group", None, QtGui.QApplication.UnicodeUTF8))
        self.vo_read.setToolTip(QtGui.QApplication.translate("userperms", "Others can read details of variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vo_read.setText(QtGui.QApplication.translate("userperms", "Read variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vo_write.setToolTip(QtGui.QApplication.translate("userperms", "Others can update details of variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vo_write.setText(QtGui.QApplication.translate("userperms", "Write variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vo_show.setToolTip(QtGui.QApplication.translate("userperms", "Others can see variable exists", None, QtGui.QApplication.UnicodeUTF8))
        self.vo_show.setText(QtGui.QApplication.translate("userperms", "Reveal variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vo_rperm.setToolTip(QtGui.QApplication.translate("userperms", "Others can read variable permissions", None, QtGui.QApplication.UnicodeUTF8))
        self.vo_rperm.setText(QtGui.QApplication.translate("userperms", "Read perms variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vo_wperm.setToolTip(QtGui.QApplication.translate("userperms", "Others can update variable permissions", None, QtGui.QApplication.UnicodeUTF8))
        self.vo_wperm.setText(QtGui.QApplication.translate("userperms", "Write perms variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vo_utake.setToolTip(QtGui.QApplication.translate("userperms", "Others can acquire variable for user", None, QtGui.QApplication.UnicodeUTF8))
        self.vo_utake.setText(QtGui.QApplication.translate("userperms", "Acquire ownership variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vo_gtake.setToolTip(QtGui.QApplication.translate("userperms", "Others can acquire variable for group owner", None, QtGui.QApplication.UnicodeUTF8))
        self.vo_gtake.setText(QtGui.QApplication.translate("userperms", "Acquire group ownership variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vo_ugive.setToolTip(QtGui.QApplication.translate("userperms", "Others can give away variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vo_ugive.setText(QtGui.QApplication.translate("userperms", "Give away owner variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vo_ggive.setToolTip(QtGui.QApplication.translate("userperms", "Others can give away group ownership", None, QtGui.QApplication.UnicodeUTF8))
        self.vo_ggive.setText(QtGui.QApplication.translate("userperms", "Give away group owner variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vo_del.setToolTip(QtGui.QApplication.translate("userperms", "Others can delete variable", None, QtGui.QApplication.UnicodeUTF8))
        self.vo_del.setText(QtGui.QApplication.translate("userperms", "Delete variable", None, QtGui.QApplication.UnicodeUTF8))
        self.permtab.setTabText(self.permtab.indexOf(self.vother), QtGui.QApplication.translate("userperms", "Var-other", None, QtGui.QApplication.UnicodeUTF8))

