# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'jassdlg.ui'
#
# Created: Fri Nov 23 23:14:34 2012
#      by: PyQt4 UI code generator 4.9.1
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    _fromUtf8 = lambda s: s

class Ui_jassdlg(object):
    def setupUi(self, jassdlg):
        jassdlg.setObjectName(_fromUtf8("jassdlg"))
        jassdlg.resize(1069, 458)
        self.buttonBox = QtGui.QDialogButtonBox(jassdlg)
        self.buttonBox.setGeometry(QtCore.QRect(840, 420, 191, 32))
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtGui.QDialogButtonBox.Cancel|QtGui.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName(_fromUtf8("buttonBox"))
        self.label = QtGui.QLabel(jassdlg)
        self.label.setGeometry(QtCore.QRect(40, 30, 141, 17))
        self.label.setObjectName(_fromUtf8("label"))
        self.edjob = QtGui.QLabel(jassdlg)
        self.edjob.setGeometry(QtCore.QRect(180, 30, 331, 17))
        self.edjob.setText(_fromUtf8(""))
        self.edjob.setObjectName(_fromUtf8("edjob"))
        self.label_2 = QtGui.QLabel(jassdlg)
        self.label_2.setGeometry(QtCore.QRect(50, 60, 66, 17))
        self.label_2.setObjectName(_fromUtf8("label_2"))
        self.label_3 = QtGui.QLabel(jassdlg)
        self.label_3.setGeometry(QtCore.QRect(170, 60, 41, 17))
        self.label_3.setObjectName(_fromUtf8("label_3"))
        self.label_4 = QtGui.QLabel(jassdlg)
        self.label_4.setGeometry(QtCore.QRect(340, 60, 81, 17))
        self.label_4.setObjectName(_fromUtf8("label_4"))
        self.label_5 = QtGui.QLabel(jassdlg)
        self.label_5.setGeometry(QtCore.QRect(640, 60, 71, 17))
        self.label_5.setObjectName(_fromUtf8("label_5"))
        self.label_6 = QtGui.QLabel(jassdlg)
        self.label_6.setGeometry(QtCore.QRect(900, 60, 51, 17))
        self.label_6.setObjectName(_fromUtf8("label_6"))
        self.widget = QtGui.QWidget(jassdlg)
        self.widget.setGeometry(QtCore.QRect(30, 90, 1001, 301))
        self.widget.setObjectName(_fromUtf8("widget"))
        self.gridLayout = QtGui.QGridLayout(self.widget)
        self.gridLayout.setMargin(0)
        self.gridLayout.setObjectName(_fromUtf8("gridLayout"))
        self.assvar0 = QtGui.QComboBox(self.widget)
        self.assvar0.setObjectName(_fromUtf8("assvar0"))
        self.assvar0.addItem(_fromUtf8(""))
        self.gridLayout.addWidget(self.assvar0, 0, 0, 1, 1)
        self.assop0 = QtGui.QComboBox(self.widget)
        self.assop0.setObjectName(_fromUtf8("assop0"))
        self.assop0.addItem(_fromUtf8(""))
        self.assop0.addItem(_fromUtf8(""))
        self.assop0.addItem(_fromUtf8(""))
        self.assop0.addItem(_fromUtf8(""))
        self.assop0.addItem(_fromUtf8(""))
        self.assop0.addItem(_fromUtf8(""))
        self.assop0.addItem(_fromUtf8(""))
        self.assop0.addItem(_fromUtf8(""))
        self.assop0.addItem(_fromUtf8(""))
        self.gridLayout.addWidget(self.assop0, 0, 1, 1, 1)
        self.FS0 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FS0.setFont(font)
        self.FS0.setObjectName(_fromUtf8("FS0"))
        self.gridLayout.addWidget(self.FS0, 0, 2, 1, 1)
        self.FN0 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FN0.setFont(font)
        self.FN0.setObjectName(_fromUtf8("FN0"))
        self.gridLayout.addWidget(self.FN0, 0, 3, 1, 1)
        self.FE0 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FE0.setFont(font)
        self.FE0.setObjectName(_fromUtf8("FE0"))
        self.gridLayout.addWidget(self.FE0, 0, 4, 1, 1)
        self.FA0 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FA0.setFont(font)
        self.FA0.setObjectName(_fromUtf8("FA0"))
        self.gridLayout.addWidget(self.FA0, 0, 5, 1, 1)
        self.FC0 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FC0.setFont(font)
        self.FC0.setObjectName(_fromUtf8("FC0"))
        self.gridLayout.addWidget(self.FC0, 0, 6, 1, 1)
        self.FR0 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FR0.setFont(font)
        self.FR0.setObjectName(_fromUtf8("FR0"))
        self.gridLayout.addWidget(self.FR0, 0, 7, 1, 1)
        self.textval0 = QtGui.QLineEdit(self.widget)
        self.textval0.setEnabled(False)
        font = QtGui.QFont()
        font.setFamily(_fromUtf8("Courier New"))
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.textval0.setFont(font)
        self.textval0.setMaxLength(49)
        self.textval0.setObjectName(_fromUtf8("textval0"))
        self.gridLayout.addWidget(self.textval0, 0, 8, 1, 1)
        self.asstext0 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(11)
        self.asstext0.setFont(font)
        self.asstext0.setObjectName(_fromUtf8("asstext0"))
        self.gridLayout.addWidget(self.asstext0, 0, 9, 1, 1)
        self.intval0 = QtGui.QSpinBox(self.widget)
        self.intval0.setMinimum(-1000000)
        self.intval0.setMaximum(1000000)
        self.intval0.setProperty("value", 0)
        self.intval0.setObjectName(_fromUtf8("intval0"))
        self.gridLayout.addWidget(self.intval0, 0, 10, 1, 1)
        self.ac0 = QtGui.QCheckBox(self.widget)
        self.ac0.setObjectName(_fromUtf8("ac0"))
        self.gridLayout.addWidget(self.ac0, 0, 11, 1, 1)
        self.assvar1 = QtGui.QComboBox(self.widget)
        self.assvar1.setObjectName(_fromUtf8("assvar1"))
        self.assvar1.addItem(_fromUtf8(""))
        self.gridLayout.addWidget(self.assvar1, 1, 0, 1, 1)
        self.assop1 = QtGui.QComboBox(self.widget)
        self.assop1.setObjectName(_fromUtf8("assop1"))
        self.assop1.addItem(_fromUtf8(""))
        self.assop1.addItem(_fromUtf8(""))
        self.assop1.addItem(_fromUtf8(""))
        self.assop1.addItem(_fromUtf8(""))
        self.assop1.addItem(_fromUtf8(""))
        self.assop1.addItem(_fromUtf8(""))
        self.assop1.addItem(_fromUtf8(""))
        self.assop1.addItem(_fromUtf8(""))
        self.assop1.addItem(_fromUtf8(""))
        self.gridLayout.addWidget(self.assop1, 1, 1, 1, 1)
        self.FS1 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FS1.setFont(font)
        self.FS1.setObjectName(_fromUtf8("FS1"))
        self.gridLayout.addWidget(self.FS1, 1, 2, 1, 1)
        self.FN1 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FN1.setFont(font)
        self.FN1.setObjectName(_fromUtf8("FN1"))
        self.gridLayout.addWidget(self.FN1, 1, 3, 1, 1)
        self.FE1 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FE1.setFont(font)
        self.FE1.setObjectName(_fromUtf8("FE1"))
        self.gridLayout.addWidget(self.FE1, 1, 4, 1, 1)
        self.FA1 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FA1.setFont(font)
        self.FA1.setObjectName(_fromUtf8("FA1"))
        self.gridLayout.addWidget(self.FA1, 1, 5, 1, 1)
        self.FC1 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FC1.setFont(font)
        self.FC1.setObjectName(_fromUtf8("FC1"))
        self.gridLayout.addWidget(self.FC1, 1, 6, 1, 1)
        self.FR1 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FR1.setFont(font)
        self.FR1.setObjectName(_fromUtf8("FR1"))
        self.gridLayout.addWidget(self.FR1, 1, 7, 1, 1)
        self.textval1 = QtGui.QLineEdit(self.widget)
        self.textval1.setEnabled(False)
        font = QtGui.QFont()
        font.setFamily(_fromUtf8("Courier New"))
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.textval1.setFont(font)
        self.textval1.setMaxLength(49)
        self.textval1.setObjectName(_fromUtf8("textval1"))
        self.gridLayout.addWidget(self.textval1, 1, 8, 1, 1)
        self.asstext1 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(11)
        self.asstext1.setFont(font)
        self.asstext1.setObjectName(_fromUtf8("asstext1"))
        self.gridLayout.addWidget(self.asstext1, 1, 9, 1, 1)
        self.intval1 = QtGui.QSpinBox(self.widget)
        self.intval1.setMinimum(-1000000)
        self.intval1.setMaximum(1000000)
        self.intval1.setProperty("value", 0)
        self.intval1.setObjectName(_fromUtf8("intval1"))
        self.gridLayout.addWidget(self.intval1, 1, 10, 1, 1)
        self.ac1 = QtGui.QCheckBox(self.widget)
        self.ac1.setObjectName(_fromUtf8("ac1"))
        self.gridLayout.addWidget(self.ac1, 1, 11, 1, 1)
        self.assvar2 = QtGui.QComboBox(self.widget)
        self.assvar2.setObjectName(_fromUtf8("assvar2"))
        self.assvar2.addItem(_fromUtf8(""))
        self.gridLayout.addWidget(self.assvar2, 2, 0, 1, 1)
        self.assop2 = QtGui.QComboBox(self.widget)
        self.assop2.setObjectName(_fromUtf8("assop2"))
        self.assop2.addItem(_fromUtf8(""))
        self.assop2.addItem(_fromUtf8(""))
        self.assop2.addItem(_fromUtf8(""))
        self.assop2.addItem(_fromUtf8(""))
        self.assop2.addItem(_fromUtf8(""))
        self.assop2.addItem(_fromUtf8(""))
        self.assop2.addItem(_fromUtf8(""))
        self.assop2.addItem(_fromUtf8(""))
        self.assop2.addItem(_fromUtf8(""))
        self.gridLayout.addWidget(self.assop2, 2, 1, 1, 1)
        self.FS2 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FS2.setFont(font)
        self.FS2.setObjectName(_fromUtf8("FS2"))
        self.gridLayout.addWidget(self.FS2, 2, 2, 1, 1)
        self.FN2 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FN2.setFont(font)
        self.FN2.setObjectName(_fromUtf8("FN2"))
        self.gridLayout.addWidget(self.FN2, 2, 3, 1, 1)
        self.FE2 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FE2.setFont(font)
        self.FE2.setObjectName(_fromUtf8("FE2"))
        self.gridLayout.addWidget(self.FE2, 2, 4, 1, 1)
        self.FA2 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FA2.setFont(font)
        self.FA2.setObjectName(_fromUtf8("FA2"))
        self.gridLayout.addWidget(self.FA2, 2, 5, 1, 1)
        self.FC2 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FC2.setFont(font)
        self.FC2.setObjectName(_fromUtf8("FC2"))
        self.gridLayout.addWidget(self.FC2, 2, 6, 1, 1)
        self.FR2 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FR2.setFont(font)
        self.FR2.setObjectName(_fromUtf8("FR2"))
        self.gridLayout.addWidget(self.FR2, 2, 7, 1, 1)
        self.textval2 = QtGui.QLineEdit(self.widget)
        self.textval2.setEnabled(False)
        font = QtGui.QFont()
        font.setFamily(_fromUtf8("Courier New"))
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.textval2.setFont(font)
        self.textval2.setMaxLength(49)
        self.textval2.setObjectName(_fromUtf8("textval2"))
        self.gridLayout.addWidget(self.textval2, 2, 8, 1, 1)
        self.asstext2 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(11)
        self.asstext2.setFont(font)
        self.asstext2.setObjectName(_fromUtf8("asstext2"))
        self.gridLayout.addWidget(self.asstext2, 2, 9, 1, 1)
        self.intval2 = QtGui.QSpinBox(self.widget)
        self.intval2.setMinimum(-1000000)
        self.intval2.setMaximum(1000000)
        self.intval2.setProperty("value", 0)
        self.intval2.setObjectName(_fromUtf8("intval2"))
        self.gridLayout.addWidget(self.intval2, 2, 10, 1, 1)
        self.ac2 = QtGui.QCheckBox(self.widget)
        self.ac2.setObjectName(_fromUtf8("ac2"))
        self.gridLayout.addWidget(self.ac2, 2, 11, 1, 1)
        self.assvar3 = QtGui.QComboBox(self.widget)
        self.assvar3.setObjectName(_fromUtf8("assvar3"))
        self.assvar3.addItem(_fromUtf8(""))
        self.gridLayout.addWidget(self.assvar3, 3, 0, 1, 1)
        self.assop3 = QtGui.QComboBox(self.widget)
        self.assop3.setObjectName(_fromUtf8("assop3"))
        self.assop3.addItem(_fromUtf8(""))
        self.assop3.addItem(_fromUtf8(""))
        self.assop3.addItem(_fromUtf8(""))
        self.assop3.addItem(_fromUtf8(""))
        self.assop3.addItem(_fromUtf8(""))
        self.assop3.addItem(_fromUtf8(""))
        self.assop3.addItem(_fromUtf8(""))
        self.assop3.addItem(_fromUtf8(""))
        self.assop3.addItem(_fromUtf8(""))
        self.gridLayout.addWidget(self.assop3, 3, 1, 1, 1)
        self.FS3 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FS3.setFont(font)
        self.FS3.setObjectName(_fromUtf8("FS3"))
        self.gridLayout.addWidget(self.FS3, 3, 2, 1, 1)
        self.FN3 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FN3.setFont(font)
        self.FN3.setObjectName(_fromUtf8("FN3"))
        self.gridLayout.addWidget(self.FN3, 3, 3, 1, 1)
        self.FE3 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FE3.setFont(font)
        self.FE3.setObjectName(_fromUtf8("FE3"))
        self.gridLayout.addWidget(self.FE3, 3, 4, 1, 1)
        self.FA3 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FA3.setFont(font)
        self.FA3.setObjectName(_fromUtf8("FA3"))
        self.gridLayout.addWidget(self.FA3, 3, 5, 1, 1)
        self.FC3 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FC3.setFont(font)
        self.FC3.setObjectName(_fromUtf8("FC3"))
        self.gridLayout.addWidget(self.FC3, 3, 6, 1, 1)
        self.FR3 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FR3.setFont(font)
        self.FR3.setObjectName(_fromUtf8("FR3"))
        self.gridLayout.addWidget(self.FR3, 3, 7, 1, 1)
        self.textval3 = QtGui.QLineEdit(self.widget)
        self.textval3.setEnabled(False)
        font = QtGui.QFont()
        font.setFamily(_fromUtf8("Courier New"))
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.textval3.setFont(font)
        self.textval3.setMaxLength(49)
        self.textval3.setObjectName(_fromUtf8("textval3"))
        self.gridLayout.addWidget(self.textval3, 3, 8, 1, 1)
        self.asstext3 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(11)
        self.asstext3.setFont(font)
        self.asstext3.setObjectName(_fromUtf8("asstext3"))
        self.gridLayout.addWidget(self.asstext3, 3, 9, 1, 1)
        self.intval3 = QtGui.QSpinBox(self.widget)
        self.intval3.setMinimum(-1000000)
        self.intval3.setMaximum(1000000)
        self.intval3.setProperty("value", 0)
        self.intval3.setObjectName(_fromUtf8("intval3"))
        self.gridLayout.addWidget(self.intval3, 3, 10, 1, 1)
        self.ac3 = QtGui.QCheckBox(self.widget)
        self.ac3.setObjectName(_fromUtf8("ac3"))
        self.gridLayout.addWidget(self.ac3, 3, 11, 1, 1)
        self.assvar4 = QtGui.QComboBox(self.widget)
        self.assvar4.setObjectName(_fromUtf8("assvar4"))
        self.assvar4.addItem(_fromUtf8(""))
        self.gridLayout.addWidget(self.assvar4, 4, 0, 1, 1)
        self.assop4 = QtGui.QComboBox(self.widget)
        self.assop4.setObjectName(_fromUtf8("assop4"))
        self.assop4.addItem(_fromUtf8(""))
        self.assop4.addItem(_fromUtf8(""))
        self.assop4.addItem(_fromUtf8(""))
        self.assop4.addItem(_fromUtf8(""))
        self.assop4.addItem(_fromUtf8(""))
        self.assop4.addItem(_fromUtf8(""))
        self.assop4.addItem(_fromUtf8(""))
        self.assop4.addItem(_fromUtf8(""))
        self.assop4.addItem(_fromUtf8(""))
        self.gridLayout.addWidget(self.assop4, 4, 1, 1, 1)
        self.FS4 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FS4.setFont(font)
        self.FS4.setObjectName(_fromUtf8("FS4"))
        self.gridLayout.addWidget(self.FS4, 4, 2, 1, 1)
        self.FN4 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FN4.setFont(font)
        self.FN4.setObjectName(_fromUtf8("FN4"))
        self.gridLayout.addWidget(self.FN4, 4, 3, 1, 1)
        self.FE4 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FE4.setFont(font)
        self.FE4.setObjectName(_fromUtf8("FE4"))
        self.gridLayout.addWidget(self.FE4, 4, 4, 1, 1)
        self.FA4 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FA4.setFont(font)
        self.FA4.setObjectName(_fromUtf8("FA4"))
        self.gridLayout.addWidget(self.FA4, 4, 5, 1, 1)
        self.FC4 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FC4.setFont(font)
        self.FC4.setObjectName(_fromUtf8("FC4"))
        self.gridLayout.addWidget(self.FC4, 4, 6, 1, 1)
        self.FR4 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FR4.setFont(font)
        self.FR4.setObjectName(_fromUtf8("FR4"))
        self.gridLayout.addWidget(self.FR4, 4, 7, 1, 1)
        self.textval4 = QtGui.QLineEdit(self.widget)
        self.textval4.setEnabled(False)
        font = QtGui.QFont()
        font.setFamily(_fromUtf8("Courier New"))
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.textval4.setFont(font)
        self.textval4.setMaxLength(49)
        self.textval4.setObjectName(_fromUtf8("textval4"))
        self.gridLayout.addWidget(self.textval4, 4, 8, 1, 1)
        self.asstext4 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(11)
        self.asstext4.setFont(font)
        self.asstext4.setObjectName(_fromUtf8("asstext4"))
        self.gridLayout.addWidget(self.asstext4, 4, 9, 1, 1)
        self.intval4 = QtGui.QSpinBox(self.widget)
        self.intval4.setMinimum(-1000000)
        self.intval4.setMaximum(1000000)
        self.intval4.setProperty("value", 0)
        self.intval4.setObjectName(_fromUtf8("intval4"))
        self.gridLayout.addWidget(self.intval4, 4, 10, 1, 1)
        self.ac4 = QtGui.QCheckBox(self.widget)
        self.ac4.setObjectName(_fromUtf8("ac4"))
        self.gridLayout.addWidget(self.ac4, 4, 11, 1, 1)
        self.assvar5 = QtGui.QComboBox(self.widget)
        self.assvar5.setObjectName(_fromUtf8("assvar5"))
        self.assvar5.addItem(_fromUtf8(""))
        self.gridLayout.addWidget(self.assvar5, 5, 0, 1, 1)
        self.assop5 = QtGui.QComboBox(self.widget)
        self.assop5.setObjectName(_fromUtf8("assop5"))
        self.assop5.addItem(_fromUtf8(""))
        self.assop5.addItem(_fromUtf8(""))
        self.assop5.addItem(_fromUtf8(""))
        self.assop5.addItem(_fromUtf8(""))
        self.assop5.addItem(_fromUtf8(""))
        self.assop5.addItem(_fromUtf8(""))
        self.assop5.addItem(_fromUtf8(""))
        self.assop5.addItem(_fromUtf8(""))
        self.assop5.addItem(_fromUtf8(""))
        self.gridLayout.addWidget(self.assop5, 5, 1, 1, 1)
        self.FS5 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FS5.setFont(font)
        self.FS5.setObjectName(_fromUtf8("FS5"))
        self.gridLayout.addWidget(self.FS5, 5, 2, 1, 1)
        self.FN5 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FN5.setFont(font)
        self.FN5.setObjectName(_fromUtf8("FN5"))
        self.gridLayout.addWidget(self.FN5, 5, 3, 1, 1)
        self.FE5 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FE5.setFont(font)
        self.FE5.setObjectName(_fromUtf8("FE5"))
        self.gridLayout.addWidget(self.FE5, 5, 4, 1, 1)
        self.FA5 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FA5.setFont(font)
        self.FA5.setObjectName(_fromUtf8("FA5"))
        self.gridLayout.addWidget(self.FA5, 5, 5, 1, 1)
        self.FC5 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FC5.setFont(font)
        self.FC5.setObjectName(_fromUtf8("FC5"))
        self.gridLayout.addWidget(self.FC5, 5, 6, 1, 1)
        self.FR5 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FR5.setFont(font)
        self.FR5.setObjectName(_fromUtf8("FR5"))
        self.gridLayout.addWidget(self.FR5, 5, 7, 1, 1)
        self.textval5 = QtGui.QLineEdit(self.widget)
        self.textval5.setEnabled(False)
        font = QtGui.QFont()
        font.setFamily(_fromUtf8("Courier New"))
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.textval5.setFont(font)
        self.textval5.setMaxLength(49)
        self.textval5.setObjectName(_fromUtf8("textval5"))
        self.gridLayout.addWidget(self.textval5, 5, 8, 1, 1)
        self.asstext5 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(11)
        self.asstext5.setFont(font)
        self.asstext5.setObjectName(_fromUtf8("asstext5"))
        self.gridLayout.addWidget(self.asstext5, 5, 9, 1, 1)
        self.intval5 = QtGui.QSpinBox(self.widget)
        self.intval5.setMinimum(-1000000)
        self.intval5.setMaximum(1000000)
        self.intval5.setProperty("value", 0)
        self.intval5.setObjectName(_fromUtf8("intval5"))
        self.gridLayout.addWidget(self.intval5, 5, 10, 1, 1)
        self.ac5 = QtGui.QCheckBox(self.widget)
        self.ac5.setObjectName(_fromUtf8("ac5"))
        self.gridLayout.addWidget(self.ac5, 5, 11, 1, 1)
        self.assvar6 = QtGui.QComboBox(self.widget)
        self.assvar6.setObjectName(_fromUtf8("assvar6"))
        self.assvar6.addItem(_fromUtf8(""))
        self.gridLayout.addWidget(self.assvar6, 6, 0, 1, 1)
        self.assop6 = QtGui.QComboBox(self.widget)
        self.assop6.setObjectName(_fromUtf8("assop6"))
        self.assop6.addItem(_fromUtf8(""))
        self.assop6.addItem(_fromUtf8(""))
        self.assop6.addItem(_fromUtf8(""))
        self.assop6.addItem(_fromUtf8(""))
        self.assop6.addItem(_fromUtf8(""))
        self.assop6.addItem(_fromUtf8(""))
        self.assop6.addItem(_fromUtf8(""))
        self.assop6.addItem(_fromUtf8(""))
        self.assop6.addItem(_fromUtf8(""))
        self.gridLayout.addWidget(self.assop6, 6, 1, 1, 1)
        self.FS6 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FS6.setFont(font)
        self.FS6.setObjectName(_fromUtf8("FS6"))
        self.gridLayout.addWidget(self.FS6, 6, 2, 1, 1)
        self.FN6 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FN6.setFont(font)
        self.FN6.setObjectName(_fromUtf8("FN6"))
        self.gridLayout.addWidget(self.FN6, 6, 3, 1, 1)
        self.FE6 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FE6.setFont(font)
        self.FE6.setObjectName(_fromUtf8("FE6"))
        self.gridLayout.addWidget(self.FE6, 6, 4, 1, 1)
        self.FA6 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FA6.setFont(font)
        self.FA6.setObjectName(_fromUtf8("FA6"))
        self.gridLayout.addWidget(self.FA6, 6, 5, 1, 1)
        self.FC6 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FC6.setFont(font)
        self.FC6.setObjectName(_fromUtf8("FC6"))
        self.gridLayout.addWidget(self.FC6, 6, 6, 1, 1)
        self.FR6 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FR6.setFont(font)
        self.FR6.setObjectName(_fromUtf8("FR6"))
        self.gridLayout.addWidget(self.FR6, 6, 7, 1, 1)
        self.textval6 = QtGui.QLineEdit(self.widget)
        self.textval6.setEnabled(False)
        font = QtGui.QFont()
        font.setFamily(_fromUtf8("Courier New"))
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.textval6.setFont(font)
        self.textval6.setMaxLength(49)
        self.textval6.setObjectName(_fromUtf8("textval6"))
        self.gridLayout.addWidget(self.textval6, 6, 8, 1, 1)
        self.asstext6 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(11)
        self.asstext6.setFont(font)
        self.asstext6.setObjectName(_fromUtf8("asstext6"))
        self.gridLayout.addWidget(self.asstext6, 6, 9, 1, 1)
        self.intval6 = QtGui.QSpinBox(self.widget)
        self.intval6.setMinimum(-1000000)
        self.intval6.setMaximum(1000000)
        self.intval6.setProperty("value", 0)
        self.intval6.setObjectName(_fromUtf8("intval6"))
        self.gridLayout.addWidget(self.intval6, 6, 10, 1, 1)
        self.ac6 = QtGui.QCheckBox(self.widget)
        self.ac6.setObjectName(_fromUtf8("ac6"))
        self.gridLayout.addWidget(self.ac6, 6, 11, 1, 1)
        self.assvar7 = QtGui.QComboBox(self.widget)
        self.assvar7.setObjectName(_fromUtf8("assvar7"))
        self.assvar7.addItem(_fromUtf8(""))
        self.gridLayout.addWidget(self.assvar7, 7, 0, 1, 1)
        self.assop7 = QtGui.QComboBox(self.widget)
        self.assop7.setObjectName(_fromUtf8("assop7"))
        self.assop7.addItem(_fromUtf8(""))
        self.assop7.addItem(_fromUtf8(""))
        self.assop7.addItem(_fromUtf8(""))
        self.assop7.addItem(_fromUtf8(""))
        self.assop7.addItem(_fromUtf8(""))
        self.assop7.addItem(_fromUtf8(""))
        self.assop7.addItem(_fromUtf8(""))
        self.assop7.addItem(_fromUtf8(""))
        self.assop7.addItem(_fromUtf8(""))
        self.gridLayout.addWidget(self.assop7, 7, 1, 1, 1)
        self.FS7 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FS7.setFont(font)
        self.FS7.setObjectName(_fromUtf8("FS7"))
        self.gridLayout.addWidget(self.FS7, 7, 2, 1, 1)
        self.FN7 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FN7.setFont(font)
        self.FN7.setObjectName(_fromUtf8("FN7"))
        self.gridLayout.addWidget(self.FN7, 7, 3, 1, 1)
        self.FE7 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FE7.setFont(font)
        self.FE7.setObjectName(_fromUtf8("FE7"))
        self.gridLayout.addWidget(self.FE7, 7, 4, 1, 1)
        self.FA7 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FA7.setFont(font)
        self.FA7.setObjectName(_fromUtf8("FA7"))
        self.gridLayout.addWidget(self.FA7, 7, 5, 1, 1)
        self.FC7 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FC7.setFont(font)
        self.FC7.setObjectName(_fromUtf8("FC7"))
        self.gridLayout.addWidget(self.FC7, 7, 6, 1, 1)
        self.FR7 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(9)
        font.setBold(True)
        font.setItalic(True)
        font.setWeight(75)
        self.FR7.setFont(font)
        self.FR7.setObjectName(_fromUtf8("FR7"))
        self.gridLayout.addWidget(self.FR7, 7, 7, 1, 1)
        self.textval7 = QtGui.QLineEdit(self.widget)
        self.textval7.setEnabled(False)
        font = QtGui.QFont()
        font.setFamily(_fromUtf8("Courier New"))
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.textval7.setFont(font)
        self.textval7.setMaxLength(49)
        self.textval7.setObjectName(_fromUtf8("textval7"))
        self.gridLayout.addWidget(self.textval7, 7, 8, 1, 1)
        self.asstext7 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(11)
        self.asstext7.setFont(font)
        self.asstext7.setObjectName(_fromUtf8("asstext7"))
        self.gridLayout.addWidget(self.asstext7, 7, 9, 1, 1)
        self.intval7 = QtGui.QSpinBox(self.widget)
        self.intval7.setMinimum(-1000000)
        self.intval7.setMaximum(1000000)
        self.intval7.setProperty("value", 0)
        self.intval7.setObjectName(_fromUtf8("intval7"))
        self.gridLayout.addWidget(self.intval7, 7, 10, 1, 1)
        self.ac7 = QtGui.QCheckBox(self.widget)
        self.ac7.setObjectName(_fromUtf8("ac7"))
        self.gridLayout.addWidget(self.ac7, 7, 11, 1, 1)

        self.retranslateUi(jassdlg)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("accepted()")), jassdlg.accept)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("rejected()")), jassdlg.reject)
        QtCore.QMetaObject.connectSlotsByName(jassdlg)
        jassdlg.setTabOrder(self.assvar0, self.assop0)
        jassdlg.setTabOrder(self.assop0, self.FS0)
        jassdlg.setTabOrder(self.FS0, self.FN0)
        jassdlg.setTabOrder(self.FN0, self.FE0)
        jassdlg.setTabOrder(self.FE0, self.FA0)
        jassdlg.setTabOrder(self.FA0, self.FC0)
        jassdlg.setTabOrder(self.FC0, self.FR0)
        jassdlg.setTabOrder(self.FR0, self.textval0)
        jassdlg.setTabOrder(self.textval0, self.asstext0)
        jassdlg.setTabOrder(self.asstext0, self.intval0)
        jassdlg.setTabOrder(self.intval0, self.ac0)
        jassdlg.setTabOrder(self.ac0, self.assvar1)
        jassdlg.setTabOrder(self.assvar1, self.assop1)
        jassdlg.setTabOrder(self.assop1, self.FS1)
        jassdlg.setTabOrder(self.FS1, self.FN1)
        jassdlg.setTabOrder(self.FN1, self.FE1)
        jassdlg.setTabOrder(self.FE1, self.FA1)
        jassdlg.setTabOrder(self.FA1, self.FC1)
        jassdlg.setTabOrder(self.FC1, self.FR1)
        jassdlg.setTabOrder(self.FR1, self.textval1)
        jassdlg.setTabOrder(self.textval1, self.asstext1)
        jassdlg.setTabOrder(self.asstext1, self.intval1)
        jassdlg.setTabOrder(self.intval1, self.ac1)
        jassdlg.setTabOrder(self.ac1, self.assvar2)
        jassdlg.setTabOrder(self.assvar2, self.assop2)
        jassdlg.setTabOrder(self.assop2, self.FS2)
        jassdlg.setTabOrder(self.FS2, self.FN2)
        jassdlg.setTabOrder(self.FN2, self.FE2)
        jassdlg.setTabOrder(self.FE2, self.FA2)
        jassdlg.setTabOrder(self.FA2, self.FC2)
        jassdlg.setTabOrder(self.FC2, self.FR2)
        jassdlg.setTabOrder(self.FR2, self.textval2)
        jassdlg.setTabOrder(self.textval2, self.asstext2)
        jassdlg.setTabOrder(self.asstext2, self.intval2)
        jassdlg.setTabOrder(self.intval2, self.ac2)
        jassdlg.setTabOrder(self.ac2, self.assvar3)
        jassdlg.setTabOrder(self.assvar3, self.assop3)
        jassdlg.setTabOrder(self.assop3, self.FS3)
        jassdlg.setTabOrder(self.FS3, self.FN3)
        jassdlg.setTabOrder(self.FN3, self.FE3)
        jassdlg.setTabOrder(self.FE3, self.FA3)
        jassdlg.setTabOrder(self.FA3, self.FC3)
        jassdlg.setTabOrder(self.FC3, self.FR3)
        jassdlg.setTabOrder(self.FR3, self.textval3)
        jassdlg.setTabOrder(self.textval3, self.asstext3)
        jassdlg.setTabOrder(self.asstext3, self.intval3)
        jassdlg.setTabOrder(self.intval3, self.ac3)
        jassdlg.setTabOrder(self.ac3, self.assvar4)
        jassdlg.setTabOrder(self.assvar4, self.assop4)
        jassdlg.setTabOrder(self.assop4, self.FS4)
        jassdlg.setTabOrder(self.FS4, self.FN4)
        jassdlg.setTabOrder(self.FN4, self.FE4)
        jassdlg.setTabOrder(self.FE4, self.FA4)
        jassdlg.setTabOrder(self.FA4, self.FC4)
        jassdlg.setTabOrder(self.FC4, self.FR4)
        jassdlg.setTabOrder(self.FR4, self.textval4)
        jassdlg.setTabOrder(self.textval4, self.asstext4)
        jassdlg.setTabOrder(self.asstext4, self.intval4)
        jassdlg.setTabOrder(self.intval4, self.ac4)
        jassdlg.setTabOrder(self.ac4, self.assvar5)
        jassdlg.setTabOrder(self.assvar5, self.assop5)
        jassdlg.setTabOrder(self.assop5, self.FS5)
        jassdlg.setTabOrder(self.FS5, self.FN5)
        jassdlg.setTabOrder(self.FN5, self.FE5)
        jassdlg.setTabOrder(self.FE5, self.FA5)
        jassdlg.setTabOrder(self.FA5, self.FC5)
        jassdlg.setTabOrder(self.FC5, self.FR5)
        jassdlg.setTabOrder(self.FR5, self.textval5)
        jassdlg.setTabOrder(self.textval5, self.asstext5)
        jassdlg.setTabOrder(self.asstext5, self.intval5)
        jassdlg.setTabOrder(self.intval5, self.ac5)
        jassdlg.setTabOrder(self.ac5, self.assvar6)
        jassdlg.setTabOrder(self.assvar6, self.assop6)
        jassdlg.setTabOrder(self.assop6, self.FS6)
        jassdlg.setTabOrder(self.FS6, self.FN6)
        jassdlg.setTabOrder(self.FN6, self.FE6)
        jassdlg.setTabOrder(self.FE6, self.FA6)
        jassdlg.setTabOrder(self.FA6, self.FC6)
        jassdlg.setTabOrder(self.FC6, self.FR6)
        jassdlg.setTabOrder(self.FR6, self.textval6)
        jassdlg.setTabOrder(self.textval6, self.asstext6)
        jassdlg.setTabOrder(self.asstext6, self.intval6)
        jassdlg.setTabOrder(self.intval6, self.ac6)
        jassdlg.setTabOrder(self.ac6, self.assvar7)
        jassdlg.setTabOrder(self.assvar7, self.assop7)
        jassdlg.setTabOrder(self.assop7, self.FS7)
        jassdlg.setTabOrder(self.FS7, self.FN7)
        jassdlg.setTabOrder(self.FN7, self.FE7)
        jassdlg.setTabOrder(self.FE7, self.FA7)
        jassdlg.setTabOrder(self.FA7, self.FC7)
        jassdlg.setTabOrder(self.FC7, self.FR7)
        jassdlg.setTabOrder(self.FR7, self.textval7)
        jassdlg.setTabOrder(self.textval7, self.asstext7)
        jassdlg.setTabOrder(self.asstext7, self.intval7)
        jassdlg.setTabOrder(self.intval7, self.ac7)
        jassdlg.setTabOrder(self.ac7, self.buttonBox)

    def retranslateUi(self, jassdlg):
        jassdlg.setWindowTitle(QtGui.QApplication.translate("jassdlg", "Assignments for job", None, QtGui.QApplication.UnicodeUTF8))
        self.label.setText(QtGui.QApplication.translate("jassdlg", "Assignments for job", None, QtGui.QApplication.UnicodeUTF8))
        self.label_2.setText(QtGui.QApplication.translate("jassdlg", "Variable", None, QtGui.QApplication.UnicodeUTF8))
        self.label_3.setText(QtGui.QApplication.translate("jassdlg", "Op", None, QtGui.QApplication.UnicodeUTF8))
        self.label_4.setText(QtGui.QApplication.translate("jassdlg", "When Done", None, QtGui.QApplication.UnicodeUTF8))
        self.label_5.setText(QtGui.QApplication.translate("jassdlg", "Text Value", None, QtGui.QApplication.UnicodeUTF8))
        self.label_6.setText(QtGui.QApplication.translate("jassdlg", "Int Val", None, QtGui.QApplication.UnicodeUTF8))
        self.assvar0.setToolTip(QtGui.QApplication.translate("jassdlg", "This is the variable to be assigned to", None, QtGui.QApplication.UnicodeUTF8))
        self.assvar0.setItemText(0, QtGui.QApplication.translate("jassdlg", "(no variable)", None, QtGui.QApplication.UnicodeUTF8))
        self.assop0.setToolTip(QtGui.QApplication.translate("jassdlg", "This is the operation to be performed", None, QtGui.QApplication.UnicodeUTF8))
        self.assop0.setItemText(0, QtGui.QApplication.translate("jassdlg", "(none)", None, QtGui.QApplication.UnicodeUTF8))
        self.assop0.setItemText(1, QtGui.QApplication.translate("jassdlg", "Set", None, QtGui.QApplication.UnicodeUTF8))
        self.assop0.setItemText(2, QtGui.QApplication.translate("jassdlg", "Add", None, QtGui.QApplication.UnicodeUTF8))
        self.assop0.setItemText(3, QtGui.QApplication.translate("jassdlg", "Subtract", None, QtGui.QApplication.UnicodeUTF8))
        self.assop0.setItemText(4, QtGui.QApplication.translate("jassdlg", "Multiply", None, QtGui.QApplication.UnicodeUTF8))
        self.assop0.setItemText(5, QtGui.QApplication.translate("jassdlg", "Divide", None, QtGui.QApplication.UnicodeUTF8))
        self.assop0.setItemText(6, QtGui.QApplication.translate("jassdlg", "Modulus", None, QtGui.QApplication.UnicodeUTF8))
        self.assop0.setItemText(7, QtGui.QApplication.translate("jassdlg", "Set Exit", None, QtGui.QApplication.UnicodeUTF8))
        self.assop0.setItemText(8, QtGui.QApplication.translate("jassdlg", "Set Signal", None, QtGui.QApplication.UnicodeUTF8))
        self.FS0.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job starts", None, QtGui.QApplication.UnicodeUTF8))
        self.FS0.setText(QtGui.QApplication.translate("jassdlg", "S", None, QtGui.QApplication.UnicodeUTF8))
        self.FN0.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job\n"
"exits normally (as indicated by the exit code settings).", None, QtGui.QApplication.UnicodeUTF8))
        self.FN0.setText(QtGui.QApplication.translate("jassdlg", "N", None, QtGui.QApplication.UnicodeUTF8))
        self.FE0.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job\n"
"exits with an error code (as indicated by the exit code settings).", None, QtGui.QApplication.UnicodeUTF8))
        self.FE0.setText(QtGui.QApplication.translate("jassdlg", "E", None, QtGui.QApplication.UnicodeUTF8))
        self.FA0.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job\n"
"aborts - either exits with a signal, or with an error code not covered\n"
"by the job exit code settings.", None, QtGui.QApplication.UnicodeUTF8))
        self.FA0.setText(QtGui.QApplication.translate("jassdlg", "A", None, QtGui.QApplication.UnicodeUTF8))
        self.FC0.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job\n"
"is cancelled (killed with a signal before it is run).", None, QtGui.QApplication.UnicodeUTF8))
        self.FC0.setText(QtGui.QApplication.translate("jassdlg", "C", None, QtGui.QApplication.UnicodeUTF8))
        self.FR0.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the exit code operations (N E A C) are to be reversed if\n"
"possible.\n"
"\n"
"Note that only add subtract multiply and divide can be reversed.", None, QtGui.QApplication.UnicodeUTF8))
        self.FR0.setText(QtGui.QApplication.translate("jassdlg", "R", None, QtGui.QApplication.UnicodeUTF8))
        self.textval0.setToolTip(QtGui.QApplication.translate("jassdlg", "Give the text value to be assigned here", None, QtGui.QApplication.UnicodeUTF8))
        self.asstext0.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicate that the value to be assigned is text", None, QtGui.QApplication.UnicodeUTF8))
        self.asstext0.setText(QtGui.QApplication.translate("jassdlg", "Text", None, QtGui.QApplication.UnicodeUTF8))
        self.intval0.setToolTip(QtGui.QApplication.translate("jassdlg", "Give the integer value to be used here", None, QtGui.QApplication.UnicodeUTF8))
        self.ac0.setToolTip(QtGui.QApplication.translate("jassdlg", "This is a critical assignment\n"
"\n"
"If set and the host with the variable is not running, then the job is held.\n"
"\n"
"If it is not set and the host with the variable is not running, then the\n"
"assignment is ignored.", None, QtGui.QApplication.UnicodeUTF8))
        self.ac0.setText(QtGui.QApplication.translate("jassdlg", "Acrit", None, QtGui.QApplication.UnicodeUTF8))
        self.assvar1.setToolTip(QtGui.QApplication.translate("jassdlg", "This is the variable to be assigned to", None, QtGui.QApplication.UnicodeUTF8))
        self.assvar1.setItemText(0, QtGui.QApplication.translate("jassdlg", "(no variable)", None, QtGui.QApplication.UnicodeUTF8))
        self.assop1.setToolTip(QtGui.QApplication.translate("jassdlg", "This is the operation to be performed", None, QtGui.QApplication.UnicodeUTF8))
        self.assop1.setItemText(0, QtGui.QApplication.translate("jassdlg", "(none)", None, QtGui.QApplication.UnicodeUTF8))
        self.assop1.setItemText(1, QtGui.QApplication.translate("jassdlg", "Set", None, QtGui.QApplication.UnicodeUTF8))
        self.assop1.setItemText(2, QtGui.QApplication.translate("jassdlg", "Add", None, QtGui.QApplication.UnicodeUTF8))
        self.assop1.setItemText(3, QtGui.QApplication.translate("jassdlg", "Subtract", None, QtGui.QApplication.UnicodeUTF8))
        self.assop1.setItemText(4, QtGui.QApplication.translate("jassdlg", "Multiply", None, QtGui.QApplication.UnicodeUTF8))
        self.assop1.setItemText(5, QtGui.QApplication.translate("jassdlg", "Divide", None, QtGui.QApplication.UnicodeUTF8))
        self.assop1.setItemText(6, QtGui.QApplication.translate("jassdlg", "Modulus", None, QtGui.QApplication.UnicodeUTF8))
        self.assop1.setItemText(7, QtGui.QApplication.translate("jassdlg", "Set Exit", None, QtGui.QApplication.UnicodeUTF8))
        self.assop1.setItemText(8, QtGui.QApplication.translate("jassdlg", "Set Signal", None, QtGui.QApplication.UnicodeUTF8))
        self.FS1.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job starts", None, QtGui.QApplication.UnicodeUTF8))
        self.FS1.setText(QtGui.QApplication.translate("jassdlg", "S", None, QtGui.QApplication.UnicodeUTF8))
        self.FN1.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job\n"
"exits normally (as indicated by the exit code settings).", None, QtGui.QApplication.UnicodeUTF8))
        self.FN1.setText(QtGui.QApplication.translate("jassdlg", "N", None, QtGui.QApplication.UnicodeUTF8))
        self.FE1.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job\n"
"exits with an error code (as indicated by the exit code settings).", None, QtGui.QApplication.UnicodeUTF8))
        self.FE1.setText(QtGui.QApplication.translate("jassdlg", "E", None, QtGui.QApplication.UnicodeUTF8))
        self.FA1.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job\n"
"aborts - either exits with a signal, or with an error code not covered\n"
"by the job exit code settings.", None, QtGui.QApplication.UnicodeUTF8))
        self.FA1.setText(QtGui.QApplication.translate("jassdlg", "A", None, QtGui.QApplication.UnicodeUTF8))
        self.FC1.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job\n"
"is cancelled (killed with a signal before it is run).", None, QtGui.QApplication.UnicodeUTF8))
        self.FC1.setText(QtGui.QApplication.translate("jassdlg", "C", None, QtGui.QApplication.UnicodeUTF8))
        self.FR1.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the exit code operations (N E A C) are to be reversed if\n"
"possible.\n"
"\n"
"Note that only add subtract multiply and divide can be reversed.", None, QtGui.QApplication.UnicodeUTF8))
        self.FR1.setText(QtGui.QApplication.translate("jassdlg", "R", None, QtGui.QApplication.UnicodeUTF8))
        self.textval1.setToolTip(QtGui.QApplication.translate("jassdlg", "Give the text value to be assigned here", None, QtGui.QApplication.UnicodeUTF8))
        self.asstext1.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicate that the value to be assigned is text", None, QtGui.QApplication.UnicodeUTF8))
        self.asstext1.setText(QtGui.QApplication.translate("jassdlg", "Text", None, QtGui.QApplication.UnicodeUTF8))
        self.intval1.setToolTip(QtGui.QApplication.translate("jassdlg", "Give the integer value to be used here", None, QtGui.QApplication.UnicodeUTF8))
        self.ac1.setToolTip(QtGui.QApplication.translate("jassdlg", "This is a critical assignment\n"
"\n"
"If set and the host with the variable is not running, then the job is held.\n"
"\n"
"If it is not set and the host with the variable is not running, then the\n"
"assignment is ignored.", None, QtGui.QApplication.UnicodeUTF8))
        self.ac1.setText(QtGui.QApplication.translate("jassdlg", "Acrit", None, QtGui.QApplication.UnicodeUTF8))
        self.assvar2.setToolTip(QtGui.QApplication.translate("jassdlg", "This is the variable to be assigned to", None, QtGui.QApplication.UnicodeUTF8))
        self.assvar2.setItemText(0, QtGui.QApplication.translate("jassdlg", "(no variable)", None, QtGui.QApplication.UnicodeUTF8))
        self.assop2.setToolTip(QtGui.QApplication.translate("jassdlg", "This is the operation to be performed", None, QtGui.QApplication.UnicodeUTF8))
        self.assop2.setItemText(0, QtGui.QApplication.translate("jassdlg", "(none)", None, QtGui.QApplication.UnicodeUTF8))
        self.assop2.setItemText(1, QtGui.QApplication.translate("jassdlg", "Set", None, QtGui.QApplication.UnicodeUTF8))
        self.assop2.setItemText(2, QtGui.QApplication.translate("jassdlg", "Add", None, QtGui.QApplication.UnicodeUTF8))
        self.assop2.setItemText(3, QtGui.QApplication.translate("jassdlg", "Subtract", None, QtGui.QApplication.UnicodeUTF8))
        self.assop2.setItemText(4, QtGui.QApplication.translate("jassdlg", "Multiply", None, QtGui.QApplication.UnicodeUTF8))
        self.assop2.setItemText(5, QtGui.QApplication.translate("jassdlg", "Divide", None, QtGui.QApplication.UnicodeUTF8))
        self.assop2.setItemText(6, QtGui.QApplication.translate("jassdlg", "Modulus", None, QtGui.QApplication.UnicodeUTF8))
        self.assop2.setItemText(7, QtGui.QApplication.translate("jassdlg", "Set Exit", None, QtGui.QApplication.UnicodeUTF8))
        self.assop2.setItemText(8, QtGui.QApplication.translate("jassdlg", "Set Signal", None, QtGui.QApplication.UnicodeUTF8))
        self.FS2.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job starts", None, QtGui.QApplication.UnicodeUTF8))
        self.FS2.setText(QtGui.QApplication.translate("jassdlg", "S", None, QtGui.QApplication.UnicodeUTF8))
        self.FN2.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job\n"
"exits normally (as indicated by the exit code settings).", None, QtGui.QApplication.UnicodeUTF8))
        self.FN2.setText(QtGui.QApplication.translate("jassdlg", "N", None, QtGui.QApplication.UnicodeUTF8))
        self.FE2.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job\n"
"exits with an error code (as indicated by the exit code settings).", None, QtGui.QApplication.UnicodeUTF8))
        self.FE2.setText(QtGui.QApplication.translate("jassdlg", "E", None, QtGui.QApplication.UnicodeUTF8))
        self.FA2.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job\n"
"aborts - either exits with a signal, or with an error code not covered\n"
"by the job exit code settings.", None, QtGui.QApplication.UnicodeUTF8))
        self.FA2.setText(QtGui.QApplication.translate("jassdlg", "A", None, QtGui.QApplication.UnicodeUTF8))
        self.FC2.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job\n"
"is cancelled (killed with a signal before it is run).", None, QtGui.QApplication.UnicodeUTF8))
        self.FC2.setText(QtGui.QApplication.translate("jassdlg", "C", None, QtGui.QApplication.UnicodeUTF8))
        self.FR2.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the exit code operations (N E A C) are to be reversed if\n"
"possible.\n"
"\n"
"Note that only add subtract multiply and divide can be reversed.", None, QtGui.QApplication.UnicodeUTF8))
        self.FR2.setText(QtGui.QApplication.translate("jassdlg", "R", None, QtGui.QApplication.UnicodeUTF8))
        self.textval2.setToolTip(QtGui.QApplication.translate("jassdlg", "Give the text value to be assigned here", None, QtGui.QApplication.UnicodeUTF8))
        self.asstext2.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicate that the value to be assigned is text", None, QtGui.QApplication.UnicodeUTF8))
        self.asstext2.setText(QtGui.QApplication.translate("jassdlg", "Text", None, QtGui.QApplication.UnicodeUTF8))
        self.intval2.setToolTip(QtGui.QApplication.translate("jassdlg", "Give the integer value to be used here", None, QtGui.QApplication.UnicodeUTF8))
        self.ac2.setToolTip(QtGui.QApplication.translate("jassdlg", "This is a critical assignment\n"
"\n"
"If set and the host with the variable is not running, then the job is held.\n"
"\n"
"If it is not set and the host with the variable is not running, then the\n"
"assignment is ignored.", None, QtGui.QApplication.UnicodeUTF8))
        self.ac2.setText(QtGui.QApplication.translate("jassdlg", "Acrit", None, QtGui.QApplication.UnicodeUTF8))
        self.assvar3.setToolTip(QtGui.QApplication.translate("jassdlg", "This is the variable to be assigned to", None, QtGui.QApplication.UnicodeUTF8))
        self.assvar3.setItemText(0, QtGui.QApplication.translate("jassdlg", "(no variable)", None, QtGui.QApplication.UnicodeUTF8))
        self.assop3.setToolTip(QtGui.QApplication.translate("jassdlg", "This is the operation to be performed", None, QtGui.QApplication.UnicodeUTF8))
        self.assop3.setItemText(0, QtGui.QApplication.translate("jassdlg", "(none)", None, QtGui.QApplication.UnicodeUTF8))
        self.assop3.setItemText(1, QtGui.QApplication.translate("jassdlg", "Set", None, QtGui.QApplication.UnicodeUTF8))
        self.assop3.setItemText(2, QtGui.QApplication.translate("jassdlg", "Add", None, QtGui.QApplication.UnicodeUTF8))
        self.assop3.setItemText(3, QtGui.QApplication.translate("jassdlg", "Subtract", None, QtGui.QApplication.UnicodeUTF8))
        self.assop3.setItemText(4, QtGui.QApplication.translate("jassdlg", "Multiply", None, QtGui.QApplication.UnicodeUTF8))
        self.assop3.setItemText(5, QtGui.QApplication.translate("jassdlg", "Divide", None, QtGui.QApplication.UnicodeUTF8))
        self.assop3.setItemText(6, QtGui.QApplication.translate("jassdlg", "Modulus", None, QtGui.QApplication.UnicodeUTF8))
        self.assop3.setItemText(7, QtGui.QApplication.translate("jassdlg", "Set Exit", None, QtGui.QApplication.UnicodeUTF8))
        self.assop3.setItemText(8, QtGui.QApplication.translate("jassdlg", "Set Signal", None, QtGui.QApplication.UnicodeUTF8))
        self.FS3.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job starts", None, QtGui.QApplication.UnicodeUTF8))
        self.FS3.setText(QtGui.QApplication.translate("jassdlg", "S", None, QtGui.QApplication.UnicodeUTF8))
        self.FN3.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job\n"
"exits normally (as indicated by the exit code settings).", None, QtGui.QApplication.UnicodeUTF8))
        self.FN3.setText(QtGui.QApplication.translate("jassdlg", "N", None, QtGui.QApplication.UnicodeUTF8))
        self.FE3.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job\n"
"exits with an error code (as indicated by the exit code settings).", None, QtGui.QApplication.UnicodeUTF8))
        self.FE3.setText(QtGui.QApplication.translate("jassdlg", "E", None, QtGui.QApplication.UnicodeUTF8))
        self.FA3.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job\n"
"aborts - either exits with a signal, or with an error code not covered\n"
"by the job exit code settings.", None, QtGui.QApplication.UnicodeUTF8))
        self.FA3.setText(QtGui.QApplication.translate("jassdlg", "A", None, QtGui.QApplication.UnicodeUTF8))
        self.FC3.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job\n"
"is cancelled (killed with a signal before it is run).", None, QtGui.QApplication.UnicodeUTF8))
        self.FC3.setText(QtGui.QApplication.translate("jassdlg", "C", None, QtGui.QApplication.UnicodeUTF8))
        self.FR3.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the exit code operations (N E A C) are to be reversed if\n"
"possible.\n"
"\n"
"Note that only add subtract multiply and divide can be reversed.", None, QtGui.QApplication.UnicodeUTF8))
        self.FR3.setText(QtGui.QApplication.translate("jassdlg", "R", None, QtGui.QApplication.UnicodeUTF8))
        self.textval3.setToolTip(QtGui.QApplication.translate("jassdlg", "Give the text value to be assigned here", None, QtGui.QApplication.UnicodeUTF8))
        self.asstext3.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicate that the value to be assigned is text", None, QtGui.QApplication.UnicodeUTF8))
        self.asstext3.setText(QtGui.QApplication.translate("jassdlg", "Text", None, QtGui.QApplication.UnicodeUTF8))
        self.intval3.setToolTip(QtGui.QApplication.translate("jassdlg", "Give the integer value to be used here", None, QtGui.QApplication.UnicodeUTF8))
        self.ac3.setToolTip(QtGui.QApplication.translate("jassdlg", "This is a critical assignment\n"
"\n"
"If set and the host with the variable is not running, then the job is held.\n"
"\n"
"If it is not set and the host with the variable is not running, then the\n"
"assignment is ignored.", None, QtGui.QApplication.UnicodeUTF8))
        self.ac3.setText(QtGui.QApplication.translate("jassdlg", "Acrit", None, QtGui.QApplication.UnicodeUTF8))
        self.assvar4.setToolTip(QtGui.QApplication.translate("jassdlg", "This is the variable to be assigned to", None, QtGui.QApplication.UnicodeUTF8))
        self.assvar4.setItemText(0, QtGui.QApplication.translate("jassdlg", "(no variable)", None, QtGui.QApplication.UnicodeUTF8))
        self.assop4.setToolTip(QtGui.QApplication.translate("jassdlg", "This is the operation to be performed", None, QtGui.QApplication.UnicodeUTF8))
        self.assop4.setItemText(0, QtGui.QApplication.translate("jassdlg", "(none)", None, QtGui.QApplication.UnicodeUTF8))
        self.assop4.setItemText(1, QtGui.QApplication.translate("jassdlg", "Set", None, QtGui.QApplication.UnicodeUTF8))
        self.assop4.setItemText(2, QtGui.QApplication.translate("jassdlg", "Add", None, QtGui.QApplication.UnicodeUTF8))
        self.assop4.setItemText(3, QtGui.QApplication.translate("jassdlg", "Subtract", None, QtGui.QApplication.UnicodeUTF8))
        self.assop4.setItemText(4, QtGui.QApplication.translate("jassdlg", "Multiply", None, QtGui.QApplication.UnicodeUTF8))
        self.assop4.setItemText(5, QtGui.QApplication.translate("jassdlg", "Divide", None, QtGui.QApplication.UnicodeUTF8))
        self.assop4.setItemText(6, QtGui.QApplication.translate("jassdlg", "Modulus", None, QtGui.QApplication.UnicodeUTF8))
        self.assop4.setItemText(7, QtGui.QApplication.translate("jassdlg", "Set Exit", None, QtGui.QApplication.UnicodeUTF8))
        self.assop4.setItemText(8, QtGui.QApplication.translate("jassdlg", "Set Signal", None, QtGui.QApplication.UnicodeUTF8))
        self.FS4.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job starts", None, QtGui.QApplication.UnicodeUTF8))
        self.FS4.setText(QtGui.QApplication.translate("jassdlg", "S", None, QtGui.QApplication.UnicodeUTF8))
        self.FN4.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job\n"
"exits normally (as indicated by the exit code settings).", None, QtGui.QApplication.UnicodeUTF8))
        self.FN4.setText(QtGui.QApplication.translate("jassdlg", "N", None, QtGui.QApplication.UnicodeUTF8))
        self.FE4.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job\n"
"exits with an error code (as indicated by the exit code settings).", None, QtGui.QApplication.UnicodeUTF8))
        self.FE4.setText(QtGui.QApplication.translate("jassdlg", "E", None, QtGui.QApplication.UnicodeUTF8))
        self.FA4.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job\n"
"aborts - either exits with a signal, or with an error code not covered\n"
"by the job exit code settings.", None, QtGui.QApplication.UnicodeUTF8))
        self.FA4.setText(QtGui.QApplication.translate("jassdlg", "A", None, QtGui.QApplication.UnicodeUTF8))
        self.FC4.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job\n"
"is cancelled (killed with a signal before it is run).", None, QtGui.QApplication.UnicodeUTF8))
        self.FC4.setText(QtGui.QApplication.translate("jassdlg", "C", None, QtGui.QApplication.UnicodeUTF8))
        self.FR4.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the exit code operations (N E A C) are to be reversed if\n"
"possible.\n"
"\n"
"Note that only add subtract multiply and divide can be reversed.", None, QtGui.QApplication.UnicodeUTF8))
        self.FR4.setText(QtGui.QApplication.translate("jassdlg", "R", None, QtGui.QApplication.UnicodeUTF8))
        self.textval4.setToolTip(QtGui.QApplication.translate("jassdlg", "Give the text value to be assigned here", None, QtGui.QApplication.UnicodeUTF8))
        self.asstext4.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicate that the value to be assigned is text", None, QtGui.QApplication.UnicodeUTF8))
        self.asstext4.setText(QtGui.QApplication.translate("jassdlg", "Text", None, QtGui.QApplication.UnicodeUTF8))
        self.intval4.setToolTip(QtGui.QApplication.translate("jassdlg", "Give the integer value to be used here", None, QtGui.QApplication.UnicodeUTF8))
        self.ac4.setToolTip(QtGui.QApplication.translate("jassdlg", "This is a critical assignment\n"
"\n"
"If set and the host with the variable is not running, then the job is held.\n"
"\n"
"If it is not set and the host with the variable is not running, then the\n"
"assignment is ignored.", None, QtGui.QApplication.UnicodeUTF8))
        self.ac4.setText(QtGui.QApplication.translate("jassdlg", "Acrit", None, QtGui.QApplication.UnicodeUTF8))
        self.assvar5.setToolTip(QtGui.QApplication.translate("jassdlg", "This is the variable to be assigned to", None, QtGui.QApplication.UnicodeUTF8))
        self.assvar5.setItemText(0, QtGui.QApplication.translate("jassdlg", "(no variable)", None, QtGui.QApplication.UnicodeUTF8))
        self.assop5.setToolTip(QtGui.QApplication.translate("jassdlg", "This is the operation to be performed", None, QtGui.QApplication.UnicodeUTF8))
        self.assop5.setItemText(0, QtGui.QApplication.translate("jassdlg", "(none)", None, QtGui.QApplication.UnicodeUTF8))
        self.assop5.setItemText(1, QtGui.QApplication.translate("jassdlg", "Set", None, QtGui.QApplication.UnicodeUTF8))
        self.assop5.setItemText(2, QtGui.QApplication.translate("jassdlg", "Add", None, QtGui.QApplication.UnicodeUTF8))
        self.assop5.setItemText(3, QtGui.QApplication.translate("jassdlg", "Subtract", None, QtGui.QApplication.UnicodeUTF8))
        self.assop5.setItemText(4, QtGui.QApplication.translate("jassdlg", "Multiply", None, QtGui.QApplication.UnicodeUTF8))
        self.assop5.setItemText(5, QtGui.QApplication.translate("jassdlg", "Divide", None, QtGui.QApplication.UnicodeUTF8))
        self.assop5.setItemText(6, QtGui.QApplication.translate("jassdlg", "Modulus", None, QtGui.QApplication.UnicodeUTF8))
        self.assop5.setItemText(7, QtGui.QApplication.translate("jassdlg", "Set Exit", None, QtGui.QApplication.UnicodeUTF8))
        self.assop5.setItemText(8, QtGui.QApplication.translate("jassdlg", "Set Signal", None, QtGui.QApplication.UnicodeUTF8))
        self.FS5.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job starts", None, QtGui.QApplication.UnicodeUTF8))
        self.FS5.setText(QtGui.QApplication.translate("jassdlg", "S", None, QtGui.QApplication.UnicodeUTF8))
        self.FN5.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job\n"
"exits normally (as indicated by the exit code settings).", None, QtGui.QApplication.UnicodeUTF8))
        self.FN5.setText(QtGui.QApplication.translate("jassdlg", "N", None, QtGui.QApplication.UnicodeUTF8))
        self.FE5.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job\n"
"exits with an error code (as indicated by the exit code settings).", None, QtGui.QApplication.UnicodeUTF8))
        self.FE5.setText(QtGui.QApplication.translate("jassdlg", "E", None, QtGui.QApplication.UnicodeUTF8))
        self.FA5.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job\n"
"aborts - either exits with a signal, or with an error code not covered\n"
"by the job exit code settings.", None, QtGui.QApplication.UnicodeUTF8))
        self.FA5.setText(QtGui.QApplication.translate("jassdlg", "A", None, QtGui.QApplication.UnicodeUTF8))
        self.FC5.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job\n"
"is cancelled (killed with a signal before it is run).", None, QtGui.QApplication.UnicodeUTF8))
        self.FC5.setText(QtGui.QApplication.translate("jassdlg", "C", None, QtGui.QApplication.UnicodeUTF8))
        self.FR5.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the exit code operations (N E A C) are to be reversed if\n"
"possible.\n"
"\n"
"Note that only add subtract multiply and divide can be reversed.", None, QtGui.QApplication.UnicodeUTF8))
        self.FR5.setText(QtGui.QApplication.translate("jassdlg", "R", None, QtGui.QApplication.UnicodeUTF8))
        self.textval5.setToolTip(QtGui.QApplication.translate("jassdlg", "Give the text value to be assigned here", None, QtGui.QApplication.UnicodeUTF8))
        self.asstext5.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicate that the value to be assigned is text", None, QtGui.QApplication.UnicodeUTF8))
        self.asstext5.setText(QtGui.QApplication.translate("jassdlg", "Text", None, QtGui.QApplication.UnicodeUTF8))
        self.intval5.setToolTip(QtGui.QApplication.translate("jassdlg", "Give the integer value to be used here", None, QtGui.QApplication.UnicodeUTF8))
        self.ac5.setToolTip(QtGui.QApplication.translate("jassdlg", "This is a critical assignment\n"
"\n"
"If set and the host with the variable is not running, then the job is held.\n"
"\n"
"If it is not set and the host with the variable is not running, then the\n"
"assignment is ignored.", None, QtGui.QApplication.UnicodeUTF8))
        self.ac5.setText(QtGui.QApplication.translate("jassdlg", "Acrit", None, QtGui.QApplication.UnicodeUTF8))
        self.assvar6.setToolTip(QtGui.QApplication.translate("jassdlg", "This is the variable to be assigned to", None, QtGui.QApplication.UnicodeUTF8))
        self.assvar6.setItemText(0, QtGui.QApplication.translate("jassdlg", "(no variable)", None, QtGui.QApplication.UnicodeUTF8))
        self.assop6.setToolTip(QtGui.QApplication.translate("jassdlg", "This is the operation to be performed", None, QtGui.QApplication.UnicodeUTF8))
        self.assop6.setItemText(0, QtGui.QApplication.translate("jassdlg", "(none)", None, QtGui.QApplication.UnicodeUTF8))
        self.assop6.setItemText(1, QtGui.QApplication.translate("jassdlg", "Set", None, QtGui.QApplication.UnicodeUTF8))
        self.assop6.setItemText(2, QtGui.QApplication.translate("jassdlg", "Add", None, QtGui.QApplication.UnicodeUTF8))
        self.assop6.setItemText(3, QtGui.QApplication.translate("jassdlg", "Subtract", None, QtGui.QApplication.UnicodeUTF8))
        self.assop6.setItemText(4, QtGui.QApplication.translate("jassdlg", "Multiply", None, QtGui.QApplication.UnicodeUTF8))
        self.assop6.setItemText(5, QtGui.QApplication.translate("jassdlg", "Divide", None, QtGui.QApplication.UnicodeUTF8))
        self.assop6.setItemText(6, QtGui.QApplication.translate("jassdlg", "Modulus", None, QtGui.QApplication.UnicodeUTF8))
        self.assop6.setItemText(7, QtGui.QApplication.translate("jassdlg", "Set Exit", None, QtGui.QApplication.UnicodeUTF8))
        self.assop6.setItemText(8, QtGui.QApplication.translate("jassdlg", "Set Signal", None, QtGui.QApplication.UnicodeUTF8))
        self.FS6.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job starts", None, QtGui.QApplication.UnicodeUTF8))
        self.FS6.setText(QtGui.QApplication.translate("jassdlg", "S", None, QtGui.QApplication.UnicodeUTF8))
        self.FN6.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job\n"
"exits normally (as indicated by the exit code settings).", None, QtGui.QApplication.UnicodeUTF8))
        self.FN6.setText(QtGui.QApplication.translate("jassdlg", "N", None, QtGui.QApplication.UnicodeUTF8))
        self.FE6.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job\n"
"exits with an error code (as indicated by the exit code settings).", None, QtGui.QApplication.UnicodeUTF8))
        self.FE6.setText(QtGui.QApplication.translate("jassdlg", "E", None, QtGui.QApplication.UnicodeUTF8))
        self.FA6.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job\n"
"aborts - either exits with a signal, or with an error code not covered\n"
"by the job exit code settings.", None, QtGui.QApplication.UnicodeUTF8))
        self.FA6.setText(QtGui.QApplication.translate("jassdlg", "A", None, QtGui.QApplication.UnicodeUTF8))
        self.FC6.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job\n"
"is cancelled (killed with a signal before it is run).", None, QtGui.QApplication.UnicodeUTF8))
        self.FC6.setText(QtGui.QApplication.translate("jassdlg", "C", None, QtGui.QApplication.UnicodeUTF8))
        self.FR6.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the exit code operations (N E A C) are to be reversed if\n"
"possible.\n"
"\n"
"Note that only add subtract multiply and divide can be reversed.", None, QtGui.QApplication.UnicodeUTF8))
        self.FR6.setText(QtGui.QApplication.translate("jassdlg", "R", None, QtGui.QApplication.UnicodeUTF8))
        self.textval6.setToolTip(QtGui.QApplication.translate("jassdlg", "Give the text value to be assigned here", None, QtGui.QApplication.UnicodeUTF8))
        self.asstext6.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicate that the value to be assigned is text", None, QtGui.QApplication.UnicodeUTF8))
        self.asstext6.setText(QtGui.QApplication.translate("jassdlg", "Text", None, QtGui.QApplication.UnicodeUTF8))
        self.intval6.setToolTip(QtGui.QApplication.translate("jassdlg", "Give the integer value to be used here", None, QtGui.QApplication.UnicodeUTF8))
        self.ac6.setToolTip(QtGui.QApplication.translate("jassdlg", "This is a critical assignment\n"
"\n"
"If set and the host with the variable is not running, then the job is held.\n"
"\n"
"If it is not set and the host with the variable is not running, then the\n"
"assignment is ignored.", None, QtGui.QApplication.UnicodeUTF8))
        self.ac6.setText(QtGui.QApplication.translate("jassdlg", "Acrit", None, QtGui.QApplication.UnicodeUTF8))
        self.assvar7.setToolTip(QtGui.QApplication.translate("jassdlg", "This is the variable to be assigned to", None, QtGui.QApplication.UnicodeUTF8))
        self.assvar7.setItemText(0, QtGui.QApplication.translate("jassdlg", "(no variable)", None, QtGui.QApplication.UnicodeUTF8))
        self.assop7.setToolTip(QtGui.QApplication.translate("jassdlg", "This is the operation to be performed", None, QtGui.QApplication.UnicodeUTF8))
        self.assop7.setItemText(0, QtGui.QApplication.translate("jassdlg", "(none)", None, QtGui.QApplication.UnicodeUTF8))
        self.assop7.setItemText(1, QtGui.QApplication.translate("jassdlg", "Set", None, QtGui.QApplication.UnicodeUTF8))
        self.assop7.setItemText(2, QtGui.QApplication.translate("jassdlg", "Add", None, QtGui.QApplication.UnicodeUTF8))
        self.assop7.setItemText(3, QtGui.QApplication.translate("jassdlg", "Subtract", None, QtGui.QApplication.UnicodeUTF8))
        self.assop7.setItemText(4, QtGui.QApplication.translate("jassdlg", "Multiply", None, QtGui.QApplication.UnicodeUTF8))
        self.assop7.setItemText(5, QtGui.QApplication.translate("jassdlg", "Divide", None, QtGui.QApplication.UnicodeUTF8))
        self.assop7.setItemText(6, QtGui.QApplication.translate("jassdlg", "Modulus", None, QtGui.QApplication.UnicodeUTF8))
        self.assop7.setItemText(7, QtGui.QApplication.translate("jassdlg", "Set Exit", None, QtGui.QApplication.UnicodeUTF8))
        self.assop7.setItemText(8, QtGui.QApplication.translate("jassdlg", "Set Signal", None, QtGui.QApplication.UnicodeUTF8))
        self.FS7.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job starts", None, QtGui.QApplication.UnicodeUTF8))
        self.FS7.setText(QtGui.QApplication.translate("jassdlg", "S", None, QtGui.QApplication.UnicodeUTF8))
        self.FN7.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job\n"
"exits normally (as indicated by the exit code settings).", None, QtGui.QApplication.UnicodeUTF8))
        self.FN7.setText(QtGui.QApplication.translate("jassdlg", "N", None, QtGui.QApplication.UnicodeUTF8))
        self.FE7.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job\n"
"exits with an error code (as indicated by the exit code settings).", None, QtGui.QApplication.UnicodeUTF8))
        self.FE7.setText(QtGui.QApplication.translate("jassdlg", "E", None, QtGui.QApplication.UnicodeUTF8))
        self.FA7.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job\n"
"aborts - either exits with a signal, or with an error code not covered\n"
"by the job exit code settings.", None, QtGui.QApplication.UnicodeUTF8))
        self.FA7.setText(QtGui.QApplication.translate("jassdlg", "A", None, QtGui.QApplication.UnicodeUTF8))
        self.FC7.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the operation is to be performed when the job\n"
"is cancelled (killed with a signal before it is run).", None, QtGui.QApplication.UnicodeUTF8))
        self.FC7.setText(QtGui.QApplication.translate("jassdlg", "C", None, QtGui.QApplication.UnicodeUTF8))
        self.FR7.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicates that the exit code operations (N E A C) are to be reversed if\n"
"possible.\n"
"\n"
"Note that only add subtract multiply and divide can be reversed.", None, QtGui.QApplication.UnicodeUTF8))
        self.FR7.setText(QtGui.QApplication.translate("jassdlg", "R", None, QtGui.QApplication.UnicodeUTF8))
        self.textval7.setToolTip(QtGui.QApplication.translate("jassdlg", "Give the text value to be assigned here", None, QtGui.QApplication.UnicodeUTF8))
        self.asstext7.setToolTip(QtGui.QApplication.translate("jassdlg", "Indicate that the value to be assigned is text", None, QtGui.QApplication.UnicodeUTF8))
        self.asstext7.setText(QtGui.QApplication.translate("jassdlg", "Text", None, QtGui.QApplication.UnicodeUTF8))
        self.intval7.setToolTip(QtGui.QApplication.translate("jassdlg", "Give the integer value to be used here", None, QtGui.QApplication.UnicodeUTF8))
        self.ac7.setToolTip(QtGui.QApplication.translate("jassdlg", "This is a critical assignment\n"
"\n"
"If set and the host with the variable is not running, then the job is held.\n"
"\n"
"If it is not set and the host with the variable is not running, then the\n"
"assignment is ignored.", None, QtGui.QApplication.UnicodeUTF8))
        self.ac7.setText(QtGui.QApplication.translate("jassdlg", "Acrit", None, QtGui.QApplication.UnicodeUTF8))

