# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'vpermdlg.ui'
#
# Created: Sun Nov 25 19:49:47 2012
#      by: PyQt4 UI code generator 4.9.1
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    _fromUtf8 = lambda s: s

class Ui_vpermdlg(object):
    def setupUi(self, vpermdlg):
        vpermdlg.setObjectName(_fromUtf8("vpermdlg"))
        vpermdlg.resize(465, 458)
        self.buttonBox = QtGui.QDialogButtonBox(vpermdlg)
        self.buttonBox.setGeometry(QtCore.QRect(250, 400, 191, 32))
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtGui.QDialogButtonBox.Cancel|QtGui.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName(_fromUtf8("buttonBox"))
        self.edvar = QtGui.QLabel(vpermdlg)
        self.edvar.setGeometry(QtCore.QRect(110, 30, 301, 17))
        self.edvar.setText(_fromUtf8(""))
        self.edvar.setObjectName(_fromUtf8("edvar"))
        self.label = QtGui.QLabel(vpermdlg)
        self.label.setGeometry(QtCore.QRect(10, 30, 101, 17))
        self.label.setObjectName(_fromUtf8("label"))
        self.layoutWidget = QtGui.QWidget(vpermdlg)
        self.layoutWidget.setGeometry(QtCore.QRect(60, 70, 313, 304))
        self.layoutWidget.setObjectName(_fromUtf8("layoutWidget"))
        self.gridLayout = QtGui.QGridLayout(self.layoutWidget)
        self.gridLayout.setMargin(0)
        self.gridLayout.setObjectName(_fromUtf8("gridLayout"))
        self.urdmd = QtGui.QCheckBox(self.layoutWidget)
        self.urdmd.setObjectName(_fromUtf8("urdmd"))
        self.gridLayout.addWidget(self.urdmd, 3, 1, 1, 1)
        self.gshow = QtGui.QCheckBox(self.layoutWidget)
        self.gshow.setObjectName(_fromUtf8("gshow"))
        self.gridLayout.addWidget(self.gshow, 2, 2, 1, 1)
        self.odel = QtGui.QCheckBox(self.layoutWidget)
        self.odel.setObjectName(_fromUtf8("odel"))
        self.gridLayout.addWidget(self.odel, 9, 3, 1, 1)
        self.gread = QtGui.QCheckBox(self.layoutWidget)
        self.gread.setObjectName(_fromUtf8("gread"))
        self.gridLayout.addWidget(self.gread, 0, 2, 1, 1)
        self.label_11 = QtGui.QLabel(self.layoutWidget)
        self.label_11.setObjectName(_fromUtf8("label_11"))
        self.gridLayout.addWidget(self.label_11, 9, 0, 1, 1)
        self.grdmd = QtGui.QCheckBox(self.layoutWidget)
        self.grdmd.setObjectName(_fromUtf8("grdmd"))
        self.gridLayout.addWidget(self.grdmd, 3, 2, 1, 1)
        self.label_8 = QtGui.QLabel(self.layoutWidget)
        self.label_8.setObjectName(_fromUtf8("label_8"))
        self.gridLayout.addWidget(self.label_8, 6, 0, 1, 1)
        self.ushow = QtGui.QCheckBox(self.layoutWidget)
        self.ushow.setObjectName(_fromUtf8("ushow"))
        self.gridLayout.addWidget(self.ushow, 2, 1, 1, 1)
        self.owrite = QtGui.QCheckBox(self.layoutWidget)
        self.owrite.setObjectName(_fromUtf8("owrite"))
        self.gridLayout.addWidget(self.owrite, 1, 3, 1, 1)
        self.label_5 = QtGui.QLabel(self.layoutWidget)
        self.label_5.setObjectName(_fromUtf8("label_5"))
        self.gridLayout.addWidget(self.label_5, 3, 0, 1, 1)
        self.uwrite = QtGui.QCheckBox(self.layoutWidget)
        self.uwrite.setObjectName(_fromUtf8("uwrite"))
        self.gridLayout.addWidget(self.uwrite, 1, 1, 1, 1)
        self.oggive = QtGui.QCheckBox(self.layoutWidget)
        self.oggive.setObjectName(_fromUtf8("oggive"))
        self.gridLayout.addWidget(self.oggive, 8, 3, 1, 1)
        self.ggtake = QtGui.QCheckBox(self.layoutWidget)
        self.ggtake.setObjectName(_fromUtf8("ggtake"))
        self.gridLayout.addWidget(self.ggtake, 6, 2, 1, 1)
        self.ogive = QtGui.QCheckBox(self.layoutWidget)
        self.ogive.setObjectName(_fromUtf8("ogive"))
        self.gridLayout.addWidget(self.ogive, 7, 3, 1, 1)
        self.label_3 = QtGui.QLabel(self.layoutWidget)
        self.label_3.setObjectName(_fromUtf8("label_3"))
        self.gridLayout.addWidget(self.label_3, 1, 0, 1, 1)
        self.gggive = QtGui.QCheckBox(self.layoutWidget)
        self.gggive.setObjectName(_fromUtf8("gggive"))
        self.gridLayout.addWidget(self.gggive, 8, 2, 1, 1)
        self.gtake = QtGui.QCheckBox(self.layoutWidget)
        self.gtake.setObjectName(_fromUtf8("gtake"))
        self.gridLayout.addWidget(self.gtake, 5, 2, 1, 1)
        self.gwrmd = QtGui.QCheckBox(self.layoutWidget)
        self.gwrmd.setObjectName(_fromUtf8("gwrmd"))
        self.gridLayout.addWidget(self.gwrmd, 4, 2, 1, 1)
        self.oshow = QtGui.QCheckBox(self.layoutWidget)
        self.oshow.setObjectName(_fromUtf8("oshow"))
        self.gridLayout.addWidget(self.oshow, 2, 3, 1, 1)
        self.label_4 = QtGui.QLabel(self.layoutWidget)
        self.label_4.setObjectName(_fromUtf8("label_4"))
        self.gridLayout.addWidget(self.label_4, 2, 0, 1, 1)
        self.ggive = QtGui.QCheckBox(self.layoutWidget)
        self.ggive.setObjectName(_fromUtf8("ggive"))
        self.gridLayout.addWidget(self.ggive, 7, 2, 1, 1)
        self.udel = QtGui.QCheckBox(self.layoutWidget)
        self.udel.setObjectName(_fromUtf8("udel"))
        self.gridLayout.addWidget(self.udel, 9, 1, 1, 1)
        self.label_9 = QtGui.QLabel(self.layoutWidget)
        self.label_9.setObjectName(_fromUtf8("label_9"))
        self.gridLayout.addWidget(self.label_9, 7, 0, 1, 1)
        self.ordmd = QtGui.QCheckBox(self.layoutWidget)
        self.ordmd.setObjectName(_fromUtf8("ordmd"))
        self.gridLayout.addWidget(self.ordmd, 3, 3, 1, 1)
        self.label_2 = QtGui.QLabel(self.layoutWidget)
        self.label_2.setObjectName(_fromUtf8("label_2"))
        self.gridLayout.addWidget(self.label_2, 0, 0, 1, 1)
        self.utake = QtGui.QCheckBox(self.layoutWidget)
        self.utake.setObjectName(_fromUtf8("utake"))
        self.gridLayout.addWidget(self.utake, 5, 1, 1, 1)
        self.label_10 = QtGui.QLabel(self.layoutWidget)
        self.label_10.setObjectName(_fromUtf8("label_10"))
        self.gridLayout.addWidget(self.label_10, 8, 0, 1, 1)
        self.ugtake = QtGui.QCheckBox(self.layoutWidget)
        self.ugtake.setObjectName(_fromUtf8("ugtake"))
        self.gridLayout.addWidget(self.ugtake, 6, 1, 1, 1)
        self.uread = QtGui.QCheckBox(self.layoutWidget)
        self.uread.setObjectName(_fromUtf8("uread"))
        self.gridLayout.addWidget(self.uread, 0, 1, 1, 1)
        self.uggive = QtGui.QCheckBox(self.layoutWidget)
        self.uggive.setObjectName(_fromUtf8("uggive"))
        self.gridLayout.addWidget(self.uggive, 8, 1, 1, 1)
        self.label_7 = QtGui.QLabel(self.layoutWidget)
        self.label_7.setObjectName(_fromUtf8("label_7"))
        self.gridLayout.addWidget(self.label_7, 5, 0, 1, 1)
        self.otake = QtGui.QCheckBox(self.layoutWidget)
        self.otake.setObjectName(_fromUtf8("otake"))
        self.gridLayout.addWidget(self.otake, 5, 3, 1, 1)
        self.ogtake = QtGui.QCheckBox(self.layoutWidget)
        self.ogtake.setObjectName(_fromUtf8("ogtake"))
        self.gridLayout.addWidget(self.ogtake, 6, 3, 1, 1)
        self.owrmd = QtGui.QCheckBox(self.layoutWidget)
        self.owrmd.setObjectName(_fromUtf8("owrmd"))
        self.gridLayout.addWidget(self.owrmd, 4, 3, 1, 1)
        self.gdel = QtGui.QCheckBox(self.layoutWidget)
        self.gdel.setObjectName(_fromUtf8("gdel"))
        self.gridLayout.addWidget(self.gdel, 9, 2, 1, 1)
        self.label_6 = QtGui.QLabel(self.layoutWidget)
        self.label_6.setObjectName(_fromUtf8("label_6"))
        self.gridLayout.addWidget(self.label_6, 4, 0, 1, 1)
        self.ugive = QtGui.QCheckBox(self.layoutWidget)
        self.ugive.setObjectName(_fromUtf8("ugive"))
        self.gridLayout.addWidget(self.ugive, 7, 1, 1, 1)
        self.oread = QtGui.QCheckBox(self.layoutWidget)
        self.oread.setObjectName(_fromUtf8("oread"))
        self.gridLayout.addWidget(self.oread, 0, 3, 1, 1)
        self.uwrmd = QtGui.QCheckBox(self.layoutWidget)
        self.uwrmd.setObjectName(_fromUtf8("uwrmd"))
        self.gridLayout.addWidget(self.uwrmd, 4, 1, 1, 1)
        self.gwrite = QtGui.QCheckBox(self.layoutWidget)
        self.gwrite.setObjectName(_fromUtf8("gwrite"))
        self.gridLayout.addWidget(self.gwrite, 1, 2, 1, 1)

        self.retranslateUi(vpermdlg)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("accepted()")), vpermdlg.accept)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("rejected()")), vpermdlg.reject)
        QtCore.QMetaObject.connectSlotsByName(vpermdlg)
        vpermdlg.setTabOrder(self.uread, self.gread)
        vpermdlg.setTabOrder(self.gread, self.oread)
        vpermdlg.setTabOrder(self.oread, self.uwrite)
        vpermdlg.setTabOrder(self.uwrite, self.gwrite)
        vpermdlg.setTabOrder(self.gwrite, self.owrite)
        vpermdlg.setTabOrder(self.owrite, self.ushow)
        vpermdlg.setTabOrder(self.ushow, self.gshow)
        vpermdlg.setTabOrder(self.gshow, self.oshow)
        vpermdlg.setTabOrder(self.oshow, self.urdmd)
        vpermdlg.setTabOrder(self.urdmd, self.grdmd)
        vpermdlg.setTabOrder(self.grdmd, self.ordmd)
        vpermdlg.setTabOrder(self.ordmd, self.uwrmd)
        vpermdlg.setTabOrder(self.uwrmd, self.gwrmd)
        vpermdlg.setTabOrder(self.gwrmd, self.owrmd)
        vpermdlg.setTabOrder(self.owrmd, self.utake)
        vpermdlg.setTabOrder(self.utake, self.gtake)
        vpermdlg.setTabOrder(self.gtake, self.otake)
        vpermdlg.setTabOrder(self.otake, self.ugtake)
        vpermdlg.setTabOrder(self.ugtake, self.ggtake)
        vpermdlg.setTabOrder(self.ggtake, self.ogtake)
        vpermdlg.setTabOrder(self.ogtake, self.ugive)
        vpermdlg.setTabOrder(self.ugive, self.ggive)
        vpermdlg.setTabOrder(self.ggive, self.ogive)
        vpermdlg.setTabOrder(self.ogive, self.uggive)
        vpermdlg.setTabOrder(self.uggive, self.gggive)
        vpermdlg.setTabOrder(self.gggive, self.oggive)
        vpermdlg.setTabOrder(self.oggive, self.udel)
        vpermdlg.setTabOrder(self.udel, self.gdel)
        vpermdlg.setTabOrder(self.gdel, self.odel)
        vpermdlg.setTabOrder(self.odel, self.buttonBox)

    def retranslateUi(self, vpermdlg):
        vpermdlg.setWindowTitle(QtGui.QApplication.translate("vpermdlg", "Variable permissions", None, QtGui.QApplication.UnicodeUTF8))
        self.label.setText(QtGui.QApplication.translate("vpermdlg", "Perms on var:", None, QtGui.QApplication.UnicodeUTF8))
        self.urdmd.setToolTip(QtGui.QApplication.translate("vpermdlg", "Indicates that the user can read the permissions", None, QtGui.QApplication.UnicodeUTF8))
        self.urdmd.setText(QtGui.QApplication.translate("vpermdlg", "U", None, QtGui.QApplication.UnicodeUTF8))
        self.gshow.setToolTip(QtGui.QApplication.translate("vpermdlg", "Indicates that group  has reveal (is visible) permission", None, QtGui.QApplication.UnicodeUTF8))
        self.gshow.setText(QtGui.QApplication.translate("vpermdlg", "G", None, QtGui.QApplication.UnicodeUTF8))
        self.odel.setToolTip(QtGui.QApplication.translate("vpermdlg", "Indicates that others can delete the variable", None, QtGui.QApplication.UnicodeUTF8))
        self.odel.setText(QtGui.QApplication.translate("vpermdlg", "O", None, QtGui.QApplication.UnicodeUTF8))
        self.gread.setToolTip(QtGui.QApplication.translate("vpermdlg", "Indicates that group has read permission", None, QtGui.QApplication.UnicodeUTF8))
        self.gread.setText(QtGui.QApplication.translate("vpermdlg", "G", None, QtGui.QApplication.UnicodeUTF8))
        self.label_11.setText(QtGui.QApplication.translate("vpermdlg", "Delete", None, QtGui.QApplication.UnicodeUTF8))
        self.grdmd.setToolTip(QtGui.QApplication.translate("vpermdlg", "Indicates that the group can read the permissions", None, QtGui.QApplication.UnicodeUTF8))
        self.grdmd.setText(QtGui.QApplication.translate("vpermdlg", "G", None, QtGui.QApplication.UnicodeUTF8))
        self.label_8.setText(QtGui.QApplication.translate("vpermdlg", "Assume group ownership", None, QtGui.QApplication.UnicodeUTF8))
        self.ushow.setToolTip(QtGui.QApplication.translate("vpermdlg", "Indicates that user has reveal (is visible) permission", None, QtGui.QApplication.UnicodeUTF8))
        self.ushow.setText(QtGui.QApplication.translate("vpermdlg", "U", None, QtGui.QApplication.UnicodeUTF8))
        self.owrite.setToolTip(QtGui.QApplication.translate("vpermdlg", "Indicates that others have write permission", None, QtGui.QApplication.UnicodeUTF8))
        self.owrite.setText(QtGui.QApplication.translate("vpermdlg", "O", None, QtGui.QApplication.UnicodeUTF8))
        self.label_5.setText(QtGui.QApplication.translate("vpermdlg", "Display mode", None, QtGui.QApplication.UnicodeUTF8))
        self.uwrite.setToolTip(QtGui.QApplication.translate("vpermdlg", "Indicates that user has write permission", None, QtGui.QApplication.UnicodeUTF8))
        self.uwrite.setText(QtGui.QApplication.translate("vpermdlg", "U", None, QtGui.QApplication.UnicodeUTF8))
        self.oggive.setToolTip(QtGui.QApplication.translate("vpermdlg", "Indicates that others can give away group ownership", None, QtGui.QApplication.UnicodeUTF8))
        self.oggive.setText(QtGui.QApplication.translate("vpermdlg", "O", None, QtGui.QApplication.UnicodeUTF8))
        self.ggtake.setToolTip(QtGui.QApplication.translate("vpermdlg", "Indicates that group can set the group", None, QtGui.QApplication.UnicodeUTF8))
        self.ggtake.setText(QtGui.QApplication.translate("vpermdlg", "G", None, QtGui.QApplication.UnicodeUTF8))
        self.ogive.setToolTip(QtGui.QApplication.translate("vpermdlg", "Indicates that others can give away ownership", None, QtGui.QApplication.UnicodeUTF8))
        self.ogive.setText(QtGui.QApplication.translate("vpermdlg", "O", None, QtGui.QApplication.UnicodeUTF8))
        self.label_3.setText(QtGui.QApplication.translate("vpermdlg", "Write", None, QtGui.QApplication.UnicodeUTF8))
        self.gggive.setToolTip(QtGui.QApplication.translate("vpermdlg", "Indicates that group can give away group ownership", None, QtGui.QApplication.UnicodeUTF8))
        self.gggive.setText(QtGui.QApplication.translate("vpermdlg", "G", None, QtGui.QApplication.UnicodeUTF8))
        self.gtake.setToolTip(QtGui.QApplication.translate("vpermdlg", "Indicates that group can set the owner", None, QtGui.QApplication.UnicodeUTF8))
        self.gtake.setText(QtGui.QApplication.translate("vpermdlg", "G", None, QtGui.QApplication.UnicodeUTF8))
        self.gwrmd.setToolTip(QtGui.QApplication.translate("vpermdlg", "Indicates that group can set permissions", None, QtGui.QApplication.UnicodeUTF8))
        self.gwrmd.setText(QtGui.QApplication.translate("vpermdlg", "G", None, QtGui.QApplication.UnicodeUTF8))
        self.oshow.setToolTip(QtGui.QApplication.translate("vpermdlg", "Indicates that others have  reveal (is visible) permission", None, QtGui.QApplication.UnicodeUTF8))
        self.oshow.setText(QtGui.QApplication.translate("vpermdlg", "O", None, QtGui.QApplication.UnicodeUTF8))
        self.label_4.setText(QtGui.QApplication.translate("vpermdlg", "Reveal", None, QtGui.QApplication.UnicodeUTF8))
        self.ggive.setToolTip(QtGui.QApplication.translate("vpermdlg", "Indicates that group can give away ownership", None, QtGui.QApplication.UnicodeUTF8))
        self.ggive.setText(QtGui.QApplication.translate("vpermdlg", "G", None, QtGui.QApplication.UnicodeUTF8))
        self.udel.setToolTip(QtGui.QApplication.translate("vpermdlg", "Indicates that user can delete the variable", None, QtGui.QApplication.UnicodeUTF8))
        self.udel.setText(QtGui.QApplication.translate("vpermdlg", "U", None, QtGui.QApplication.UnicodeUTF8))
        self.label_9.setText(QtGui.QApplication.translate("vpermdlg", "Give away owner", None, QtGui.QApplication.UnicodeUTF8))
        self.ordmd.setToolTip(QtGui.QApplication.translate("vpermdlg", "Indicates that others can read the permissions", None, QtGui.QApplication.UnicodeUTF8))
        self.ordmd.setText(QtGui.QApplication.translate("vpermdlg", "O", None, QtGui.QApplication.UnicodeUTF8))
        self.label_2.setText(QtGui.QApplication.translate("vpermdlg", "Read", None, QtGui.QApplication.UnicodeUTF8))
        self.utake.setToolTip(QtGui.QApplication.translate("vpermdlg", "Indicates that user can set the owner to him/herself", None, QtGui.QApplication.UnicodeUTF8))
        self.utake.setText(QtGui.QApplication.translate("vpermdlg", "U", None, QtGui.QApplication.UnicodeUTF8))
        self.label_10.setText(QtGui.QApplication.translate("vpermdlg", "Give away group", None, QtGui.QApplication.UnicodeUTF8))
        self.ugtake.setToolTip(QtGui.QApplication.translate("vpermdlg", "Indicates that user can set the group to his/her own", None, QtGui.QApplication.UnicodeUTF8))
        self.ugtake.setText(QtGui.QApplication.translate("vpermdlg", "U", None, QtGui.QApplication.UnicodeUTF8))
        self.uread.setToolTip(QtGui.QApplication.translate("vpermdlg", "Indicates that user has read permission", None, QtGui.QApplication.UnicodeUTF8))
        self.uread.setText(QtGui.QApplication.translate("vpermdlg", "U", None, QtGui.QApplication.UnicodeUTF8))
        self.uggive.setToolTip(QtGui.QApplication.translate("vpermdlg", "Indicates that user can give away the group ownership", None, QtGui.QApplication.UnicodeUTF8))
        self.uggive.setText(QtGui.QApplication.translate("vpermdlg", "U", None, QtGui.QApplication.UnicodeUTF8))
        self.label_7.setText(QtGui.QApplication.translate("vpermdlg", "Assume ownership", None, QtGui.QApplication.UnicodeUTF8))
        self.otake.setToolTip(QtGui.QApplication.translate("vpermdlg", "Indicates that others can set the owner", None, QtGui.QApplication.UnicodeUTF8))
        self.otake.setText(QtGui.QApplication.translate("vpermdlg", "O", None, QtGui.QApplication.UnicodeUTF8))
        self.ogtake.setToolTip(QtGui.QApplication.translate("vpermdlg", "Indicates that others can set the group", None, QtGui.QApplication.UnicodeUTF8))
        self.ogtake.setText(QtGui.QApplication.translate("vpermdlg", "O", None, QtGui.QApplication.UnicodeUTF8))
        self.owrmd.setToolTip(QtGui.QApplication.translate("vpermdlg", "Indicates that others can set permissions", None, QtGui.QApplication.UnicodeUTF8))
        self.owrmd.setText(QtGui.QApplication.translate("vpermdlg", "O", None, QtGui.QApplication.UnicodeUTF8))
        self.gdel.setToolTip(QtGui.QApplication.translate("vpermdlg", "Indicates that group can delete the variable", None, QtGui.QApplication.UnicodeUTF8))
        self.gdel.setText(QtGui.QApplication.translate("vpermdlg", "G", None, QtGui.QApplication.UnicodeUTF8))
        self.label_6.setText(QtGui.QApplication.translate("vpermdlg", "Set mode", None, QtGui.QApplication.UnicodeUTF8))
        self.ugive.setToolTip(QtGui.QApplication.translate("vpermdlg", "Indicates that user can give the variable to a different owner", None, QtGui.QApplication.UnicodeUTF8))
        self.ugive.setText(QtGui.QApplication.translate("vpermdlg", "U", None, QtGui.QApplication.UnicodeUTF8))
        self.oread.setToolTip(QtGui.QApplication.translate("vpermdlg", "Indicates that others have read permission", None, QtGui.QApplication.UnicodeUTF8))
        self.oread.setText(QtGui.QApplication.translate("vpermdlg", "O", None, QtGui.QApplication.UnicodeUTF8))
        self.uwrmd.setToolTip(QtGui.QApplication.translate("vpermdlg", "Indicates that user can set permissions", None, QtGui.QApplication.UnicodeUTF8))
        self.uwrmd.setText(QtGui.QApplication.translate("vpermdlg", "U", None, QtGui.QApplication.UnicodeUTF8))
        self.gwrite.setToolTip(QtGui.QApplication.translate("vpermdlg", "Indicates that group has write permission", None, QtGui.QApplication.UnicodeUTF8))
        self.gwrite.setText(QtGui.QApplication.translate("vpermdlg", "G", None, QtGui.QApplication.UnicodeUTF8))

