# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'othersigdlg.ui'
#
# Created: Mon Nov 26 19:44:53 2012
#      by: PyQt4 UI code generator 4.9.1
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    _fromUtf8 = lambda s: s

class Ui_othersigdlg(object):
    def setupUi(self, othersigdlg):
        othersigdlg.setObjectName(_fromUtf8("othersigdlg"))
        othersigdlg.resize(404, 413)
        self.groupBox = QtGui.QGroupBox(othersigdlg)
        self.groupBox.setGeometry(QtCore.QRect(40, 60, 201, 351))
        self.groupBox.setObjectName(_fromUtf8("groupBox"))
        self.stopsig = QtGui.QRadioButton(self.groupBox)
        self.stopsig.setGeometry(QtCore.QRect(40, 40, 116, 22))
        self.stopsig.setObjectName(_fromUtf8("stopsig"))
        self.contsig = QtGui.QRadioButton(self.groupBox)
        self.contsig.setGeometry(QtCore.QRect(40, 70, 116, 22))
        self.contsig.setObjectName(_fromUtf8("contsig"))
        self.termsig = QtGui.QRadioButton(self.groupBox)
        self.termsig.setGeometry(QtCore.QRect(40, 100, 116, 22))
        self.termsig.setChecked(True)
        self.termsig.setObjectName(_fromUtf8("termsig"))
        self.killsig = QtGui.QRadioButton(self.groupBox)
        self.killsig.setGeometry(QtCore.QRect(40, 130, 116, 22))
        self.killsig.setChecked(False)
        self.killsig.setObjectName(_fromUtf8("killsig"))
        self.hupsig = QtGui.QRadioButton(self.groupBox)
        self.hupsig.setGeometry(QtCore.QRect(40, 160, 116, 22))
        self.hupsig.setChecked(False)
        self.hupsig.setObjectName(_fromUtf8("hupsig"))
        self.intsig = QtGui.QRadioButton(self.groupBox)
        self.intsig.setGeometry(QtCore.QRect(40, 190, 116, 22))
        self.intsig.setChecked(False)
        self.intsig.setObjectName(_fromUtf8("intsig"))
        self.quitsig = QtGui.QRadioButton(self.groupBox)
        self.quitsig.setGeometry(QtCore.QRect(40, 220, 116, 22))
        self.quitsig.setChecked(False)
        self.quitsig.setObjectName(_fromUtf8("quitsig"))
        self.alarmsig = QtGui.QRadioButton(self.groupBox)
        self.alarmsig.setGeometry(QtCore.QRect(40, 250, 116, 22))
        self.alarmsig.setChecked(False)
        self.alarmsig.setObjectName(_fromUtf8("alarmsig"))
        self.bussig = QtGui.QRadioButton(self.groupBox)
        self.bussig.setGeometry(QtCore.QRect(40, 280, 116, 22))
        self.bussig.setChecked(False)
        self.bussig.setObjectName(_fromUtf8("bussig"))
        self.segvsig = QtGui.QRadioButton(self.groupBox)
        self.segvsig.setGeometry(QtCore.QRect(40, 310, 141, 22))
        self.segvsig.setChecked(False)
        self.segvsig.setObjectName(_fromUtf8("segvsig"))
        self.buttonBox = QtGui.QDialogButtonBox(othersigdlg)
        self.buttonBox.setGeometry(QtCore.QRect(290, 60, 81, 81))
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.buttonBox.sizePolicy().hasHeightForWidth())
        self.buttonBox.setSizePolicy(sizePolicy)
        self.buttonBox.setOrientation(QtCore.Qt.Vertical)
        self.buttonBox.setStandardButtons(QtGui.QDialogButtonBox.Cancel|QtGui.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName(_fromUtf8("buttonBox"))
        self.edjob = QtGui.QLabel(othersigdlg)
        self.edjob.setGeometry(QtCore.QRect(90, 20, 221, 17))
        self.edjob.setText(_fromUtf8(""))
        self.edjob.setObjectName(_fromUtf8("edjob"))
        self.label = QtGui.QLabel(othersigdlg)
        self.label.setGeometry(QtCore.QRect(30, 20, 61, 17))
        self.label.setObjectName(_fromUtf8("label"))

        self.retranslateUi(othersigdlg)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("accepted()")), othersigdlg.accept)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("rejected()")), othersigdlg.reject)
        QtCore.QMetaObject.connectSlotsByName(othersigdlg)
        othersigdlg.setTabOrder(self.stopsig, self.contsig)
        othersigdlg.setTabOrder(self.contsig, self.termsig)
        othersigdlg.setTabOrder(self.termsig, self.killsig)
        othersigdlg.setTabOrder(self.killsig, self.hupsig)
        othersigdlg.setTabOrder(self.hupsig, self.intsig)
        othersigdlg.setTabOrder(self.intsig, self.quitsig)
        othersigdlg.setTabOrder(self.quitsig, self.alarmsig)
        othersigdlg.setTabOrder(self.alarmsig, self.bussig)
        othersigdlg.setTabOrder(self.bussig, self.segvsig)
        othersigdlg.setTabOrder(self.segvsig, self.buttonBox)

    def retranslateUi(self, othersigdlg):
        othersigdlg.setWindowTitle(QtGui.QApplication.translate("othersigdlg", "Select signal to kill job", None, QtGui.QApplication.UnicodeUTF8))
        self.groupBox.setTitle(QtGui.QApplication.translate("othersigdlg", "Signal to use", None, QtGui.QApplication.UnicodeUTF8))
        self.stopsig.setToolTip(QtGui.QApplication.translate("othersigdlg", "Send the stop signal", None, QtGui.QApplication.UnicodeUTF8))
        self.stopsig.setText(QtGui.QApplication.translate("othersigdlg", "Stop", None, QtGui.QApplication.UnicodeUTF8))
        self.contsig.setToolTip(QtGui.QApplication.translate("othersigdlg", "Send the continue signal", None, QtGui.QApplication.UnicodeUTF8))
        self.contsig.setText(QtGui.QApplication.translate("othersigdlg", "Continue", None, QtGui.QApplication.UnicodeUTF8))
        self.termsig.setToolTip(QtGui.QApplication.translate("othersigdlg", "Send the terminate signal", None, QtGui.QApplication.UnicodeUTF8))
        self.termsig.setText(QtGui.QApplication.translate("othersigdlg", "Terminate", None, QtGui.QApplication.UnicodeUTF8))
        self.killsig.setToolTip(QtGui.QApplication.translate("othersigdlg", "Send the kill signal", None, QtGui.QApplication.UnicodeUTF8))
        self.killsig.setText(QtGui.QApplication.translate("othersigdlg", "Kill", None, QtGui.QApplication.UnicodeUTF8))
        self.hupsig.setToolTip(QtGui.QApplication.translate("othersigdlg", "Send the hangup signal", None, QtGui.QApplication.UnicodeUTF8))
        self.hupsig.setText(QtGui.QApplication.translate("othersigdlg", "Hangup", None, QtGui.QApplication.UnicodeUTF8))
        self.intsig.setToolTip(QtGui.QApplication.translate("othersigdlg", "Send the interrupt signal", None, QtGui.QApplication.UnicodeUTF8))
        self.intsig.setText(QtGui.QApplication.translate("othersigdlg", "Interrupt", None, QtGui.QApplication.UnicodeUTF8))
        self.quitsig.setToolTip(QtGui.QApplication.translate("othersigdlg", "Send the quit signal", None, QtGui.QApplication.UnicodeUTF8))
        self.quitsig.setText(QtGui.QApplication.translate("othersigdlg", "Quit", None, QtGui.QApplication.UnicodeUTF8))
        self.alarmsig.setToolTip(QtGui.QApplication.translate("othersigdlg", "Send the alarm signal", None, QtGui.QApplication.UnicodeUTF8))
        self.alarmsig.setText(QtGui.QApplication.translate("othersigdlg", "Alarm", None, QtGui.QApplication.UnicodeUTF8))
        self.bussig.setToolTip(QtGui.QApplication.translate("othersigdlg", "Send the bus error signal", None, QtGui.QApplication.UnicodeUTF8))
        self.bussig.setText(QtGui.QApplication.translate("othersigdlg", "Bus", None, QtGui.QApplication.UnicodeUTF8))
        self.segvsig.setToolTip(QtGui.QApplication.translate("othersigdlg", "Send the segmentation error signal", None, QtGui.QApplication.UnicodeUTF8))
        self.segvsig.setText(QtGui.QApplication.translate("othersigdlg", "Segmentation", None, QtGui.QApplication.UnicodeUTF8))
        self.label.setText(QtGui.QApplication.translate("othersigdlg", "Kill job:", None, QtGui.QApplication.UnicodeUTF8))

