# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'jcondsdlg.ui'
#
# Created: Fri Nov 23 23:14:34 2012
#      by: PyQt4 UI code generator 4.9.1
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    _fromUtf8 = lambda s: s

class Ui_jcondsdlg(object):
    def setupUi(self, jcondsdlg):
        jcondsdlg.setObjectName(_fromUtf8("jcondsdlg"))
        jcondsdlg.resize(852, 488)
        self.buttonBox = QtGui.QDialogButtonBox(jcondsdlg)
        self.buttonBox.setGeometry(QtCore.QRect(630, 440, 191, 32))
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtGui.QDialogButtonBox.Cancel|QtGui.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName(_fromUtf8("buttonBox"))
        self.edjob = QtGui.QLabel(jcondsdlg)
        self.edjob.setGeometry(QtCore.QRect(170, 20, 331, 17))
        self.edjob.setText(_fromUtf8(""))
        self.edjob.setObjectName(_fromUtf8("edjob"))
        self.label = QtGui.QLabel(jcondsdlg)
        self.label.setGeometry(QtCore.QRect(30, 20, 141, 17))
        self.label.setObjectName(_fromUtf8("label"))
        self.label_2 = QtGui.QLabel(jcondsdlg)
        self.label_2.setGeometry(QtCore.QRect(60, 60, 66, 17))
        self.label_2.setObjectName(_fromUtf8("label_2"))
        self.label_3 = QtGui.QLabel(jcondsdlg)
        self.label_3.setGeometry(QtCore.QRect(160, 60, 41, 17))
        self.label_3.setObjectName(_fromUtf8("label_3"))
        self.label_4 = QtGui.QLabel(jcondsdlg)
        self.label_4.setGeometry(QtCore.QRect(410, 60, 71, 17))
        self.label_4.setObjectName(_fromUtf8("label_4"))
        self.label_5 = QtGui.QLabel(jcondsdlg)
        self.label_5.setGeometry(QtCore.QRect(640, 60, 66, 17))
        self.label_5.setObjectName(_fromUtf8("label_5"))
        self.widget = QtGui.QWidget(jcondsdlg)
        self.widget.setGeometry(QtCore.QRect(40, 90, 761, 336))
        self.widget.setObjectName(_fromUtf8("widget"))
        self.gridLayout = QtGui.QGridLayout(self.widget)
        self.gridLayout.setMargin(0)
        self.gridLayout.setObjectName(_fromUtf8("gridLayout"))
        self.condvar0 = QtGui.QComboBox(self.widget)
        self.condvar0.setObjectName(_fromUtf8("condvar0"))
        self.condvar0.addItem(_fromUtf8(""))
        self.gridLayout.addWidget(self.condvar0, 0, 0, 1, 1)
        self.condop0 = QtGui.QComboBox(self.widget)
        self.condop0.setObjectName(_fromUtf8("condop0"))
        self.condop0.addItem(_fromUtf8(""))
        self.condop0.addItem(_fromUtf8(""))
        self.condop0.addItem(_fromUtf8(""))
        self.condop0.addItem(_fromUtf8(""))
        self.condop0.addItem(_fromUtf8(""))
        self.condop0.addItem(_fromUtf8(""))
        self.condop0.addItem(_fromUtf8(""))
        self.gridLayout.addWidget(self.condop0, 0, 1, 1, 1)
        self.condtext0 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(11)
        self.condtext0.setFont(font)
        self.condtext0.setObjectName(_fromUtf8("condtext0"))
        self.gridLayout.addWidget(self.condtext0, 0, 2, 1, 1)
        self.textval0 = QtGui.QLineEdit(self.widget)
        self.textval0.setEnabled(False)
        font = QtGui.QFont()
        font.setFamily(_fromUtf8("Courier New"))
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.textval0.setFont(font)
        self.textval0.setMaxLength(49)
        self.textval0.setObjectName(_fromUtf8("textval0"))
        self.gridLayout.addWidget(self.textval0, 0, 3, 1, 1)
        self.intval0 = QtGui.QSpinBox(self.widget)
        self.intval0.setMinimum(-1000000)
        self.intval0.setMaximum(1000000)
        self.intval0.setProperty("value", 0)
        self.intval0.setObjectName(_fromUtf8("intval0"))
        self.gridLayout.addWidget(self.intval0, 0, 4, 1, 1)
        self.cc0 = QtGui.QCheckBox(self.widget)
        self.cc0.setObjectName(_fromUtf8("cc0"))
        self.gridLayout.addWidget(self.cc0, 0, 5, 1, 1)
        self.condvar1 = QtGui.QComboBox(self.widget)
        self.condvar1.setObjectName(_fromUtf8("condvar1"))
        self.condvar1.addItem(_fromUtf8(""))
        self.gridLayout.addWidget(self.condvar1, 1, 0, 1, 1)
        self.condop1 = QtGui.QComboBox(self.widget)
        self.condop1.setObjectName(_fromUtf8("condop1"))
        self.condop1.addItem(_fromUtf8(""))
        self.condop1.addItem(_fromUtf8(""))
        self.condop1.addItem(_fromUtf8(""))
        self.condop1.addItem(_fromUtf8(""))
        self.condop1.addItem(_fromUtf8(""))
        self.condop1.addItem(_fromUtf8(""))
        self.condop1.addItem(_fromUtf8(""))
        self.gridLayout.addWidget(self.condop1, 1, 1, 1, 1)
        self.condtext1 = QtGui.QCheckBox(self.widget)
        font = QtGui.QFont()
        font.setPointSize(11)
        self.condtext1.setFont(font)
        self.condtext1.setObjectName(_fromUtf8("condtext1"))
        self.gridLayout.addWidget(self.condtext1, 1, 2, 1, 1)
        self.textval1 = QtGui.QLineEdit(self.widget)
        self.textval1.setEnabled(False)
        font = QtGui.QFont()
        font.setFamily(_fromUtf8("Courier New"))
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.textval1.setFont(font)
        self.textval1.setMaxLength(49)
        self.textval1.setObjectName(_fromUtf8("textval1"))
        self.gridLayout.addWidget(self.textval1, 1, 3, 1, 1)
        self.intval1 = QtGui.QSpinBox(self.widget)
        self.intval1.setObjectName(_fromUtf8("intval1"))
        self.gridLayout.addWidget(self.intval1, 1, 4, 1, 1)
        self.cc1 = QtGui.QCheckBox(self.widget)
        self.cc1.setObjectName(_fromUtf8("cc1"))
        self.gridLayout.addWidget(self.cc1, 1, 5, 1, 1)
        self.condvar2 = QtGui.QComboBox(self.widget)
        self.condvar2.setObjectName(_fromUtf8("condvar2"))
        self.condvar2.addItem(_fromUtf8(""))
        self.gridLayout.addWidget(self.condvar2, 2, 0, 1, 1)
        self.condop2 = QtGui.QComboBox(self.widget)
        self.condop2.setObjectName(_fromUtf8("condop2"))
        self.condop2.addItem(_fromUtf8(""))
        self.condop2.addItem(_fromUtf8(""))
        self.condop2.addItem(_fromUtf8(""))
        self.condop2.addItem(_fromUtf8(""))
        self.condop2.addItem(_fromUtf8(""))
        self.condop2.addItem(_fromUtf8(""))
        self.condop2.addItem(_fromUtf8(""))
        self.gridLayout.addWidget(self.condop2, 2, 1, 1, 1)
        self.condtext2 = QtGui.QCheckBox(self.widget)
        self.condtext2.setObjectName(_fromUtf8("condtext2"))
        self.gridLayout.addWidget(self.condtext2, 2, 2, 1, 1)
        self.textval2 = QtGui.QLineEdit(self.widget)
        self.textval2.setEnabled(False)
        font = QtGui.QFont()
        font.setFamily(_fromUtf8("Courier New"))
        self.textval2.setFont(font)
        self.textval2.setMaxLength(49)
        self.textval2.setObjectName(_fromUtf8("textval2"))
        self.gridLayout.addWidget(self.textval2, 2, 3, 1, 1)
        self.intval2 = QtGui.QSpinBox(self.widget)
        self.intval2.setObjectName(_fromUtf8("intval2"))
        self.gridLayout.addWidget(self.intval2, 2, 4, 1, 1)
        self.cc2 = QtGui.QCheckBox(self.widget)
        self.cc2.setObjectName(_fromUtf8("cc2"))
        self.gridLayout.addWidget(self.cc2, 2, 5, 1, 1)
        self.condvar3 = QtGui.QComboBox(self.widget)
        self.condvar3.setObjectName(_fromUtf8("condvar3"))
        self.condvar3.addItem(_fromUtf8(""))
        self.gridLayout.addWidget(self.condvar3, 3, 0, 1, 1)
        self.condop3 = QtGui.QComboBox(self.widget)
        self.condop3.setObjectName(_fromUtf8("condop3"))
        self.condop3.addItem(_fromUtf8(""))
        self.condop3.addItem(_fromUtf8(""))
        self.condop3.addItem(_fromUtf8(""))
        self.condop3.addItem(_fromUtf8(""))
        self.condop3.addItem(_fromUtf8(""))
        self.condop3.addItem(_fromUtf8(""))
        self.condop3.addItem(_fromUtf8(""))
        self.gridLayout.addWidget(self.condop3, 3, 1, 1, 1)
        self.condtext3 = QtGui.QCheckBox(self.widget)
        self.condtext3.setObjectName(_fromUtf8("condtext3"))
        self.gridLayout.addWidget(self.condtext3, 3, 2, 1, 1)
        self.textval3 = QtGui.QLineEdit(self.widget)
        self.textval3.setEnabled(False)
        font = QtGui.QFont()
        font.setFamily(_fromUtf8("Courier New"))
        self.textval3.setFont(font)
        self.textval3.setMaxLength(49)
        self.textval3.setObjectName(_fromUtf8("textval3"))
        self.gridLayout.addWidget(self.textval3, 3, 3, 1, 1)
        self.intval3 = QtGui.QSpinBox(self.widget)
        self.intval3.setObjectName(_fromUtf8("intval3"))
        self.gridLayout.addWidget(self.intval3, 3, 4, 1, 1)
        self.cc3 = QtGui.QCheckBox(self.widget)
        self.cc3.setObjectName(_fromUtf8("cc3"))
        self.gridLayout.addWidget(self.cc3, 3, 5, 1, 1)
        self.condvar4 = QtGui.QComboBox(self.widget)
        self.condvar4.setObjectName(_fromUtf8("condvar4"))
        self.condvar4.addItem(_fromUtf8(""))
        self.gridLayout.addWidget(self.condvar4, 4, 0, 1, 1)
        self.condop4 = QtGui.QComboBox(self.widget)
        self.condop4.setObjectName(_fromUtf8("condop4"))
        self.condop4.addItem(_fromUtf8(""))
        self.condop4.addItem(_fromUtf8(""))
        self.condop4.addItem(_fromUtf8(""))
        self.condop4.addItem(_fromUtf8(""))
        self.condop4.addItem(_fromUtf8(""))
        self.condop4.addItem(_fromUtf8(""))
        self.condop4.addItem(_fromUtf8(""))
        self.gridLayout.addWidget(self.condop4, 4, 1, 1, 1)
        self.condtext4 = QtGui.QCheckBox(self.widget)
        self.condtext4.setObjectName(_fromUtf8("condtext4"))
        self.gridLayout.addWidget(self.condtext4, 4, 2, 1, 1)
        self.textval4 = QtGui.QLineEdit(self.widget)
        self.textval4.setEnabled(False)
        font = QtGui.QFont()
        font.setFamily(_fromUtf8("Courier New"))
        self.textval4.setFont(font)
        self.textval4.setMaxLength(49)
        self.textval4.setObjectName(_fromUtf8("textval4"))
        self.gridLayout.addWidget(self.textval4, 4, 3, 1, 1)
        self.intval4 = QtGui.QSpinBox(self.widget)
        self.intval4.setObjectName(_fromUtf8("intval4"))
        self.gridLayout.addWidget(self.intval4, 4, 4, 1, 1)
        self.cc4 = QtGui.QCheckBox(self.widget)
        self.cc4.setObjectName(_fromUtf8("cc4"))
        self.gridLayout.addWidget(self.cc4, 4, 5, 1, 1)
        self.condvar5 = QtGui.QComboBox(self.widget)
        self.condvar5.setObjectName(_fromUtf8("condvar5"))
        self.condvar5.addItem(_fromUtf8(""))
        self.gridLayout.addWidget(self.condvar5, 5, 0, 1, 1)
        self.condop5 = QtGui.QComboBox(self.widget)
        self.condop5.setObjectName(_fromUtf8("condop5"))
        self.condop5.addItem(_fromUtf8(""))
        self.condop5.addItem(_fromUtf8(""))
        self.condop5.addItem(_fromUtf8(""))
        self.condop5.addItem(_fromUtf8(""))
        self.condop5.addItem(_fromUtf8(""))
        self.condop5.addItem(_fromUtf8(""))
        self.condop5.addItem(_fromUtf8(""))
        self.gridLayout.addWidget(self.condop5, 5, 1, 1, 1)
        self.condtext5 = QtGui.QCheckBox(self.widget)
        self.condtext5.setObjectName(_fromUtf8("condtext5"))
        self.gridLayout.addWidget(self.condtext5, 5, 2, 1, 1)
        self.textval5 = QtGui.QLineEdit(self.widget)
        self.textval5.setEnabled(False)
        font = QtGui.QFont()
        font.setFamily(_fromUtf8("Courier New"))
        self.textval5.setFont(font)
        self.textval5.setMaxLength(49)
        self.textval5.setObjectName(_fromUtf8("textval5"))
        self.gridLayout.addWidget(self.textval5, 5, 3, 1, 1)
        self.intval5 = QtGui.QSpinBox(self.widget)
        self.intval5.setObjectName(_fromUtf8("intval5"))
        self.gridLayout.addWidget(self.intval5, 5, 4, 1, 1)
        self.cc5 = QtGui.QCheckBox(self.widget)
        self.cc5.setObjectName(_fromUtf8("cc5"))
        self.gridLayout.addWidget(self.cc5, 5, 5, 1, 1)
        self.condvar6 = QtGui.QComboBox(self.widget)
        self.condvar6.setObjectName(_fromUtf8("condvar6"))
        self.condvar6.addItem(_fromUtf8(""))
        self.gridLayout.addWidget(self.condvar6, 6, 0, 1, 1)
        self.condop6 = QtGui.QComboBox(self.widget)
        self.condop6.setObjectName(_fromUtf8("condop6"))
        self.condop6.addItem(_fromUtf8(""))
        self.condop6.addItem(_fromUtf8(""))
        self.condop6.addItem(_fromUtf8(""))
        self.condop6.addItem(_fromUtf8(""))
        self.condop6.addItem(_fromUtf8(""))
        self.condop6.addItem(_fromUtf8(""))
        self.condop6.addItem(_fromUtf8(""))
        self.gridLayout.addWidget(self.condop6, 6, 1, 1, 1)
        self.condtext6 = QtGui.QCheckBox(self.widget)
        self.condtext6.setObjectName(_fromUtf8("condtext6"))
        self.gridLayout.addWidget(self.condtext6, 6, 2, 1, 1)
        self.textval6 = QtGui.QLineEdit(self.widget)
        self.textval6.setEnabled(False)
        font = QtGui.QFont()
        font.setFamily(_fromUtf8("Courier New"))
        self.textval6.setFont(font)
        self.textval6.setMaxLength(49)
        self.textval6.setObjectName(_fromUtf8("textval6"))
        self.gridLayout.addWidget(self.textval6, 6, 3, 1, 1)
        self.intval6 = QtGui.QSpinBox(self.widget)
        self.intval6.setObjectName(_fromUtf8("intval6"))
        self.gridLayout.addWidget(self.intval6, 6, 4, 1, 1)
        self.cc6 = QtGui.QCheckBox(self.widget)
        self.cc6.setObjectName(_fromUtf8("cc6"))
        self.gridLayout.addWidget(self.cc6, 6, 5, 1, 1)
        self.condvar7 = QtGui.QComboBox(self.widget)
        self.condvar7.setObjectName(_fromUtf8("condvar7"))
        self.condvar7.addItem(_fromUtf8(""))
        self.gridLayout.addWidget(self.condvar7, 7, 0, 1, 1)
        self.condop7 = QtGui.QComboBox(self.widget)
        self.condop7.setObjectName(_fromUtf8("condop7"))
        self.condop7.addItem(_fromUtf8(""))
        self.condop7.addItem(_fromUtf8(""))
        self.condop7.addItem(_fromUtf8(""))
        self.condop7.addItem(_fromUtf8(""))
        self.condop7.addItem(_fromUtf8(""))
        self.condop7.addItem(_fromUtf8(""))
        self.condop7.addItem(_fromUtf8(""))
        self.gridLayout.addWidget(self.condop7, 7, 1, 1, 1)
        self.condtext7 = QtGui.QCheckBox(self.widget)
        self.condtext7.setObjectName(_fromUtf8("condtext7"))
        self.gridLayout.addWidget(self.condtext7, 7, 2, 1, 1)
        self.textval7 = QtGui.QLineEdit(self.widget)
        self.textval7.setEnabled(False)
        font = QtGui.QFont()
        font.setFamily(_fromUtf8("Courier New"))
        self.textval7.setFont(font)
        self.textval7.setMaxLength(49)
        self.textval7.setObjectName(_fromUtf8("textval7"))
        self.gridLayout.addWidget(self.textval7, 7, 3, 1, 1)
        self.intval7 = QtGui.QSpinBox(self.widget)
        self.intval7.setObjectName(_fromUtf8("intval7"))
        self.gridLayout.addWidget(self.intval7, 7, 4, 1, 1)
        self.cc7 = QtGui.QCheckBox(self.widget)
        self.cc7.setObjectName(_fromUtf8("cc7"))
        self.gridLayout.addWidget(self.cc7, 7, 5, 1, 1)
        self.condvar8 = QtGui.QComboBox(self.widget)
        self.condvar8.setObjectName(_fromUtf8("condvar8"))
        self.condvar8.addItem(_fromUtf8(""))
        self.gridLayout.addWidget(self.condvar8, 8, 0, 1, 1)
        self.condop8 = QtGui.QComboBox(self.widget)
        self.condop8.setObjectName(_fromUtf8("condop8"))
        self.condop8.addItem(_fromUtf8(""))
        self.condop8.addItem(_fromUtf8(""))
        self.condop8.addItem(_fromUtf8(""))
        self.condop8.addItem(_fromUtf8(""))
        self.condop8.addItem(_fromUtf8(""))
        self.condop8.addItem(_fromUtf8(""))
        self.condop8.addItem(_fromUtf8(""))
        self.gridLayout.addWidget(self.condop8, 8, 1, 1, 1)
        self.condtext8 = QtGui.QCheckBox(self.widget)
        self.condtext8.setObjectName(_fromUtf8("condtext8"))
        self.gridLayout.addWidget(self.condtext8, 8, 2, 1, 1)
        self.textval8 = QtGui.QLineEdit(self.widget)
        self.textval8.setEnabled(False)
        font = QtGui.QFont()
        font.setFamily(_fromUtf8("Courier New"))
        self.textval8.setFont(font)
        self.textval8.setMaxLength(49)
        self.textval8.setObjectName(_fromUtf8("textval8"))
        self.gridLayout.addWidget(self.textval8, 8, 3, 1, 1)
        self.intval8 = QtGui.QSpinBox(self.widget)
        self.intval8.setObjectName(_fromUtf8("intval8"))
        self.gridLayout.addWidget(self.intval8, 8, 4, 1, 1)
        self.cc8 = QtGui.QCheckBox(self.widget)
        self.cc8.setObjectName(_fromUtf8("cc8"))
        self.gridLayout.addWidget(self.cc8, 8, 5, 1, 1)
        self.condvar9 = QtGui.QComboBox(self.widget)
        self.condvar9.setObjectName(_fromUtf8("condvar9"))
        self.condvar9.addItem(_fromUtf8(""))
        self.gridLayout.addWidget(self.condvar9, 9, 0, 1, 1)
        self.condop9 = QtGui.QComboBox(self.widget)
        self.condop9.setObjectName(_fromUtf8("condop9"))
        self.condop9.addItem(_fromUtf8(""))
        self.condop9.addItem(_fromUtf8(""))
        self.condop9.addItem(_fromUtf8(""))
        self.condop9.addItem(_fromUtf8(""))
        self.condop9.addItem(_fromUtf8(""))
        self.condop9.addItem(_fromUtf8(""))
        self.condop9.addItem(_fromUtf8(""))
        self.gridLayout.addWidget(self.condop9, 9, 1, 1, 1)
        self.condtext9 = QtGui.QCheckBox(self.widget)
        self.condtext9.setObjectName(_fromUtf8("condtext9"))
        self.gridLayout.addWidget(self.condtext9, 9, 2, 1, 1)
        self.textval9 = QtGui.QLineEdit(self.widget)
        self.textval9.setEnabled(False)
        font = QtGui.QFont()
        font.setFamily(_fromUtf8("Courier New"))
        self.textval9.setFont(font)
        self.textval9.setMaxLength(49)
        self.textval9.setObjectName(_fromUtf8("textval9"))
        self.gridLayout.addWidget(self.textval9, 9, 3, 1, 1)
        self.intval9 = QtGui.QSpinBox(self.widget)
        self.intval9.setObjectName(_fromUtf8("intval9"))
        self.gridLayout.addWidget(self.intval9, 9, 4, 1, 1)
        self.cc9 = QtGui.QCheckBox(self.widget)
        self.cc9.setObjectName(_fromUtf8("cc9"))
        self.gridLayout.addWidget(self.cc9, 9, 5, 1, 1)

        self.retranslateUi(jcondsdlg)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("accepted()")), jcondsdlg.accept)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("rejected()")), jcondsdlg.reject)
        QtCore.QMetaObject.connectSlotsByName(jcondsdlg)
        jcondsdlg.setTabOrder(self.condvar0, self.condop0)
        jcondsdlg.setTabOrder(self.condop0, self.condtext0)
        jcondsdlg.setTabOrder(self.condtext0, self.textval0)
        jcondsdlg.setTabOrder(self.textval0, self.intval0)
        jcondsdlg.setTabOrder(self.intval0, self.cc0)
        jcondsdlg.setTabOrder(self.cc0, self.condvar1)
        jcondsdlg.setTabOrder(self.condvar1, self.condop1)
        jcondsdlg.setTabOrder(self.condop1, self.condtext1)
        jcondsdlg.setTabOrder(self.condtext1, self.textval1)
        jcondsdlg.setTabOrder(self.textval1, self.intval1)
        jcondsdlg.setTabOrder(self.intval1, self.cc1)
        jcondsdlg.setTabOrder(self.cc1, self.condvar2)
        jcondsdlg.setTabOrder(self.condvar2, self.condop2)
        jcondsdlg.setTabOrder(self.condop2, self.condtext2)
        jcondsdlg.setTabOrder(self.condtext2, self.textval2)
        jcondsdlg.setTabOrder(self.textval2, self.intval2)
        jcondsdlg.setTabOrder(self.intval2, self.cc2)
        jcondsdlg.setTabOrder(self.cc2, self.condvar3)
        jcondsdlg.setTabOrder(self.condvar3, self.condop3)
        jcondsdlg.setTabOrder(self.condop3, self.condtext3)
        jcondsdlg.setTabOrder(self.condtext3, self.textval3)
        jcondsdlg.setTabOrder(self.textval3, self.intval3)
        jcondsdlg.setTabOrder(self.intval3, self.cc3)
        jcondsdlg.setTabOrder(self.cc3, self.condvar4)
        jcondsdlg.setTabOrder(self.condvar4, self.condop4)
        jcondsdlg.setTabOrder(self.condop4, self.condtext4)
        jcondsdlg.setTabOrder(self.condtext4, self.textval4)
        jcondsdlg.setTabOrder(self.textval4, self.intval4)
        jcondsdlg.setTabOrder(self.intval4, self.cc4)
        jcondsdlg.setTabOrder(self.cc4, self.condvar5)
        jcondsdlg.setTabOrder(self.condvar5, self.condop5)
        jcondsdlg.setTabOrder(self.condop5, self.condtext5)
        jcondsdlg.setTabOrder(self.condtext5, self.textval5)
        jcondsdlg.setTabOrder(self.textval5, self.intval5)
        jcondsdlg.setTabOrder(self.intval5, self.cc5)
        jcondsdlg.setTabOrder(self.cc5, self.condvar6)
        jcondsdlg.setTabOrder(self.condvar6, self.condop6)
        jcondsdlg.setTabOrder(self.condop6, self.condtext6)
        jcondsdlg.setTabOrder(self.condtext6, self.textval6)
        jcondsdlg.setTabOrder(self.textval6, self.intval6)
        jcondsdlg.setTabOrder(self.intval6, self.cc6)
        jcondsdlg.setTabOrder(self.cc6, self.condvar7)
        jcondsdlg.setTabOrder(self.condvar7, self.condop7)
        jcondsdlg.setTabOrder(self.condop7, self.condtext7)
        jcondsdlg.setTabOrder(self.condtext7, self.textval7)
        jcondsdlg.setTabOrder(self.textval7, self.intval7)
        jcondsdlg.setTabOrder(self.intval7, self.cc7)
        jcondsdlg.setTabOrder(self.cc7, self.condvar8)
        jcondsdlg.setTabOrder(self.condvar8, self.condop8)
        jcondsdlg.setTabOrder(self.condop8, self.condtext8)
        jcondsdlg.setTabOrder(self.condtext8, self.textval8)
        jcondsdlg.setTabOrder(self.textval8, self.intval8)
        jcondsdlg.setTabOrder(self.intval8, self.cc8)
        jcondsdlg.setTabOrder(self.cc8, self.condvar9)
        jcondsdlg.setTabOrder(self.condvar9, self.condop9)
        jcondsdlg.setTabOrder(self.condop9, self.condtext9)
        jcondsdlg.setTabOrder(self.condtext9, self.textval9)
        jcondsdlg.setTabOrder(self.textval9, self.intval9)
        jcondsdlg.setTabOrder(self.intval9, self.cc9)
        jcondsdlg.setTabOrder(self.cc9, self.buttonBox)

    def retranslateUi(self, jcondsdlg):
        jcondsdlg.setWindowTitle(QtGui.QApplication.translate("jcondsdlg", "Conditions for job", None, QtGui.QApplication.UnicodeUTF8))
        self.label.setText(QtGui.QApplication.translate("jcondsdlg", "Conditions for job", None, QtGui.QApplication.UnicodeUTF8))
        self.label_2.setText(QtGui.QApplication.translate("jcondsdlg", "Variable", None, QtGui.QApplication.UnicodeUTF8))
        self.label_3.setText(QtGui.QApplication.translate("jcondsdlg", "Op", None, QtGui.QApplication.UnicodeUTF8))
        self.label_4.setText(QtGui.QApplication.translate("jcondsdlg", "Text Value", None, QtGui.QApplication.UnicodeUTF8))
        self.label_5.setText(QtGui.QApplication.translate("jcondsdlg", "Int Val", None, QtGui.QApplication.UnicodeUTF8))
        self.condvar0.setToolTip(QtGui.QApplication.translate("jcondsdlg", "This is the variable whose value is to be inspected", None, QtGui.QApplication.UnicodeUTF8))
        self.condvar0.setItemText(0, QtGui.QApplication.translate("jcondsdlg", "(no variable)", None, QtGui.QApplication.UnicodeUTF8))
        self.condop0.setToolTip(QtGui.QApplication.translate("jcondsdlg", "This is the operation", None, QtGui.QApplication.UnicodeUTF8))
        self.condop0.setItemText(0, QtGui.QApplication.translate("jcondsdlg", "n/a", None, QtGui.QApplication.UnicodeUTF8))
        self.condop0.setItemText(1, QtGui.QApplication.translate("jcondsdlg", "=", None, QtGui.QApplication.UnicodeUTF8))
        self.condop0.setItemText(2, QtGui.QApplication.translate("jcondsdlg", "!=", None, QtGui.QApplication.UnicodeUTF8))
        self.condop0.setItemText(3, QtGui.QApplication.translate("jcondsdlg", "<", None, QtGui.QApplication.UnicodeUTF8))
        self.condop0.setItemText(4, QtGui.QApplication.translate("jcondsdlg", "<=", None, QtGui.QApplication.UnicodeUTF8))
        self.condop0.setItemText(5, QtGui.QApplication.translate("jcondsdlg", ">", None, QtGui.QApplication.UnicodeUTF8))
        self.condop0.setItemText(6, QtGui.QApplication.translate("jcondsdlg", ">=", None, QtGui.QApplication.UnicodeUTF8))
        self.condtext0.setToolTip(QtGui.QApplication.translate("jcondsdlg", "Indicate that the value to be compared is text", None, QtGui.QApplication.UnicodeUTF8))
        self.condtext0.setText(QtGui.QApplication.translate("jcondsdlg", "Text", None, QtGui.QApplication.UnicodeUTF8))
        self.textval0.setToolTip(QtGui.QApplication.translate("jcondsdlg", "Give the text value to be compared here", None, QtGui.QApplication.UnicodeUTF8))
        self.intval0.setToolTip(QtGui.QApplication.translate("jcondsdlg", "Give the integer value to be compared here", None, QtGui.QApplication.UnicodeUTF8))
        self.cc0.setToolTip(QtGui.QApplication.translate("jcondsdlg", "This is a critical condition\n"
"\n"
"If host with variable is not running do not run the job, if not set, in\n"
"this case ignore the condition.", None, QtGui.QApplication.UnicodeUTF8))
        self.cc0.setText(QtGui.QApplication.translate("jcondsdlg", "CCrit", None, QtGui.QApplication.UnicodeUTF8))
        self.condvar1.setToolTip(QtGui.QApplication.translate("jcondsdlg", "This is the variable whose value is to be inspected", None, QtGui.QApplication.UnicodeUTF8))
        self.condvar1.setItemText(0, QtGui.QApplication.translate("jcondsdlg", "(no variable)", None, QtGui.QApplication.UnicodeUTF8))
        self.condop1.setToolTip(QtGui.QApplication.translate("jcondsdlg", "This is the operation", None, QtGui.QApplication.UnicodeUTF8))
        self.condop1.setItemText(0, QtGui.QApplication.translate("jcondsdlg", "n/a", None, QtGui.QApplication.UnicodeUTF8))
        self.condop1.setItemText(1, QtGui.QApplication.translate("jcondsdlg", "=", None, QtGui.QApplication.UnicodeUTF8))
        self.condop1.setItemText(2, QtGui.QApplication.translate("jcondsdlg", "!=", None, QtGui.QApplication.UnicodeUTF8))
        self.condop1.setItemText(3, QtGui.QApplication.translate("jcondsdlg", "<", None, QtGui.QApplication.UnicodeUTF8))
        self.condop1.setItemText(4, QtGui.QApplication.translate("jcondsdlg", "<=", None, QtGui.QApplication.UnicodeUTF8))
        self.condop1.setItemText(5, QtGui.QApplication.translate("jcondsdlg", ">", None, QtGui.QApplication.UnicodeUTF8))
        self.condop1.setItemText(6, QtGui.QApplication.translate("jcondsdlg", ">=", None, QtGui.QApplication.UnicodeUTF8))
        self.condtext1.setToolTip(QtGui.QApplication.translate("jcondsdlg", "Indicate that the value to be compared is text", None, QtGui.QApplication.UnicodeUTF8))
        self.condtext1.setText(QtGui.QApplication.translate("jcondsdlg", "Text", None, QtGui.QApplication.UnicodeUTF8))
        self.textval1.setToolTip(QtGui.QApplication.translate("jcondsdlg", "Give the text value to be compared here", None, QtGui.QApplication.UnicodeUTF8))
        self.intval1.setToolTip(QtGui.QApplication.translate("jcondsdlg", "Give the integer value to be compared here", None, QtGui.QApplication.UnicodeUTF8))
        self.cc1.setToolTip(QtGui.QApplication.translate("jcondsdlg", "This is a critical condition\n"
"\n"
"If host with variable is not running do not run the job, if not set, in\n"
"this case ignore the condition.", None, QtGui.QApplication.UnicodeUTF8))
        self.cc1.setText(QtGui.QApplication.translate("jcondsdlg", "CCrit", None, QtGui.QApplication.UnicodeUTF8))
        self.condvar2.setToolTip(QtGui.QApplication.translate("jcondsdlg", "This is the variable whose value is to be inspected", None, QtGui.QApplication.UnicodeUTF8))
        self.condvar2.setItemText(0, QtGui.QApplication.translate("jcondsdlg", "(no variable)", None, QtGui.QApplication.UnicodeUTF8))
        self.condop2.setToolTip(QtGui.QApplication.translate("jcondsdlg", "This is the operation", None, QtGui.QApplication.UnicodeUTF8))
        self.condop2.setItemText(0, QtGui.QApplication.translate("jcondsdlg", "n/a", None, QtGui.QApplication.UnicodeUTF8))
        self.condop2.setItemText(1, QtGui.QApplication.translate("jcondsdlg", "=", None, QtGui.QApplication.UnicodeUTF8))
        self.condop2.setItemText(2, QtGui.QApplication.translate("jcondsdlg", "!=", None, QtGui.QApplication.UnicodeUTF8))
        self.condop2.setItemText(3, QtGui.QApplication.translate("jcondsdlg", "<", None, QtGui.QApplication.UnicodeUTF8))
        self.condop2.setItemText(4, QtGui.QApplication.translate("jcondsdlg", "<=", None, QtGui.QApplication.UnicodeUTF8))
        self.condop2.setItemText(5, QtGui.QApplication.translate("jcondsdlg", ">", None, QtGui.QApplication.UnicodeUTF8))
        self.condop2.setItemText(6, QtGui.QApplication.translate("jcondsdlg", ">=", None, QtGui.QApplication.UnicodeUTF8))
        self.condtext2.setToolTip(QtGui.QApplication.translate("jcondsdlg", "Indicate that the value to be compared is text", None, QtGui.QApplication.UnicodeUTF8))
        self.condtext2.setText(QtGui.QApplication.translate("jcondsdlg", "Text", None, QtGui.QApplication.UnicodeUTF8))
        self.textval2.setToolTip(QtGui.QApplication.translate("jcondsdlg", "Give the text value to be compared here", None, QtGui.QApplication.UnicodeUTF8))
        self.intval2.setToolTip(QtGui.QApplication.translate("jcondsdlg", "Give the integer value to be compared here", None, QtGui.QApplication.UnicodeUTF8))
        self.cc2.setToolTip(QtGui.QApplication.translate("jcondsdlg", "This is a critical condition\n"
"\n"
"If host with variable is not running do not run the job, if not set, in\n"
"this case ignore the condition.", None, QtGui.QApplication.UnicodeUTF8))
        self.cc2.setText(QtGui.QApplication.translate("jcondsdlg", "CCrit", None, QtGui.QApplication.UnicodeUTF8))
        self.condvar3.setToolTip(QtGui.QApplication.translate("jcondsdlg", "This is the variable whose value is to be inspected", None, QtGui.QApplication.UnicodeUTF8))
        self.condvar3.setItemText(0, QtGui.QApplication.translate("jcondsdlg", "(no variable)", None, QtGui.QApplication.UnicodeUTF8))
        self.condop3.setToolTip(QtGui.QApplication.translate("jcondsdlg", "This is the operation", None, QtGui.QApplication.UnicodeUTF8))
        self.condop3.setItemText(0, QtGui.QApplication.translate("jcondsdlg", "n/a", None, QtGui.QApplication.UnicodeUTF8))
        self.condop3.setItemText(1, QtGui.QApplication.translate("jcondsdlg", "=", None, QtGui.QApplication.UnicodeUTF8))
        self.condop3.setItemText(2, QtGui.QApplication.translate("jcondsdlg", "!=", None, QtGui.QApplication.UnicodeUTF8))
        self.condop3.setItemText(3, QtGui.QApplication.translate("jcondsdlg", "<", None, QtGui.QApplication.UnicodeUTF8))
        self.condop3.setItemText(4, QtGui.QApplication.translate("jcondsdlg", "<=", None, QtGui.QApplication.UnicodeUTF8))
        self.condop3.setItemText(5, QtGui.QApplication.translate("jcondsdlg", ">", None, QtGui.QApplication.UnicodeUTF8))
        self.condop3.setItemText(6, QtGui.QApplication.translate("jcondsdlg", ">=", None, QtGui.QApplication.UnicodeUTF8))
        self.condtext3.setToolTip(QtGui.QApplication.translate("jcondsdlg", "Indicate that the value to be compared is text", None, QtGui.QApplication.UnicodeUTF8))
        self.condtext3.setText(QtGui.QApplication.translate("jcondsdlg", "Text", None, QtGui.QApplication.UnicodeUTF8))
        self.textval3.setToolTip(QtGui.QApplication.translate("jcondsdlg", "Give the text value to be compared here", None, QtGui.QApplication.UnicodeUTF8))
        self.intval3.setToolTip(QtGui.QApplication.translate("jcondsdlg", "Give the integer value to be compared here", None, QtGui.QApplication.UnicodeUTF8))
        self.cc3.setToolTip(QtGui.QApplication.translate("jcondsdlg", "This is a critical condition\n"
"\n"
"If host with variable is not running do not run the job, if not set, in\n"
"this case ignore the condition.", None, QtGui.QApplication.UnicodeUTF8))
        self.cc3.setText(QtGui.QApplication.translate("jcondsdlg", "CCrit", None, QtGui.QApplication.UnicodeUTF8))
        self.condvar4.setToolTip(QtGui.QApplication.translate("jcondsdlg", "This is the variable whose value is to be inspected", None, QtGui.QApplication.UnicodeUTF8))
        self.condvar4.setItemText(0, QtGui.QApplication.translate("jcondsdlg", "(no variable)", None, QtGui.QApplication.UnicodeUTF8))
        self.condop4.setToolTip(QtGui.QApplication.translate("jcondsdlg", "This is the operation", None, QtGui.QApplication.UnicodeUTF8))
        self.condop4.setItemText(0, QtGui.QApplication.translate("jcondsdlg", "n/a", None, QtGui.QApplication.UnicodeUTF8))
        self.condop4.setItemText(1, QtGui.QApplication.translate("jcondsdlg", "=", None, QtGui.QApplication.UnicodeUTF8))
        self.condop4.setItemText(2, QtGui.QApplication.translate("jcondsdlg", "!=", None, QtGui.QApplication.UnicodeUTF8))
        self.condop4.setItemText(3, QtGui.QApplication.translate("jcondsdlg", "<", None, QtGui.QApplication.UnicodeUTF8))
        self.condop4.setItemText(4, QtGui.QApplication.translate("jcondsdlg", "<=", None, QtGui.QApplication.UnicodeUTF8))
        self.condop4.setItemText(5, QtGui.QApplication.translate("jcondsdlg", ">", None, QtGui.QApplication.UnicodeUTF8))
        self.condop4.setItemText(6, QtGui.QApplication.translate("jcondsdlg", ">=", None, QtGui.QApplication.UnicodeUTF8))
        self.condtext4.setToolTip(QtGui.QApplication.translate("jcondsdlg", "Indicate that the value to be compared is text", None, QtGui.QApplication.UnicodeUTF8))
        self.condtext4.setText(QtGui.QApplication.translate("jcondsdlg", "Text", None, QtGui.QApplication.UnicodeUTF8))
        self.textval4.setToolTip(QtGui.QApplication.translate("jcondsdlg", "Give the text value to be compared here", None, QtGui.QApplication.UnicodeUTF8))
        self.intval4.setToolTip(QtGui.QApplication.translate("jcondsdlg", "Give the integer value to be compared here", None, QtGui.QApplication.UnicodeUTF8))
        self.cc4.setToolTip(QtGui.QApplication.translate("jcondsdlg", "This is a critical condition\n"
"\n"
"If host with variable is not running do not run the job, if not set, in\n"
"this case ignore the condition.", None, QtGui.QApplication.UnicodeUTF8))
        self.cc4.setText(QtGui.QApplication.translate("jcondsdlg", "CCrit", None, QtGui.QApplication.UnicodeUTF8))
        self.condvar5.setToolTip(QtGui.QApplication.translate("jcondsdlg", "This is the variable whose value is to be inspected", None, QtGui.QApplication.UnicodeUTF8))
        self.condvar5.setItemText(0, QtGui.QApplication.translate("jcondsdlg", "(no variable)", None, QtGui.QApplication.UnicodeUTF8))
        self.condop5.setToolTip(QtGui.QApplication.translate("jcondsdlg", "This is the operation", None, QtGui.QApplication.UnicodeUTF8))
        self.condop5.setItemText(0, QtGui.QApplication.translate("jcondsdlg", "n/a", None, QtGui.QApplication.UnicodeUTF8))
        self.condop5.setItemText(1, QtGui.QApplication.translate("jcondsdlg", "=", None, QtGui.QApplication.UnicodeUTF8))
        self.condop5.setItemText(2, QtGui.QApplication.translate("jcondsdlg", "!=", None, QtGui.QApplication.UnicodeUTF8))
        self.condop5.setItemText(3, QtGui.QApplication.translate("jcondsdlg", "<", None, QtGui.QApplication.UnicodeUTF8))
        self.condop5.setItemText(4, QtGui.QApplication.translate("jcondsdlg", "<=", None, QtGui.QApplication.UnicodeUTF8))
        self.condop5.setItemText(5, QtGui.QApplication.translate("jcondsdlg", ">", None, QtGui.QApplication.UnicodeUTF8))
        self.condop5.setItemText(6, QtGui.QApplication.translate("jcondsdlg", ">=", None, QtGui.QApplication.UnicodeUTF8))
        self.condtext5.setToolTip(QtGui.QApplication.translate("jcondsdlg", "Indicate that the value to be compared is text", None, QtGui.QApplication.UnicodeUTF8))
        self.condtext5.setText(QtGui.QApplication.translate("jcondsdlg", "Text", None, QtGui.QApplication.UnicodeUTF8))
        self.textval5.setToolTip(QtGui.QApplication.translate("jcondsdlg", "Give the text value to be compared here", None, QtGui.QApplication.UnicodeUTF8))
        self.intval5.setToolTip(QtGui.QApplication.translate("jcondsdlg", "Give the integer value to be compared here", None, QtGui.QApplication.UnicodeUTF8))
        self.cc5.setToolTip(QtGui.QApplication.translate("jcondsdlg", "This is a critical condition\n"
"\n"
"If host with variable is not running do not run the job, if not set, in\n"
"this case ignore the condition.", None, QtGui.QApplication.UnicodeUTF8))
        self.cc5.setText(QtGui.QApplication.translate("jcondsdlg", "CCrit", None, QtGui.QApplication.UnicodeUTF8))
        self.condvar6.setToolTip(QtGui.QApplication.translate("jcondsdlg", "This is the variable whose value is to be inspected", None, QtGui.QApplication.UnicodeUTF8))
        self.condvar6.setItemText(0, QtGui.QApplication.translate("jcondsdlg", "(no variable)", None, QtGui.QApplication.UnicodeUTF8))
        self.condop6.setToolTip(QtGui.QApplication.translate("jcondsdlg", "This is the operation", None, QtGui.QApplication.UnicodeUTF8))
        self.condop6.setItemText(0, QtGui.QApplication.translate("jcondsdlg", "n/a", None, QtGui.QApplication.UnicodeUTF8))
        self.condop6.setItemText(1, QtGui.QApplication.translate("jcondsdlg", "=", None, QtGui.QApplication.UnicodeUTF8))
        self.condop6.setItemText(2, QtGui.QApplication.translate("jcondsdlg", "!=", None, QtGui.QApplication.UnicodeUTF8))
        self.condop6.setItemText(3, QtGui.QApplication.translate("jcondsdlg", "<", None, QtGui.QApplication.UnicodeUTF8))
        self.condop6.setItemText(4, QtGui.QApplication.translate("jcondsdlg", "<=", None, QtGui.QApplication.UnicodeUTF8))
        self.condop6.setItemText(5, QtGui.QApplication.translate("jcondsdlg", ">", None, QtGui.QApplication.UnicodeUTF8))
        self.condop6.setItemText(6, QtGui.QApplication.translate("jcondsdlg", ">=", None, QtGui.QApplication.UnicodeUTF8))
        self.condtext6.setToolTip(QtGui.QApplication.translate("jcondsdlg", "Indicate that the value to be compared is text", None, QtGui.QApplication.UnicodeUTF8))
        self.condtext6.setText(QtGui.QApplication.translate("jcondsdlg", "Text", None, QtGui.QApplication.UnicodeUTF8))
        self.textval6.setToolTip(QtGui.QApplication.translate("jcondsdlg", "Give the text value to be compared here", None, QtGui.QApplication.UnicodeUTF8))
        self.intval6.setToolTip(QtGui.QApplication.translate("jcondsdlg", "Give the integer value to be compared here", None, QtGui.QApplication.UnicodeUTF8))
        self.cc6.setToolTip(QtGui.QApplication.translate("jcondsdlg", "This is a critical condition\n"
"\n"
"If host with variable is not running do not run the job, if not set, in\n"
"this case ignore the condition.", None, QtGui.QApplication.UnicodeUTF8))
        self.cc6.setText(QtGui.QApplication.translate("jcondsdlg", "CCrit", None, QtGui.QApplication.UnicodeUTF8))
        self.condvar7.setToolTip(QtGui.QApplication.translate("jcondsdlg", "This is the variable whose value is to be inspected", None, QtGui.QApplication.UnicodeUTF8))
        self.condvar7.setItemText(0, QtGui.QApplication.translate("jcondsdlg", "(no variable)", None, QtGui.QApplication.UnicodeUTF8))
        self.condop7.setToolTip(QtGui.QApplication.translate("jcondsdlg", "This is the operation", None, QtGui.QApplication.UnicodeUTF8))
        self.condop7.setItemText(0, QtGui.QApplication.translate("jcondsdlg", "n/a", None, QtGui.QApplication.UnicodeUTF8))
        self.condop7.setItemText(1, QtGui.QApplication.translate("jcondsdlg", "=", None, QtGui.QApplication.UnicodeUTF8))
        self.condop7.setItemText(2, QtGui.QApplication.translate("jcondsdlg", "!=", None, QtGui.QApplication.UnicodeUTF8))
        self.condop7.setItemText(3, QtGui.QApplication.translate("jcondsdlg", "<", None, QtGui.QApplication.UnicodeUTF8))
        self.condop7.setItemText(4, QtGui.QApplication.translate("jcondsdlg", "<=", None, QtGui.QApplication.UnicodeUTF8))
        self.condop7.setItemText(5, QtGui.QApplication.translate("jcondsdlg", ">", None, QtGui.QApplication.UnicodeUTF8))
        self.condop7.setItemText(6, QtGui.QApplication.translate("jcondsdlg", ">=", None, QtGui.QApplication.UnicodeUTF8))
        self.condtext7.setToolTip(QtGui.QApplication.translate("jcondsdlg", "Indicate that the value to be compared is text", None, QtGui.QApplication.UnicodeUTF8))
        self.condtext7.setText(QtGui.QApplication.translate("jcondsdlg", "Text", None, QtGui.QApplication.UnicodeUTF8))
        self.textval7.setToolTip(QtGui.QApplication.translate("jcondsdlg", "Give the text value to be compared here", None, QtGui.QApplication.UnicodeUTF8))
        self.intval7.setToolTip(QtGui.QApplication.translate("jcondsdlg", "Give the integer value to be compared here", None, QtGui.QApplication.UnicodeUTF8))
        self.cc7.setToolTip(QtGui.QApplication.translate("jcondsdlg", "This is a critical condition\n"
"\n"
"If host with variable is not running do not run the job, if not set, in\n"
"this case ignore the condition.", None, QtGui.QApplication.UnicodeUTF8))
        self.cc7.setText(QtGui.QApplication.translate("jcondsdlg", "CCrit", None, QtGui.QApplication.UnicodeUTF8))
        self.condvar8.setToolTip(QtGui.QApplication.translate("jcondsdlg", "This is the variable whose value is to be inspected", None, QtGui.QApplication.UnicodeUTF8))
        self.condvar8.setItemText(0, QtGui.QApplication.translate("jcondsdlg", "(no variable)", None, QtGui.QApplication.UnicodeUTF8))
        self.condop8.setToolTip(QtGui.QApplication.translate("jcondsdlg", "This is the operation", None, QtGui.QApplication.UnicodeUTF8))
        self.condop8.setItemText(0, QtGui.QApplication.translate("jcondsdlg", "n/a", None, QtGui.QApplication.UnicodeUTF8))
        self.condop8.setItemText(1, QtGui.QApplication.translate("jcondsdlg", "=", None, QtGui.QApplication.UnicodeUTF8))
        self.condop8.setItemText(2, QtGui.QApplication.translate("jcondsdlg", "!=", None, QtGui.QApplication.UnicodeUTF8))
        self.condop8.setItemText(3, QtGui.QApplication.translate("jcondsdlg", "<", None, QtGui.QApplication.UnicodeUTF8))
        self.condop8.setItemText(4, QtGui.QApplication.translate("jcondsdlg", "<=", None, QtGui.QApplication.UnicodeUTF8))
        self.condop8.setItemText(5, QtGui.QApplication.translate("jcondsdlg", ">", None, QtGui.QApplication.UnicodeUTF8))
        self.condop8.setItemText(6, QtGui.QApplication.translate("jcondsdlg", ">=", None, QtGui.QApplication.UnicodeUTF8))
        self.condtext8.setToolTip(QtGui.QApplication.translate("jcondsdlg", "Indicate that the value to be compared is text", None, QtGui.QApplication.UnicodeUTF8))
        self.condtext8.setText(QtGui.QApplication.translate("jcondsdlg", "Text", None, QtGui.QApplication.UnicodeUTF8))
        self.textval8.setToolTip(QtGui.QApplication.translate("jcondsdlg", "Give the text value to be compared here", None, QtGui.QApplication.UnicodeUTF8))
        self.intval8.setToolTip(QtGui.QApplication.translate("jcondsdlg", "Give the integer value to be compared here", None, QtGui.QApplication.UnicodeUTF8))
        self.cc8.setToolTip(QtGui.QApplication.translate("jcondsdlg", "This is a critical condition\n"
"\n"
"If host with variable is not running do not run the job, if not set, in\n"
"this case ignore the condition.", None, QtGui.QApplication.UnicodeUTF8))
        self.cc8.setText(QtGui.QApplication.translate("jcondsdlg", "CCrit", None, QtGui.QApplication.UnicodeUTF8))
        self.condvar9.setToolTip(QtGui.QApplication.translate("jcondsdlg", "This is the variable whose value is to be inspected", None, QtGui.QApplication.UnicodeUTF8))
        self.condvar9.setItemText(0, QtGui.QApplication.translate("jcondsdlg", "(no variable)", None, QtGui.QApplication.UnicodeUTF8))
        self.condop9.setToolTip(QtGui.QApplication.translate("jcondsdlg", "This is the operation", None, QtGui.QApplication.UnicodeUTF8))
        self.condop9.setItemText(0, QtGui.QApplication.translate("jcondsdlg", "n/a", None, QtGui.QApplication.UnicodeUTF8))
        self.condop9.setItemText(1, QtGui.QApplication.translate("jcondsdlg", "=", None, QtGui.QApplication.UnicodeUTF8))
        self.condop9.setItemText(2, QtGui.QApplication.translate("jcondsdlg", "!=", None, QtGui.QApplication.UnicodeUTF8))
        self.condop9.setItemText(3, QtGui.QApplication.translate("jcondsdlg", "<", None, QtGui.QApplication.UnicodeUTF8))
        self.condop9.setItemText(4, QtGui.QApplication.translate("jcondsdlg", "<=", None, QtGui.QApplication.UnicodeUTF8))
        self.condop9.setItemText(5, QtGui.QApplication.translate("jcondsdlg", ">", None, QtGui.QApplication.UnicodeUTF8))
        self.condop9.setItemText(6, QtGui.QApplication.translate("jcondsdlg", ">=", None, QtGui.QApplication.UnicodeUTF8))
        self.condtext9.setToolTip(QtGui.QApplication.translate("jcondsdlg", "Indicate that the value to be compared is text", None, QtGui.QApplication.UnicodeUTF8))
        self.condtext9.setText(QtGui.QApplication.translate("jcondsdlg", "Text", None, QtGui.QApplication.UnicodeUTF8))
        self.textval9.setToolTip(QtGui.QApplication.translate("jcondsdlg", "Give the text value to be compared here", None, QtGui.QApplication.UnicodeUTF8))
        self.intval9.setToolTip(QtGui.QApplication.translate("jcondsdlg", "Give the integer value to be compared here", None, QtGui.QApplication.UnicodeUTF8))
        self.cc9.setToolTip(QtGui.QApplication.translate("jcondsdlg", "This is a critical condition\n"
"\n"
"If host with variable is not running do not run the job, if not set, in\n"
"this case ignore the condition.", None, QtGui.QApplication.UnicodeUTF8))
        self.cc9.setText(QtGui.QApplication.translate("jcondsdlg", "CCrit", None, QtGui.QApplication.UnicodeUTF8))

