# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'procpardlg.ui'
#
# Created: Wed Nov 14 21:42:49 2012
#      by: PyQt4 UI code generator 4.9.1
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    _fromUtf8 = lambda s: s

class Ui_procpardlg(object):
    def setupUi(self, procpardlg):
        procpardlg.setObjectName(_fromUtf8("procpardlg"))
        procpardlg.resize(624, 444)
        self.buttonBox = QtGui.QDialogButtonBox(procpardlg)
        self.buttonBox.setGeometry(QtCore.QRect(410, 390, 191, 32))
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtGui.QDialogButtonBox.Cancel|QtGui.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName(_fromUtf8("buttonBox"))
        self.label = QtGui.QLabel(procpardlg)
        self.label.setGeometry(QtCore.QRect(30, 20, 81, 17))
        self.label.setObjectName(_fromUtf8("label"))
        self.edjob = QtGui.QLabel(procpardlg)
        self.edjob.setGeometry(QtCore.QRect(130, 20, 331, 17))
        self.edjob.setText(_fromUtf8(""))
        self.edjob.setObjectName(_fromUtf8("edjob"))
        self.label_2 = QtGui.QLabel(procpardlg)
        self.label_2.setGeometry(QtCore.QRect(30, 50, 71, 17))
        self.label_2.setObjectName(_fromUtf8("label_2"))
        self.directory = QtGui.QLineEdit(procpardlg)
        self.directory.setGeometry(QtCore.QRect(130, 50, 461, 27))
        self.directory.setObjectName(_fromUtf8("directory"))
        self.groupBox = QtGui.QGroupBox(procpardlg)
        self.groupBox.setGeometry(QtCore.QRect(50, 100, 511, 131))
        self.groupBox.setObjectName(_fromUtf8("groupBox"))
        self.um_ur = QtGui.QCheckBox(self.groupBox)
        self.um_ur.setGeometry(QtCore.QRect(20, 30, 97, 22))
        self.um_ur.setObjectName(_fromUtf8("um_ur"))
        self.um_uw = QtGui.QCheckBox(self.groupBox)
        self.um_uw.setGeometry(QtCore.QRect(20, 60, 97, 22))
        self.um_uw.setObjectName(_fromUtf8("um_uw"))
        self.um_ux = QtGui.QCheckBox(self.groupBox)
        self.um_ux.setGeometry(QtCore.QRect(20, 90, 121, 22))
        self.um_ux.setObjectName(_fromUtf8("um_ux"))
        self.um_gx = QtGui.QCheckBox(self.groupBox)
        self.um_gx.setGeometry(QtCore.QRect(160, 90, 131, 22))
        self.um_gx.setObjectName(_fromUtf8("um_gx"))
        self.um_gr = QtGui.QCheckBox(self.groupBox)
        self.um_gr.setGeometry(QtCore.QRect(160, 30, 111, 22))
        self.um_gr.setObjectName(_fromUtf8("um_gr"))
        self.um_gw = QtGui.QCheckBox(self.groupBox)
        self.um_gw.setGeometry(QtCore.QRect(160, 60, 121, 22))
        self.um_gw.setObjectName(_fromUtf8("um_gw"))
        self.um_ow = QtGui.QCheckBox(self.groupBox)
        self.um_ow.setGeometry(QtCore.QRect(340, 60, 121, 22))
        self.um_ow.setObjectName(_fromUtf8("um_ow"))
        self.um_or = QtGui.QCheckBox(self.groupBox)
        self.um_or.setGeometry(QtCore.QRect(340, 30, 111, 22))
        self.um_or.setObjectName(_fromUtf8("um_or"))
        self.um_ox = QtGui.QCheckBox(self.groupBox)
        self.um_ox.setGeometry(QtCore.QRect(340, 90, 131, 22))
        self.um_ox.setObjectName(_fromUtf8("um_ox"))
        self.label_3 = QtGui.QLabel(procpardlg)
        self.label_3.setGeometry(QtCore.QRect(40, 300, 101, 17))
        self.label_3.setObjectName(_fromUtf8("label_3"))
        self.norml = QtGui.QSpinBox(procpardlg)
        self.norml.setGeometry(QtCore.QRect(140, 290, 71, 27))
        self.norml.setMaximum(255)
        self.norml.setObjectName(_fromUtf8("norml"))
        self.label_4 = QtGui.QLabel(procpardlg)
        self.label_4.setGeometry(QtCore.QRect(220, 290, 21, 21))
        self.label_4.setObjectName(_fromUtf8("label_4"))
        self.normu = QtGui.QSpinBox(procpardlg)
        self.normu.setGeometry(QtCore.QRect(250, 290, 71, 27))
        self.normu.setMaximum(255)
        self.normu.setObjectName(_fromUtf8("normu"))
        self.label_5 = QtGui.QLabel(procpardlg)
        self.label_5.setGeometry(QtCore.QRect(340, 290, 66, 21))
        self.label_5.setObjectName(_fromUtf8("label_5"))
        self.errl = QtGui.QSpinBox(procpardlg)
        self.errl.setGeometry(QtCore.QRect(400, 290, 71, 27))
        self.errl.setMaximum(255)
        self.errl.setProperty("value", 1)
        self.errl.setObjectName(_fromUtf8("errl"))
        self.label_6 = QtGui.QLabel(procpardlg)
        self.label_6.setGeometry(QtCore.QRect(480, 290, 21, 21))
        self.label_6.setObjectName(_fromUtf8("label_6"))
        self.erru = QtGui.QSpinBox(procpardlg)
        self.erru.setGeometry(QtCore.QRect(510, 290, 71, 27))
        self.erru.setMaximum(255)
        self.erru.setProperty("value", 255)
        self.erru.setObjectName(_fromUtf8("erru"))
        self.label_7 = QtGui.QLabel(procpardlg)
        self.label_7.setGeometry(QtCore.QRect(40, 240, 51, 17))
        self.label_7.setObjectName(_fromUtf8("label_7"))
        self.ulimitv = QtGui.QSpinBox(procpardlg)
        self.ulimitv.setGeometry(QtCore.QRect(120, 230, 91, 27))
        self.ulimitv.setMaximum(1023)
        self.ulimitv.setObjectName(_fromUtf8("ulimitv"))
        self.ulimitmult = QtGui.QComboBox(procpardlg)
        self.ulimitmult.setGeometry(QtCore.QRect(250, 230, 81, 27))
        self.ulimitmult.setObjectName(_fromUtf8("ulimitmult"))
        self.ulimitmult.addItem(_fromUtf8(""))
        self.ulimitmult.addItem(_fromUtf8(""))
        self.ulimitmult.addItem(_fromUtf8(""))
        self.noadverr = QtGui.QCheckBox(procpardlg)
        self.noadverr.setGeometry(QtCore.QRect(50, 350, 181, 22))
        self.noadverr.setObjectName(_fromUtf8("noadverr"))
        self.exporttype = QtGui.QComboBox(procpardlg)
        self.exporttype.setGeometry(QtCore.QRect(270, 350, 151, 27))
        self.exporttype.setObjectName(_fromUtf8("exporttype"))
        self.exporttype.addItem(_fromUtf8(""))
        self.exporttype.addItem(_fromUtf8(""))
        self.exporttype.addItem(_fromUtf8(""))

        self.retranslateUi(procpardlg)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("accepted()")), procpardlg.accept)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("rejected()")), procpardlg.reject)
        QtCore.QMetaObject.connectSlotsByName(procpardlg)
        procpardlg.setTabOrder(self.directory, self.um_ur)
        procpardlg.setTabOrder(self.um_ur, self.um_uw)
        procpardlg.setTabOrder(self.um_uw, self.um_ux)
        procpardlg.setTabOrder(self.um_ux, self.um_gr)
        procpardlg.setTabOrder(self.um_gr, self.um_gw)
        procpardlg.setTabOrder(self.um_gw, self.um_gx)
        procpardlg.setTabOrder(self.um_gx, self.um_or)
        procpardlg.setTabOrder(self.um_or, self.um_ow)
        procpardlg.setTabOrder(self.um_ow, self.um_ox)
        procpardlg.setTabOrder(self.um_ox, self.ulimitv)
        procpardlg.setTabOrder(self.ulimitv, self.ulimitmult)
        procpardlg.setTabOrder(self.ulimitmult, self.norml)
        procpardlg.setTabOrder(self.norml, self.normu)
        procpardlg.setTabOrder(self.normu, self.errl)
        procpardlg.setTabOrder(self.errl, self.erru)
        procpardlg.setTabOrder(self.erru, self.noadverr)
        procpardlg.setTabOrder(self.noadverr, self.exporttype)
        procpardlg.setTabOrder(self.exporttype, self.buttonBox)

    def retranslateUi(self, procpardlg):
        procpardlg.setWindowTitle(QtGui.QApplication.translate("procpardlg", "Process Parameters", None, QtGui.QApplication.UnicodeUTF8))
        self.label.setText(QtGui.QApplication.translate("procpardlg", "Editing job:", None, QtGui.QApplication.UnicodeUTF8))
        self.label_2.setText(QtGui.QApplication.translate("procpardlg", "Directory:", None, QtGui.QApplication.UnicodeUTF8))
        self.directory.setToolTip(QtGui.QApplication.translate("procpardlg", "This is the working directory for the job.\n"
"\n"
"Remember you can use ~user to give the user\'s home directory or $HOME\n"
"and so forth (but this will use the environment variables in the job).", None, QtGui.QApplication.UnicodeUTF8))
        self.groupBox.setTitle(QtGui.QApplication.translate("procpardlg", "Umask - turn OFF", None, QtGui.QApplication.UnicodeUTF8))
        self.um_ur.setToolTip(QtGui.QApplication.translate("procpardlg", "Set Umask bit to turn off user read", None, QtGui.QApplication.UnicodeUTF8))
        self.um_ur.setText(QtGui.QApplication.translate("procpardlg", "User Read", None, QtGui.QApplication.UnicodeUTF8))
        self.um_uw.setToolTip(QtGui.QApplication.translate("procpardlg", "Set Umask bit to turn off user write", None, QtGui.QApplication.UnicodeUTF8))
        self.um_uw.setText(QtGui.QApplication.translate("procpardlg", "User Write", None, QtGui.QApplication.UnicodeUTF8))
        self.um_ux.setToolTip(QtGui.QApplication.translate("procpardlg", "Set Umask bit to turn off user execute/search", None, QtGui.QApplication.UnicodeUTF8))
        self.um_ux.setText(QtGui.QApplication.translate("procpardlg", "User Execute", None, QtGui.QApplication.UnicodeUTF8))
        self.um_gx.setToolTip(QtGui.QApplication.translate("procpardlg", "Set Umask bit to turn off group execute/search", None, QtGui.QApplication.UnicodeUTF8))
        self.um_gx.setText(QtGui.QApplication.translate("procpardlg", "Group Execute", None, QtGui.QApplication.UnicodeUTF8))
        self.um_gr.setToolTip(QtGui.QApplication.translate("procpardlg", "Set Umask bit to turn off group read", None, QtGui.QApplication.UnicodeUTF8))
        self.um_gr.setText(QtGui.QApplication.translate("procpardlg", "Group Read", None, QtGui.QApplication.UnicodeUTF8))
        self.um_gw.setToolTip(QtGui.QApplication.translate("procpardlg", "Set Umask bit to turn off group write", None, QtGui.QApplication.UnicodeUTF8))
        self.um_gw.setText(QtGui.QApplication.translate("procpardlg", "Group Write", None, QtGui.QApplication.UnicodeUTF8))
        self.um_ow.setToolTip(QtGui.QApplication.translate("procpardlg", "Set Umask bit to turn off others write", None, QtGui.QApplication.UnicodeUTF8))
        self.um_ow.setText(QtGui.QApplication.translate("procpardlg", "Others Write", None, QtGui.QApplication.UnicodeUTF8))
        self.um_or.setToolTip(QtGui.QApplication.translate("procpardlg", "Set Umask bit to turn off others read", None, QtGui.QApplication.UnicodeUTF8))
        self.um_or.setText(QtGui.QApplication.translate("procpardlg", "Others Read", None, QtGui.QApplication.UnicodeUTF8))
        self.um_ox.setToolTip(QtGui.QApplication.translate("procpardlg", "Set Umask bit to turn off others execute/search", None, QtGui.QApplication.UnicodeUTF8))
        self.um_ox.setText(QtGui.QApplication.translate("procpardlg", "Others Execute", None, QtGui.QApplication.UnicodeUTF8))
        self.label_3.setText(QtGui.QApplication.translate("procpardlg", "Exits - Normal", None, QtGui.QApplication.UnicodeUTF8))
        self.norml.setToolTip(QtGui.QApplication.translate("procpardlg", "This is the lower bound of exit codes considered \"normal\"", None, QtGui.QApplication.UnicodeUTF8))
        self.label_4.setText(QtGui.QApplication.translate("procpardlg", "to", None, QtGui.QApplication.UnicodeUTF8))
        self.normu.setToolTip(QtGui.QApplication.translate("procpardlg", "This is the upper bound of exit codes considered \"normal\"", None, QtGui.QApplication.UnicodeUTF8))
        self.label_5.setText(QtGui.QApplication.translate("procpardlg", "Error", None, QtGui.QApplication.UnicodeUTF8))
        self.errl.setToolTip(QtGui.QApplication.translate("procpardlg", "This is the lower bound of exit codes considered \"error\"", None, QtGui.QApplication.UnicodeUTF8))
        self.label_6.setText(QtGui.QApplication.translate("procpardlg", "to", None, QtGui.QApplication.UnicodeUTF8))
        self.erru.setToolTip(QtGui.QApplication.translate("procpardlg", "This is the upper bound of exit codes considered \"error\"", None, QtGui.QApplication.UnicodeUTF8))
        self.label_7.setText(QtGui.QApplication.translate("procpardlg", "Ulimit", None, QtGui.QApplication.UnicodeUTF8))
        self.ulimitv.setToolTip(QtGui.QApplication.translate("procpardlg", "This is the value of the ulimit. Set 0 to indicate unlimited", None, QtGui.QApplication.UnicodeUTF8))
        self.ulimitmult.setToolTip(QtGui.QApplication.translate("procpardlg", "Give a multiplier here for the ulimit", None, QtGui.QApplication.UnicodeUTF8))
        self.ulimitmult.setItemText(0, QtGui.QApplication.translate("procpardlg", "Bytes", None, QtGui.QApplication.UnicodeUTF8))
        self.ulimitmult.setItemText(1, QtGui.QApplication.translate("procpardlg", "KB", None, QtGui.QApplication.UnicodeUTF8))
        self.ulimitmult.setItemText(2, QtGui.QApplication.translate("procpardlg", "MB", None, QtGui.QApplication.UnicodeUTF8))
        self.noadverr.setToolTip(QtGui.QApplication.translate("procpardlg", "Select this if time is not to be advanced on error", None, QtGui.QApplication.UnicodeUTF8))
        self.noadverr.setText(QtGui.QApplication.translate("procpardlg", "No advance on error", None, QtGui.QApplication.UnicodeUTF8))
        self.exporttype.setToolTip(QtGui.QApplication.translate("procpardlg", "Select export type\n"
"\n"
"Local means local only to current host\n"
"Exported means visible on other hosts, not executable\n"
"Remote runnable means it can run on other hosts.", None, QtGui.QApplication.UnicodeUTF8))
        self.exporttype.setItemText(0, QtGui.QApplication.translate("procpardlg", "Local only", None, QtGui.QApplication.UnicodeUTF8))
        self.exporttype.setItemText(1, QtGui.QApplication.translate("procpardlg", "Exported", None, QtGui.QApplication.UnicodeUTF8))
        self.exporttype.setItemText(2, QtGui.QApplication.translate("procpardlg", "Remote runnable", None, QtGui.QApplication.UnicodeUTF8))

